/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 09948
 |                  NATIONAL YOUTH SURVEY (1983): WAVE 6
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\09948-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE v1ffffff  1='(1) Male' 2='(2) Female' ;
  VALUE v2ffffff  1='(1) Anglo' 2='(2) Black' 3='(3) Hispanic' 4='(4) American Indian'
                  5='(5) Asian' 6='(6) Other' ;
  VALUE v7ffffff  1='(1) Single' 2='(2) Married' 3='(3) Divorced' ;
  VALUE v10fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v15fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v16fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v17fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v18fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v19fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v20fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v21fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v24fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v27fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v30fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v33fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v37fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v38fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v39fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v40fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v41fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v42fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v43fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v44fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v45fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v47fffff  1='(1) NIMH' 2='(2) LEAA' ;
  VALUE v50fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v51fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v52fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v53fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v54fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v55fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v56fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v57fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v58fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v59fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v60fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v61fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v62fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v63fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v64fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v65fffff  1='(1) Mother/Father' 2='(2) Mother only' 3='(3) Father only'
                  4='(4) Moth/Stepfath' 5='(5) Fath/Stepmoth' 6='(6) Spouse' 7='(7) Roommate'
                  8='(8) Boy/girlfriend' 9='(9) Alone' 10='(10) Military' 11='(11) Other'
                  12='(12) Mother/oth rel' 13='(13) Father/oth rel'
                  14='(14) Moth/fath oth rel' 15='(15) Relatives' 16='(16) In-laws'
                  17='(17) Spouse/in-laws' 18='(18) Prison' 19='(19) Spouse/parents'
                  20='(20) Boy/girlfrd/par' 21='(21) B/gfriend/in-law' ;
  VALUE v66fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v67fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v68fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v69fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v70fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v71fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v72fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v73fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v74fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v75fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v76fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v77fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v78fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v79fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v80fffff  1='(1) Not problem' 2='(2) Somewhat problem' 3='(3) Big problem' ;
  VALUE v81fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v82fffff  1='(1) No' 2='(2) Yes' 3='(3) Yes to V81' ;
  VALUE v83fffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v84fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v85fffff  0='(0) Less than once wk' ;
  VALUE v86fffff  0='(0) Less than once wk' ;
  VALUE v87fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v89fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v90fffff  1='(1) Not at all' 2='(2) In a few ways' 3='(3) In some ways'
                  4='(4) In most ways' 5='(5) In all ways' ;
  VALUE v91fffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v92fffff  1='(1) Very diss' 2='(2) Somewhat diss' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE v93fffff  1='(1) None' 2='(2) A few' 3='(3) Some' 4='(4) Most' 5='(5) All' ;
  VALUE v94fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v95fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v96fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v97fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v98fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v99fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v102ffff  1='(1) Very diss' 2='(2) Somewhat diss' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE v103ffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v104ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v105ffff  18='(18) Not in school' 19='(19) Adult ed' 20='(20) GED program'
                  21='(21) Other' ;
  VALUE v106ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v107ffff  18='(18) Not in school' 19='(19) Adult ed' 20='(20) GED program'
                  21='(21) Other' ;
  VALUE v109ffff  1='(1) Mostly F''s' 2='(2) Mostly D''s' 3='(3) Mostly C''s'
                  4='(4) Mostly B''s' 5='(5) Mostly A''s' ;
  VALUE v110ffff  0='(0) Less than once wk' ;
  VALUE v111ffff  0='(0) Less than once wk' ;
  VALUE v112ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v114ffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v115ffff  1='(1) Very diss' 2='(2) Somewhat diss' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE v116ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v117ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v118ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v119ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v120ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v121ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v122ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v123ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v124ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v125ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v126ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v127ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v128ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v129ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v130ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v131ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v132ffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v133ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v138ffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v139ffff  1='(1) Very diss' 2='(2) Somewhat diss' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE v140ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v141ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v142ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v143ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v144ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v145ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v146ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v147ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v148ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v149ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v150ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v151ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v152ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v153ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v154ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v155ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v156ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v157ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v158ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v159ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v160ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v161ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v162ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v163ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v164ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v165ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v166ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v167ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v168ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v169ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v170ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v171ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v172ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v173ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v174ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v176ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v181ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v186ffff  1='(1) Spouse' 2='(2) Girl/boyfriend' ;
  VALUE v187ffff  0='(0) Less than 1 mo' ;
  VALUE v188ffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v189ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v190ffff  1='(1) Not at all' 2='(2) In a few ways' 3='(3) In some ways'
                  4='(4) In most ways' 5='(5) In all ways' ;
  VALUE v191ffff  1='(1) Very diss' 2='(2) Somewhat diss' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE v192ffff  1='(1) None' 2='(2) A few' 3='(3) Some' 4='(4) Most' 5='(5) All' ;
  VALUE v193ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v194ffff  1='(1) Very diss' 2='(2) Somewhat diss' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE v195ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v196ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v197ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v198ffff  0='(0) No' 1='(1) Once' 2='(2) 2 or 3 times' 3='(3) 4 or more times' ;
  VALUE v199ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v203ffff  16='(16) B.A. degree' 17='(17) Grad degree' ;
  VALUE v205ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly' ;
  VALUE v206ffff  0='(0) Less than 1 mo' ;
  VALUE v207ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly' ;
  VALUE v208ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v209ffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v210ffff  1='(1) Very diss' 2='(2) Somewhat diss' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE v211ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v212ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly' ;
  VALUE v213ffff  0='(0) Less than 1 mo' ;
  VALUE v214ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly' ;
  VALUE v215ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v216ffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v217ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v218ffff  1='(1) Very diss' 2='(2) Somewhat diss' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE v219ffff  0='(0) Less than once wk' ;
  VALUE v220ffff  0='(0) Less than once wk' ;
  VALUE v221ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v222ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly' ;
  VALUE v223ffff  0='(0) Less than 1 mo' ;
  VALUE v224ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly' ;
  VALUE v225ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v226ffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v227ffff  1='(1) Very diss' 2='(2) Somewhat diss' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE v228ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v229ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v230ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v231ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v232ffff  99='(99) Don''t know' ;
  VALUE v233ffff  99='(99) Don''t know' ;
  VALUE v234ffff  1='(1) Boy' 2='(2) Girl' ;
  VALUE v235ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v236ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v237ffff  99='(99) Don''t know' ;
  VALUE v238ffff  99='(99) Don''t know' ;
  VALUE v239ffff  1='(1) Boy' 2='(2) Girl' ;
  VALUE v240ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v241ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v242ffff  99='(99) Don''t know' ;
  VALUE v243ffff  99='(99) Don''t know' ;
  VALUE v244ffff  1='(1) Boy' 2='(2) Girl' ;
  VALUE v245ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v246ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v247ffff  99='(99) Don''t know' ;
  VALUE v248ffff  99='(99) Don''t know' ;
  VALUE v249ffff  1='(1) Boy' 2='(2) Girl' ;
  VALUE v250ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v251ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v252ffff  99='(99) Don''t know' ;
  VALUE v253ffff  99='(99) Don''t know' ;
  VALUE v254ffff  1='(1) Boy' 2='(2) Girl' ;
  VALUE v255ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v256ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v258ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v259ffff  1='(1) Very diss' 2='(2) Somewhat diss' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE v260ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v261ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly' ;
  VALUE v262ffff  1='(1) Not imp' 2='(2) Not too imp' 3='(3) Somewhat imp' 4='(4) Pretty imp'
                  5='(5) Very imp' ;
  VALUE v263ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v264ffff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved'
                  9='(9) Don''t know/NA' ;
  VALUE v265ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v266ffff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved'
                  9='(9) Don''t know/NA' ;
  VALUE v267ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v268ffff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved'
                  9='(9) Don''t know/NA' ;
  VALUE v269ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v270ffff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved'
                  9='(9) Don''t know/NA' ;
  VALUE v271ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v272ffff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved'
                  9='(9) Don''t know/NA' ;
  VALUE v273ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v274ffff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved'
                  9='(9) Don''t know/NA' ;
  VALUE v275ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v276ffff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved'
                  9='(9) Don''t know/NA' ;
  VALUE v277ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v278ffff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved'
                  9='(9) Don''t know/NA' ;
  VALUE v279ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v280ffff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved'
                  9='(9) Don''t know/NA' ;
  VALUE v281ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v282ffff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved'
                  9='(9) Don''t know/NA' ;
  VALUE v283ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v284ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v285ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v286ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v287ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v288ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v289ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v290ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v291ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v292ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v293ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v294ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v295ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v296ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v297ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v298ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v299ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v300ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v301ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v302ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v303ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v304ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v305ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v306ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v307ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v308ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v309ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v310ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v311ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v312ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v313ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v314ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v315ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v316ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v317ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v318ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v319ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v320ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v321ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v322ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v323ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v324ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v325ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v326ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v327ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v328ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v329ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v330ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v331ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v332ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v333ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v334ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v335ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v336ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v337ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v338ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v339ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v340ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v341ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v342ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v343ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v344ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v345ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v346ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v347ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v348ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v349ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v350ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v351ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v352ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v353ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v354ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v355ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v356ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v357ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v358ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v359ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v360ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v361ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v362ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v363ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v364ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v365ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v366ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v367ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v368ffff  1='(1) Not wrong' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v369ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v370ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v371ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v372ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v373ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v374ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v375ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v376ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v377ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v378ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v379ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v380ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v381ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v382ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v384ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v386ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v388ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v390ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v392ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v394ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v396ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v398ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v400ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v402ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v404ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v406ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v408ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v410ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v412ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v414ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v416ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v418ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v420ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v422ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v424ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v426ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v428ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v430ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v432ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v434ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v436ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v438ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v440ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v442ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v444ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v446ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v448ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v450ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v452ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v454ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v456ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v458ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v460ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v462ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v464ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v466ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v468ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v470ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v472ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v473ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v474ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v475ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v476ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v477ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v478ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v479ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v480ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v481ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v482ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v483ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v484ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v485ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v486ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v487ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v488ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v489ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v490ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v491ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v492ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v493ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v494ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v495ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v496ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v497ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v498ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v499ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v500ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v501ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v502ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v503ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v504ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v505ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v506ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v507ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v508ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v509ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v510ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v511ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v512ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v513ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v514ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v515ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v516ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v517ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v518ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v519ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v520ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v521ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v522ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v523ffff  1='(1) Inappropriate' 2='(2) App but trivial' 3='(3) App & nontrivial' ;
  VALUE v525ffff  0='(0) Alone' ;
  VALUE v526ffff  0='(0) No' ;
  VALUE v527ffff  0='(0) No' ;
  VALUE v529ffff  0='(0) Alone' ;
  VALUE v530ffff  0='(0) No' ;
  VALUE v531ffff  0='(0) No' ;
  VALUE v533ffff  0='(0) Alone' ;
  VALUE v534ffff  0='(0) No' ;
  VALUE v535ffff  0='(0) No' ;
  VALUE v537ffff  0='(0) Alone' ;
  VALUE v538ffff  0='(0) No' ;
  VALUE v539ffff  0='(0) No' ;
  VALUE v540ffff  1='(1) Car' 2='(2) Truck' 3='(3) Motorcycle' 4='(4) Other' ;
  VALUE v541ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v542ffff  1='(1) Family member' 2='(2) Friend' 3='(3) Other' ;
  VALUE v543ffff  1='(1) Had the keys' 2='(2) Hot wired' 3='(3) Ignition' 4='(4) Other' ;
  VALUE v544ffff  1='(1) Riding' 2='(2) Keep' 3='(3) Keep parts' 4='(4) Sell' 5='(5) Sell parts'
                  6='(6) Other' ;
  VALUE v545ffff  0='(0) Alone' ;
  VALUE v546ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v547ffff  0='(0) No' ;
  VALUE v548ffff  0='(0) No' ;
  VALUE v549ffff  1='(1) Car' 2='(2) Truck' 3='(3) Motorcycle' 4='(4) Other' ;
  VALUE v550ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v551ffff  1='(1) Family member' 2='(2) Friend' 3='(3) Other' ;
  VALUE v552ffff  1='(1) Had the keys' 2='(2) Hot wired' 3='(3) Ignition' 4='(4) Other' ;
  VALUE v553ffff  1='(1) Riding' 2='(2) Keep' 3='(3) Keep parts' 4='(4) Sell' 5='(5) Sell parts'
                  6='(6) Other' ;
  VALUE v554ffff  0='(0) Alone' ;
  VALUE v555ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v556ffff  0='(0) No' ;
  VALUE v557ffff  0='(0) No' ;
  VALUE v558ffff  1='(1) Car' 2='(2) Truck' 3='(3) Motorcycle' 4='(4) Other' ;
  VALUE v559ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v560ffff  1='(1) Family member' 2='(2) Friend' 3='(3) Other' ;
  VALUE v561ffff  1='(1) Had the keys' 2='(2) Hot wired' 3='(3) Ignition' 4='(4) Other' ;
  VALUE v562ffff  1='(1) Riding' 2='(2) Keep' 3='(3) Keep parts' 4='(4) Sell' 5='(5) Sell parts'
                  6='(6) Other' ;
  VALUE v563ffff  0='(0) Alone' ;
  VALUE v564ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v565ffff  0='(0) No' ;
  VALUE v566ffff  0='(0) No' ;
  VALUE v568ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v569ffff  1='(1) Retail store' 2='(2) Private home' 3='(3) Auto' 4='(4) Work place'
                  5='(5) College/school' 6='(6) Const site' 7='(7) Warehouse' 8='(8) Other' ;
  VALUE v570ffff  0='(0) Alone' ;
  VALUE v571ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v572ffff  0='(0) No' ;
  VALUE v573ffff  0='(0) No' ;
  VALUE v575ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v576ffff  1='(1) Retail store' 2='(2) Private home' 3='(3) Auto' 4='(4) Work place'
                  5='(5) College/school' 6='(6) Const site' 7='(7) Warehouse' 8='(8) Other' ;
  VALUE v577ffff  0='(0) Alone' ;
  VALUE v578ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v579ffff  0='(0) No' ;
  VALUE v580ffff  0='(0) No' ;
  VALUE v582ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v583ffff  1='(1) Retail store' 2='(2) Private home' 3='(3) Auto' 4='(4) Work place'
                  5='(5) College/school' 6='(6) Const site' 7='(7) Warehouse' 8='(8) Other' ;
  VALUE v584ffff  0='(0) Alone' ;
  VALUE v585ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v586ffff  0='(0) No' ;
  VALUE v587ffff  0='(0) No' ;
  VALUE v588ffff  1='(1) Try to buy' 2='(2) Try to sell' 3='(3) Try to hold' 4='(4) Buy'
                  5='(5) Sell' 6='(6) Hold' 7='(7) Other' ;
  VALUE v590ffff  0='(0) Alone' ;
  VALUE v591ffff  0='(0) No' ;
  VALUE v592ffff  0='(0) No' ;
  VALUE v593ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v594ffff  0='(0) Alone' ;
  VALUE v595ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v596ffff  0='(0) No' ;
  VALUE v597ffff  0='(0) No' ;
  VALUE v598ffff  1='(1) Knife' 2='(2) Gun' 3='(3) Other' ;
  VALUE v600ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v601ffff  0='(0) Alone' ;
  VALUE v602ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v603ffff  0='(0) No' ;
  VALUE v604ffff  0='(0) No' ;
  VALUE v605ffff  1='(1) Hit' 2='(2) Beat/choked' 3='(3) Attacked w/weapon' 4='(4) Other' ;
  VALUE v606ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v607ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v608ffff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE v609ffff  0='(0) Alone' ;
  VALUE v610ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v611ffff  0='(0) No' ;
  VALUE v612ffff  0='(0) No' ;
  VALUE v613ffff  1='(1) Hit' 2='(2) Beat/choked' 3='(3) Attacked w/weapon' 4='(4) Other' ;
  VALUE v614ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v615ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v616ffff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE v617ffff  0='(0) Alone' ;
  VALUE v618ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v619ffff  0='(0) No' ;
  VALUE v620ffff  0='(0) No' ;
  VALUE v621ffff  1='(1) Hit' 2='(2) Beat/choked' 3='(3) Attacked w/weapon' 4='(4) Other' ;
  VALUE v622ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v623ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v624ffff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE v625ffff  0='(0) Alone' ;
  VALUE v626ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v627ffff  0='(0) No' ;
  VALUE v628ffff  0='(0) No' ;
  VALUE v629ffff  1='(1) 1-2 people' 2='(2) 3-5 people' 3='(3) > 5 people' ;
  VALUE v630ffff  1='(1) 1-2 people' 2='(2) 3-5 people' 3='(3) > 5 people' ;
  VALUE v631ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v632ffff  1='(1) Knives' 2='(2) Chains' 3='(3) Knckles/numchck' 4='(4) Guns'
                  5='(5) Other' 6='(6) Mxed weap w/knive' 7='(7) Mxed weap w/guns'
                  8='(8) Mxed wp-no gun/knv' ;
  VALUE v633ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v634ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v635ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v636ffff  0='(0) No' ;
  VALUE v637ffff  0='(0) No' ;
  VALUE v638ffff  1='(1) 1-2 people' 2='(2) 3-5 people' 3='(3) > 5 people' ;
  VALUE v639ffff  1='(1) 1-2 people' 2='(2) 3-5 people' 3='(3) > 5 people' ;
  VALUE v640ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v641ffff  1='(1) Knives' 2='(2) Chains' 3='(3) Knckles/numchck' 4='(4) Guns'
                  5='(5) Other' 6='(6) Mxed weap w/knive' 7='(7) Mxed weap w/guns'
                  8='(8) Mxed wp-no gun/knv' ;
  VALUE v642ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v643ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v644ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v645ffff  0='(0) No' ;
  VALUE v646ffff  0='(0) No' ;
  VALUE v647ffff  1='(1) 1-2 people' 2='(2) 3-5 people' 3='(3) > 5 people' ;
  VALUE v648ffff  1='(1) 1-2 people' 2='(2) 3-5 people' 3='(3) > 5 people' ;
  VALUE v649ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v650ffff  1='(1) Knives' 2='(2) Chains' 3='(3) Knckles/numchck' 4='(4) Guns'
                  5='(5) Other' 6='(6) Mxed weap w/knive' 7='(7) Mxed weap w/guns'
                  8='(8) Mxed wp-no gun/knv' ;
  VALUE v651ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v652ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v653ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v654ffff  0='(0) No' ;
  VALUE v655ffff  0='(0) No' ;
  VALUE v656ffff  1='(1) Overdraft' 2='(2) Forged check' 3='(3) Cashed check'
                  4='(4) Counterfeit money' 5='(5) Other' ;
  VALUE v658ffff  0='(0) Alone' ;
  VALUE v659ffff  0='(0) No' ;
  VALUE v660ffff  0='(0) No' ;
  VALUE v662ffff  100='(100) Lrg quant/unknwn' ;
  VALUE v663ffff  0='(0) Alone' ;
  VALUE v664ffff  0='(0) No' ;
  VALUE v665ffff  0='(0) No' ;
  VALUE v666ffff  1='(1) Money' 2='(2) Other' 3='(3) Both' ;
  VALUE v669ffff  0='(0) Alone' ;
  VALUE v670ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v671ffff  0='(0) No' ;
  VALUE v672ffff  0='(0) No' ;
  VALUE v673ffff  1='(1) Money' 2='(2) Other' 3='(3) Both' ;
  VALUE v676ffff  0='(0) Alone' ;
  VALUE v677ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v678ffff  0='(0) No' ;
  VALUE v679ffff  0='(0) No' ;
  VALUE v680ffff  1='(1) Actually forced' 2='(2) Try didn''t succd' ;
  VALUE v681ffff  1='(1) Verb threat inj' 2='(2) Mild roughness' 3='(3) Phys beat/choke'
                  4='(4) Threat of weapon' 5='(5) Used a weapon' 6='(6) Other' ;
  VALUE v682ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v683ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v684ffff  0='(0) Alone' ;
  VALUE v685ffff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE v686ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v687ffff  0='(0) No' ;
  VALUE v688ffff  0='(0) No' ;
  VALUE v689ffff  1='(1) Actually forced' 2='(2) Tried didn sucd' ;
  VALUE v690ffff  1='(1) Verb thrts injy' 2='(2) Mild roughness' 3='(3) Phys beatg/chokg'
                  4='(4) Threat of weapon' 5='(5) Used a weapon' 6='(6) Other' ;
  VALUE v691ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v692ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v693ffff  0='(0) Alone' ;
  VALUE v694ffff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE v695ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v696ffff  0='(0) No' ;
  VALUE v697ffff  0='(0) No' ;
  VALUE v698ffff  1='(1) Actually forced' 2='(2) Tried ddnt succd' ;
  VALUE v699ffff  1='(1) Verb thrts injy' 2='(2) Mild roughness' 3='(3) Phys beatg/chokg'
                  4='(4) Threat of weapon' 5='(5) Used a weapon' 6='(6) Other' ;
  VALUE v700ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v701ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v702ffff  0='(0) Alone' ;
  VALUE v703ffff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE v704ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v705ffff  0='(0) No' ;
  VALUE v706ffff  0='(0) No' ;
  VALUE v707ffff  1='(1) Actually hit' 2='(2) Tried didt succd' 3='(3) Only threatd hit' ;
  VALUE v708ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v709ffff  1='(1) Pushd or slappd' 2='(2) Caused pain' 3='(3) Knocked down'
                  4='(4) Bruised' 5='(5) Cut/bleeding' 6='(6) Unconscious'
                  7='(7) Hospitalized' 8='(8) Other' ;
  VALUE v710ffff  0='(0) Alone' ;
  VALUE v711ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v712ffff  0='(0) No' ;
  VALUE v713ffff  0='(0) No' ;
  VALUE v714ffff  1='(1) Actually hit' 2='(2) Tried ddnt succd' 3='(3) Only threatd hit' ;
  VALUE v715ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v716ffff  1='(1) Pushd or slappd' 2='(2) Caused pain' 3='(3) Knocked down'
                  4='(4) Bruised' 5='(5) Cut/bleeding' 6='(6) Unconscious'
                  7='(7) Hospitalized' 8='(8) Other' ;
  VALUE v717ffff  0='(0) Alone' ;
  VALUE v718ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v719ffff  0='(0) No' ;
  VALUE v720ffff  0='(0) No' ;
  VALUE v721ffff  1='(1) Actually hit' 2='(2) Tried ddnt succd' 3='(3) Only threatd hit' ;
  VALUE v722ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v723ffff  1='(1) Pushed or slapped' 2='(2) Caused pain' 3='(3) Knocked down'
                  4='(4) Bruised' 5='(5) Cut/bleeding' 6='(6) Unconscious'
                  7='(7) Hospitalized' 8='(8) Other' ;
  VALUE v724ffff  0='(0) Alone' ;
  VALUE v725ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v726ffff  0='(0) No' ;
  VALUE v727ffff  0='(0) No' ;
  VALUE v728ffff  1='(1) Actually hit' 2='(2) Tried ddnt succd' 3='(3) Only threatd hit' ;
  VALUE v729ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v730ffff  1='(1) Pushd or slappd' 2='(2) Caused pain' 3='(3) Knocked down'
                  4='(4) Bruised' 5='(5) Cut/bleeding' 6='(6) Unconscious'
                  7='(7) Hospitalized' 8='(8) Other' ;
  VALUE v731ffff  0='(0) Alone' ;
  VALUE v732ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v733ffff  0='(0) No' ;
  VALUE v734ffff  0='(0) No' ;
  VALUE v735ffff  1='(1) Actually hit' 2='(2) Tried ddnt succd' 3='(3) Only threatd hit' ;
  VALUE v736ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v737ffff  1='(1) Pushd or slappd' 2='(2) Caused pain' 3='(3) Knocked down'
                  4='(4) Bruised' 5='(5) Cut/bleeding' 6='(6) Unconscious'
                  7='(7) Hospitalized' 8='(8) Other' ;
  VALUE v738ffff  0='(0) Alone' ;
  VALUE v739ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v740ffff  0='(0) No' ;
  VALUE v741ffff  0='(0) No' ;
  VALUE v742ffff  1='(1) Marijuana' 2='(2) Pills' 3='(3) Cocaine' 4='(4) Heroin' 5='(5) Other' ;
  VALUE v744ffff  0='(0) Alone' ;
  VALUE v745ffff  0='(0) No' ;
  VALUE v746ffff  0='(0) No' ;
  VALUE v747ffff  1='(1) Stranger' 2='(2) Family member' 3='(3) Friend' 4='(4) Other' ;
  VALUE v750ffff  1='(1) Actually sold it' 2='(2) Tried to sell it' ;
  VALUE v751ffff  0='(0) Alone' ;
  VALUE v752ffff  0='(0) No' ;
  VALUE v753ffff  0='(0) No' ;
  VALUE v754ffff  1='(1) Car' 2='(2) Truck' 3='(3) Motorcycle' 4='(4) Other' ;
  VALUE v755ffff  1='(1) Family member' 2='(2) Friend' 3='(3) Other' ;
  VALUE v756ffff  1='(1) Had the keys' 2='(2) Hot wired' 3='(3) Ignition' 4='(4) Other' ;
  VALUE v757ffff  0='(0) Alone' ;
  VALUE v758ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v759ffff  0='(0) No' ;
  VALUE v760ffff  0='(0) No' ;
  VALUE v761ffff  1='(1) Punched' 2='(2) Physical beating' 3='(3) Other' ;
  VALUE v762ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v763ffff  1='(1) Knives' 2='(2) Chains' 3='(3) Hrd knckl/nmchck' 4='(4) Guns'
                  5='(5) Other' 6='(6) Mixd weapns knvs' 7='(7) Mixd weapns guns'
                  8='(8) Md wps-n gns kvs' ;
  VALUE v764ffff  1='(1) Money' 2='(2) Other' ;
  VALUE v765ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v766ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v767ffff  0='(0) Alone' ;
  VALUE v768ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v769ffff  0='(0) No' ;
  VALUE v770ffff  0='(0) No' ;
  VALUE v771ffff  1='(1) Punched' 2='(2) Physical beating' 3='(3) Other' ;
  VALUE v772ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v773ffff  1='(1) Knives' 2='(2) Chains' 3='(3) Hrd knckl/nmchck' 4='(4) Guns'
                  5='(5) Other' 6='(6) Mixd weapns knvs' 7='(7) Mixd weapns guns'
                  8='(8) Md wpns-n gns ks' ;
  VALUE v774ffff  1='(1) Money' 2='(2) Other' ;
  VALUE v775ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v776ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v777ffff  0='(0) Alone' ;
  VALUE v778ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v779ffff  0='(0) No' ;
  VALUE v780ffff  0='(0) No' ;
  VALUE v781ffff  1='(1) Punched' 2='(2) Physical beating' 3='(3) Other' ;
  VALUE v782ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v783ffff  1='(1) Knives' 2='(2) Chains' 3='(3) Hrd knckl/nmchck' 4='(4) Guns'
                  5='(5) Other' 6='(6) Mxd wpns knvs' 7='(7) Mxd wpns guns'
                  8='(8) Mxd ws-n gs ks' ;
  VALUE v784ffff  1='(1) Money' 2='(2) Other' ;
  VALUE v785ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v786ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v787ffff  0='(0) Alone' ;
  VALUE v788ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v789ffff  0='(0) No' ;
  VALUE v790ffff  0='(0) No' ;
  VALUE v791ffff  1='(1) Punched' 2='(2) Phys beating' 3='(3) Other' ;
  VALUE v792ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v793ffff  1='(1) Knives' 2='(2) Chains' 3='(3) Hrd knckl/nmchck' 4='(4) Guns'
                  5='(5) Other' 6='(6) Mxd wpns knvs' 7='(7) Mxd wpns wth gns'
                  8='(8) Md ws-n gs ks' ;
  VALUE v794ffff  1='(1) Money' 2='(2) Other' ;
  VALUE v795ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v796ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v797ffff  0='(0) Alone' ;
  VALUE v798ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v799ffff  0='(0) No' ;
  VALUE v800ffff  0='(0) No' ;
  VALUE v801ffff  1='(1) Punched' 2='(2) Physical beating' 3='(3) Other' ;
  VALUE v802ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v803ffff  1='(1) Knives' 2='(2) Chains' 3='(3) Hrd knckl/nmchck' 4='(4) Guns'
                  5='(5) Other' 6='(6) Mxd wpns wth knvs' 7='(7) Mxd wpns wth gns'
                  8='(8) Mxd ws-n gs ks' ;
  VALUE v804ffff  1='(1) Money' 2='(2) Other' ;
  VALUE v805ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v806ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v807ffff  0='(0) Alone' ;
  VALUE v808ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v809ffff  0='(0) No' ;
  VALUE v810ffff  0='(0) No' ;
  VALUE v811ffff  1='(1) Punched' 2='(2) Physical beating' 3='(3) Other' ;
  VALUE v812ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v813ffff  1='(1) Knives' 2='(2) Chains' 3='(3) Hrd knckl/nmchck' 4='(4) Guns'
                  5='(5) Other' 6='(6) Mxd wpns wth knvs' 7='(7) Mxd wpns wth gns'
                  8='(8) Md ws-n gs ks' ;
  VALUE v814ffff  1='(1) Money' 2='(2) Other' ;
  VALUE v815ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v816ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v817ffff  0='(0) Alone' ;
  VALUE v818ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v819ffff  0='(0) No' ;
  VALUE v820ffff  0='(0) No' ;
  VALUE v822ffff  1='(1) Retail store' 2='(2) Private home' 3='(3) Auto' 4='(4) Work place'
                  5='(5) School/college' 6='(6) Constrctn site' 7='(7) Warehouse'
                  8='(8) Other' ;
  VALUE v823ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v824ffff  0='(0) Alone' ;
  VALUE v825ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v826ffff  0='(0) No' ;
  VALUE v827ffff  0='(0) No' ;
  VALUE v828ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v830ffff  0='(0) Alone' ;
  VALUE v831ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v832ffff  0='(0) No' ;
  VALUE v833ffff  0='(0) No' ;
  VALUE v834ffff  1='(1) Building' 2='(2) Vehicle' 3='(3) House' 4='(4) Other' ;
  VALUE v835ffff  1='(1) Broke in' 2='(2) Tried' 3='(3) Door open' ;
  VALUE v836ffff  1='(1) Look around' 2='(2) Steal' 3='(3) Other' ;
  VALUE v837ffff  0='(0) Alone' ;
  VALUE v838ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v839ffff  0='(0) No' ;
  VALUE v840ffff  0='(0) No' ;
  VALUE v841ffff  1='(1) Building' 2='(2) Vehicle' 3='(3) House' 4='(4) Other' ;
  VALUE v842ffff  1='(1) Broke in' 2='(2) Tried' 3='(3) Door open' ;
  VALUE v843ffff  1='(1) Look around' 2='(2) Steal' 3='(3) Other' ;
  VALUE v844ffff  0='(0) Alone' ;
  VALUE v845ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v846ffff  0='(0) No' ;
  VALUE v847ffff  0='(0) No' ;
  VALUE v848ffff  1='(1) Building' 2='(2) Vehicle' 3='(3) House' 4='(4) Other' ;
  VALUE v849ffff  1='(1) Broke in' 2='(2) Tried' 3='(3) Door open' ;
  VALUE v850ffff  1='(1) Look around' 2='(2) Steal' 3='(3) Other' ;
  VALUE v851ffff  0='(0) Alone' ;
  VALUE v852ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v853ffff  0='(0) No' ;
  VALUE v854ffff  0='(0) No' ;
  VALUE v855ffff  1='(1) Stranger' 2='(2) Family member' 3='(3) Friend' 4='(4) Other' ;
  VALUE v857ffff  0='(0) Alone' ;
  VALUE v858ffff  0='(0) No' ;
  VALUE v859ffff  0='(0) No' ;
  VALUE v860ffff  1='(1) Purse snatching' 2='(2) Pick pocket' 3='(3) Other' ;
  VALUE v861ffff  1='(1) Money' 2='(2) Credit cards' 3='(3) Checks' 4='(4) Other' ;
  VALUE v862ffff  0='(0) Alone' ;
  VALUE v863ffff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking/drugs' ;
  VALUE v864ffff  0='(0) No' ;
  VALUE v865ffff  0='(0) No' ;
  VALUE v867ffff  0='(0) No' ;
  VALUE v868ffff  0='(0) No' ;
  VALUE v869ffff  1='(1) Punched' 2='(2) Physical beating' 3='(3) Other' ;
  VALUE v870ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v871ffff  1='(1) Knives' 2='(2) Chains' 3='(3) Hrd knckl/nmchck' 4='(4) Guns'
                  5='(5) Other' 6='(6) Mxd wpns knvs' 7='(7) Mxd wpns gns'
                  8='(8) Mxd ws-n gn ks' ;
  VALUE v872ffff  1='(1) Money' 2='(2) Other' ;
  VALUE v873ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v874ffff  1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized' 6='(6) Other' ;
  VALUE v875ffff  0='(0) Alone' ;
  VALUE v876ffff  0='(0) No' ;
  VALUE v877ffff  0='(0) No' ;
  VALUE v878ffff  1='(1) To steal' 2='(2) Other' ;
  VALUE v879ffff  0='(0) Alone' ;
  VALUE v880ffff  0='(0) No' ;
  VALUE v881ffff  0='(0) No' ;
  VALUE v883ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v884ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v885ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v886ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v891ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v892ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v894ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v895ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v897ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v898ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v900ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v901ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v903ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v904ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v906ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v907ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v909ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v910ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v912ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v913ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v915ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v916ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v918ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v919ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v920ffff  1='(1) THC' 2='(2) Quaaludes' 3='(3) Cough medicine' 4='(4) Robitussin'
                  5='(5) Sominex' 6='(6) Sudafed' 7='(7) No-Doze' 8='(8) Demerol'
                  9='(9) Wght ctrl plls' 10='(10) Coricidin' 11='(11) Mushrooms' 13='(13) Pam'
                  14='(14) Other' ;
  VALUE v922ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v923ffff  1='(1) < 2 wks' 2='(2) 2-4 wks' 3='(3) > 1-2 mos' 4='(4) > 2-3 mos'
                  5='(5) > 3-4 mos' 6='(6) > 4-6 mos' 7='(7) > 6 mos'
                  8='(8) Use not episodic' ;
  VALUE v924ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v925ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v926ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v927ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v928ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v929ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v930ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v931ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v932ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v933ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v934ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v935ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v936ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v937ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v938ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v939ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v940ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v941ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v942ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v943ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v944ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v945ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v946ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v947ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times'
                  4='(4) 5 or 6 times' 5='(5) More than 6 times' ;
  VALUE v948ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v949ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v950ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v951ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v952ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v953ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v954ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v955ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v956ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v957ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v958ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v959ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v960ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v961ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v962ffff  1='(1) Yes' 2='(2) No' ;
  VALUE v972ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v973ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v974ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v975ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v976ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v977ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v978ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v979ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v980ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v981ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v982ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v983ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v984ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v985ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v986ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v987ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v988ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v989ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v990ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v991ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v992ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v993ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v994ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v995ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v996ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v997ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v998ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v999ffff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1000fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1001fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1002fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1003fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1004fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1005fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1006fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1007fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1008fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1009fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1010fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1011fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1012fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1013fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1014fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1015fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1016fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1017fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1018fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1019fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1020fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1021fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1022fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1023fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1024fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1025fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1026fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1027fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1028fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1029fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1030fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1031fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1032fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1033fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1034fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1035fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1036fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1037fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1038fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1039fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1040fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1041fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1042fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1043fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1044fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1045fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1046fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1047fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1048fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1049fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1050fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1051fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1052fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1053fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1054fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1055fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1056fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1057fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1058fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1059fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1060fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1061fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1062fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1063fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1064fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1065fff  1='(1) Never' 2='(2) 1-2 times' 3='(3) 3-11 times' 4='(4) 12 or more times' ;
  VALUE v1067fff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE v1068fff  99='(99) Unknown' ;
  VALUE v1075fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1076fff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE v1077fff  99='(99) Don''t know' ;
  VALUE v1084fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1085fff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE v1086fff  99='(99) Don''t know' ;
  VALUE v1093fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1094fff  0='(0) No' ;
  VALUE v1095fff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE v1096fff  99='(99) Unknown' ;
  VALUE v1098fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1099fff  1='(1) No police actn' 2='(2) Askd qstns n/acn'
                  3='(3) Tk R hme no actn' 4='(4) Invn rprt/cmplnt'
                  5='(5) Tmpr dtnd/qustnd' 6='(6) Arrstd/rlsd bail'
                  7='(7) Plcd cstdy/jaild' 9='(9) Other' ;
  VALUE v1101fff  99='(99) Unknown' ;
  VALUE v1103fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1104fff  1='(1) No police actn' 2='(2) Askd qstns n/acn'
                  3='(3) Tk R hme no actn' 4='(4) Invn rprt/cmplnt'
                  5='(5) Tmpr dtnd/qustnd' 6='(6) Arrstd/rlsd bail'
                  7='(7) Plcd cstdy/jaild' 9='(9) Other' ;
  VALUE v1105fff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE v1106fff  99='(99) Unknown' ;
  VALUE v1108fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1109fff  1='(1) No police actn' 2='(2) Askd qstns n/acn'
                  3='(3) Tk R hme no actn' 4='(4) Invn rprt/cmplnt'
                  5='(5) Tmpr dtnd/qustnd' 6='(6) Arrstd/rlsd bail'
                  7='(7) Plcd cstdy/jaild' 9='(9) Other' ;
  VALUE v1110fff  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE v1111fff  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE v1112fff  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE v1113fff  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE v1114fff  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE v1115fff  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE v1116fff  1='(1) Released w/o charge' 2='(2) Dismissed at crt'
                  3='(3) Fined/released' 4='(4) Prob/suspend sent'
                  5='(5) Short time jail' 6='(6) Long time jail' 7='(7) Serious punish'
                  8='(8) Nonser punish' 9='(9) No punish' ;
  VALUE v1117fff  1='(1) Released w/o charge' 2='(2) Dismissed at crt'
                  3='(3) Fined/released' 4='(4) Prob/suspend sent'
                  5='(5) Short time jail' 6='(6) Long time jail' 7='(7) Serious punish'
                  8='(8) Nonser punish' 9='(9) No punish' ;
  VALUE v1118fff  1='(1) Released w/o charge' 2='(2) Dismissed at crt'
                  3='(3) Fined/released' 4='(4) Prob/suspend sent'
                  5='(5) Short time jail' 6='(6) Long time jail' 7='(7) Serious punish'
                  8='(8) Nonser punish' 9='(9) No punish' ;
  VALUE v1119fff  1='(1) Released w/o charge' 2='(2) Dismissed at crt'
                  3='(3) Fined/released' 4='(4) Prob/suspend sent'
                  5='(5) Short time jail' 6='(6) Long time jail' 7='(7) Serious punish'
                  8='(8) Nonser punish' 9='(9) No punish' ;
  VALUE v1120fff  1='(1) Released w/o charge' 2='(2) Dismissed at crt'
                  3='(3) Fined/released' 4='(4) Prob/suspend sent'
                  5='(5) Short time jail' 6='(6) Long time jail' 7='(7) Serious punish'
                  8='(8) Nonser punish' 9='(9) No punish' ;
  VALUE v1121fff  1='(1) Released w/o charge' 2='(2) Dismissed at crt'
                  3='(3) Fined/released' 4='(4) Prob/suspend sent'
                  5='(5) Short time jail' 6='(6) Long time jail' 7='(7) Serious punish'
                  8='(8) Nonser punish' 9='(9) No punish' ;
  VALUE v1122fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1123fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1124fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1125fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1126fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1127fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1128fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1129fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1130fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1131fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1132fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1133fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1136fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1137fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1138fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1139fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1141fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1142fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1143fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1144fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1145fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1146fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1147fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1148fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1149fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1150fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1151fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1152fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1153fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1154fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1156fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1157fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1158fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1159fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1160fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1161fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1162fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1163fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1164fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1165fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1166fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1167fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1168fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1169fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1173fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1174fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1175fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1176fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1177fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1178fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1179fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1180fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1181fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1182fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1183fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1184fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1185fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1189fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1190fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1191fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1193fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1198fff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v1199fff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v1200fff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v1201fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1202fff  0='(0) No prob' 1='(1) Ortho prob' 2='(2) Endo prob'
                  3='(3) Ear/eye/nose/thrt' 4='(4) Heart disease' 5='(5) Blood/circ'
                  6='(6) Uro' 7='(7) Skin prob' 8='(8) Neuro' 9='(9) Pulmonary' 10='(10) Cancer'
                  11='(11) Other' ;
  VALUE v1203fff  0='(0) No prob' 1='(1) Ortho prob' 2='(2) Endo prob'
                  3='(3) Ear/eye/nose/thrt' 4='(4) Heart disease' 5='(5) Blood/circ'
                  6='(6) Uro' 7='(7) Skin probs' 8='(8) Neuro' 9='(9) Pulmonary' 10='(10) Cancer'
                  11='(11) Other' ;
  VALUE v1204fff  0='(0) No prob' 1='(1) Ortho prob' 2='(2) Endo prob'
                  3='(3) Ear/eye/nose/thrt' 4='(4) Heart disease' 5='(5) Blood/circ'
                  6='(6) Uro' 7='(7) Neuro' 9='(9) Pulmonary' 10='(10) Cancer' 11='(11) Other' ;
  VALUE v1205fff  0='(0) No prob' 1='(1) Ortho prob' 2='(2) Endo prob'
                  3='(3) Ear/eye/nose/thrt' 4='(4) Heart disease' 5='(5) Blood/circ'
                  6='(6) Uro' 7='(7) Neuro' 9='(9) Pulmonary' 10='(10) Cancer' 11='(11) Other' ;
  VALUE v1206fff  0='(0) No prob' 1='(1) Ortho prob' 2='(2) Endo prob'
                  3='(3) Ear/eye/nose/thrt' 4='(4) Heart disease' 5='(5) Blood/circ'
                  6='(6) Uro' 7='(7) Neuro' 9='(9) Pulmonary' 10='(10) Cancer' 11='(11) Other' ;
  VALUE v1207fff  0='(0) No prob' 1='(1) Ortho prob' 2='(2) Endo prob'
                  3='(3) Ear/eye/nose/thrt' 4='(4) Heart disease' 5='(5) Blood/circ'
                  6='(6) Uro' 7='(7) Neuro' 9='(9) Pulmonary' 10='(10) Cancer' 11='(11) Other' ;
  VALUE v1208fff  0='(0) No prob' 1='(1) Ortho prob' 2='(2) Endo prob'
                  3='(3) Ear/eye/nose/thrt' 4='(4) Heart disease' 5='(5) Blood/circ'
                  6='(6) Uro' 7='(7) Neuro' 9='(9) Pulmonary' 10='(10) Cancer' 11='(11) Other' ;
  VALUE v1209fff  1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor' ;
  VALUE v1210fff  1='(1) Yes' 2='(2) No' 3='(3) Male respondent' ;
  VALUE v1212fff  1='(1) Live birth' 2='(2) Abortion' 3='(3) Miscarriage' 4='(4) Stillbirth'
                  5='(5) Currently preg' 8='(8) Other' ;
  VALUE v1213fff  0='(0) No' 1='(1) Diff labor/deliv' 2='(2) C-section' 3='(3) Uro problems'
                  4='(4) Resp/card infant' 5='(5) Atopic preg' 6='(6) Miscarriage'
                  7='(7) Diff present' 8='(8) Drug addict' 9='(9) Phlebitis/hemo'
                  10='(10) Hemorrhaging del' 11='(11) Other' ;
  VALUE v1214fff  0='(0) No' 1='(1) Diff labor/deliv' 2='(2) C-section' 3='(3) Uro problems'
                  4='(4) Resp/card infant' 5='(5) Atopic preg' 6='(6) Miscarriage'
                  7='(7) Diff present' 8='(8) Drug addict' 9='(9) Phlebitis/hemo'
                  10='(10) Hemorrhaging del' 11='(11) Other' ;
  VALUE v1215fff  1='(1) Involuntary' 2='(2) Voluntary' ;
  VALUE v1217fff  1='(1) Live birth' 2='(2) Abortion' 3='(3) Miscarriage' 4='(4) Stillbirth'
                  5='(5) Currently preg' 8='(8) Other' ;
  VALUE v1218fff  0='(0) No' 1='(1) Diff labor/deliv' 2='(2) C-section' 3='(3) Uro problems'
                  4='(4) Resp/card infant' 5='(5) Atopic preg' 6='(6) Miscarriage'
                  7='(7) Diff present' 8='(8) Drug addict' 9='(9) Phlebitis/hemo'
                  10='(10) Hemorrhaging del' 11='(11) Other' ;
  VALUE v1219fff  0='(0) No' 1='(1) Diff labor/deliv' 2='(2) C-section' 3='(3) Uro problems'
                  4='(4) Resp/card infant' 5='(5) Atopic preg' 6='(6) Miscarriage'
                  7='(7) Diff present' 8='(8) Drug addict' 9='(9) Phlebitis/hemo'
                  10='(10) Hemorrhaging del' 11='(11) Other' ;
  VALUE v1220fff  1='(1) Involuntary' 2='(2) Voluntary' ;
  VALUE v1222fff  1='(1) Live birth' 2='(2) Abortion' 3='(3) Miscarriage' 4='(4) Stillbirth'
                  5='(5) Currently preg' 8='(8) Other' ;
  VALUE v1223fff  0='(0) No' 1='(1) Diff labor/deliv' 2='(2) C-section' 3='(3) Uro problems'
                  4='(4) Resp/card infant' 5='(5) Atopic preg' 6='(6) Miscarriage'
                  7='(7) Diff present' 8='(8) Drug addict' 9='(9) Phlebitis/hemo'
                  10='(10) Hemorrhaging del' 11='(11) Other' ;
  VALUE v1224fff  0='(0) No' 1='(1) Diff labor/deliv' 2='(2) C-section' 3='(3) Uro problems'
                  4='(4) Resp/card infant' 5='(5) Atopic preg' 6='(6) Miscarriage'
                  7='(7) Diff present' 8='(8) Drug addict' 9='(9) Phlebitis/hemo'
                  10='(10) Hemorrhaging del' 11='(11) Other' ;
  VALUE v1225fff  1='(1) Involuntary' 2='(2) Voluntary' ;
  VALUE v1227fff  1='(1) Live birth' 2='(2) Abortion' 3='(3) Miscarriage' 4='(4) Stillbirth'
                  5='(5) Currently preg' 8='(8) Other' ;
  VALUE v1228fff  0='(0) No' 1='(1) Diff labor/deliv' 2='(2) C-section' 3='(3) Uro problems'
                  4='(4) Resp/card infant' 5='(5) Atopic preg' 6='(6) Miscarriage'
                  7='(7) Diff present' 8='(8) Drug addict' 9='(9) Phlebitis/hemo'
                  10='(10) Hemorrhaging del' 11='(11) Other' ;
  VALUE v1229fff  1='(1) Involuntary' 2='(2) Voluntary' ;
  VALUE v1231fff  1='(1) Live birth' 2='(2) Abortion' 3='(3) Miscarriage' 4='(4) Stillbirth'
                  5='(5) Currently preg' 8='(8) Other' ;
  VALUE v1232fff  0='(0) No' 1='(1) Diff labor/deliv' 2='(2) C-section' 3='(3) Uro problems'
                  4='(4) Resp/card infant' 5='(5) Atopic preg' 6='(6) Miscarriage'
                  7='(7) Diff present' 8='(8) Drug addict' 9='(9) Phlebitis/hemo'
                  10='(10) Hemorrhaging del' 11='(11) Other' ;
  VALUE v1233fff  1='(1) Involuntary' 2='(2) Voluntary' ;
  VALUE v1234fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1235fff  0='(0) No effect' 1='(1) Hmrhg/bld dsrds' 2='(2) Hysterectomy'
                  3='(3) Infections' 4='(4) Depression' 5='(5) Guilt' 6='(6) Fatigue'
                  7='(7) Fr preg/intrcrse' 8='(8) Hsbnd/byfrd upst'
                  9='(9) Nvr gt athr abtn' 10='(10) Relieved' 11='(11) Other' ;
  VALUE v1236fff  0='(0) No effect' 1='(1) Hmrhg/bld dsrds' 2='(2) Hysterectomy'
                  3='(3) Infections' 4='(4) Depression' 5='(5) Guilt' 6='(6) Fatigue'
                  7='(7) Fr preg/intrcrse' 8='(8) Hsbnd/byfrd upst'
                  9='(9) Nvr gt athr abtn' 10='(10) Relieved' 11='(11) Other' ;
  VALUE v1237fff  0='(0) No effect' 1='(1) Hmrhg/bld dsrds' 2='(2) Hysterectomy'
                  3='(3) Infections' 4='(4) Depression' 5='(5) Guilt' 6='(6) Fatigue'
                  7='(7) Fr preg/intrcrse' 8='(8) Hsbnd/byfrd upst'
                  9='(9) Nvr gt athr abtn' 10='(10) Relieved' 11='(11) Other' ;
  VALUE v1238fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1239fff  0='(0) No effect' 1='(1) Hmrhg/bld dsrds' 2='(2) Hysterectomy'
                  3='(3) Infections' 4='(4) Depression' 5='(5) Guilt' 6='(6) Fatigue'
                  7='(7) Fr preg/intrcrse' 8='(8) Hsbnd/byfrd upst'
                  9='(9) Nvr gt athr abtn' 10='(10) Relieved' 11='(11) Other' ;
  VALUE v1240fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1241fff  0='(0) No effect' 1='(1) Hmrhg/bld dsrds' 2='(2) Hysterectomy'
                  3='(3) Infections' 4='(4) Depression' 5='(5) Guilt' 6='(6) Fatigue'
                  7='(7) Fr preg/intrcrse' 8='(8) Hsbnd/byfrd upst'
                  9='(9) Nvr gt athr abtn' 10='(10) Relieved' 11='(11) Other' ;
  VALUE v1242fff  0='(0) No effect' 1='(1) Hmrhg/bld dsrds' 2='(2) Hysterectomy'
                  3='(3) Infections' 4='(4) Depression' 5='(5) Guilt' 6='(6) Fatigue'
                  7='(7) Fr preg/intrcrse' 8='(8) Hsbnd/byfrd upst'
                  9='(9) Nvr gt athr abtn' 10='(10) Relieved' 11='(11) Other' ;
  VALUE v1243fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1244fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1245fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1246fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1247fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1248fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1249fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1250fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1251fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1252fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1253fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1254fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1255fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1256fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1257fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1258fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1259fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1260fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1261fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1262fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1263fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1264fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1265fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1266fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1267fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1268fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1269fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1270fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1271fff  1='(1) Symp not present' 5='(5) Symp present' ;
  VALUE v1272fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1273fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1274fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1280fff  1='(1) No' 5='(5) Yes' ;
  VALUE v1281fff  1='(1) No' 5='(5) Yes' ;
  VALUE v1282fff  1='(1) No' 5='(5) Yes' ;
  VALUE v1283fff  1='(1) No' 5='(5) Yes' ;
  VALUE v1285fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1286fff  2='(2) Only due to a death' 5='(5) Not due to a death' ;
  VALUE v1287fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1288fff  1='(1) Within last 2 wks' 2='(2) Within last month'
                  3='(3) Within last 6 months' 4='(4) Within last year'
                  5='(5) More than 1 year ago' ;
  VALUE v1290fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1291fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1292fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1293fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1294fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1295fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1296fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1297fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1298fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1299fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1300fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1301fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1302fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1303fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1304fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1305fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1306fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1307fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1308fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1309fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1310fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1311fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1312fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1313fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1314fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1315fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1316fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1317fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1318fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1319fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1320fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1321fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1322fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1323fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1324fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1325fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1326fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1327fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1328fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1329fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1330fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1331fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1332fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1333fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1334fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1335fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1336fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1337fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1338fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1339fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1340fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1341fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1342fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1343fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1344fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1345fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1346fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1347fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1348fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1349fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1350fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1351fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1352fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1353fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1354fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1355fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1356fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1357fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1358fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1359fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1360fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1361fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1362fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1363fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1364fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1365fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1366fff  0='(0) Not in past yr' 999='(999) Some/not past yr' ;
  VALUE v1367fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1368fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1369fff  0='(0) No prob' 1='(1) Drugs' 2='(2) Alcohol' 3='(3) Family rel'
                  4='(4) Depression' 5='(5) Sexual rel' 6='(6) Trouble w/law'
                  7='(7) Emot stress/nerve' 8='(8) Prob boy/girlfrnd'
                  9='(9) Work/school prob' 10='(10) Prob w/family'
                  11='(11) Phys health/ill' 12='(12) Financial prob'
                  13='(13) Death frnd/rel' 99='(99) Other' ;
  VALUE v1370fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1371fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1372fff  1='(1) Prvt Psych Hsp' 2='(2) VA/Univ Hosp' 3='(3) Gen Hospital'
                  4='(4) Cmmnty Mtl Hth' 5='(5) Alc Mntl Hth Ctr' 6='(6) Drug Trtmt Unt'
                  7='(7) Other' ;
  VALUE v1375fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1376fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1377fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1378fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1379fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1380fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1381fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1382fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1383fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1384fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1385fff  1='(1) Prvt Psych Hsp' 2='(2) VA/Univ Hosp' 3='(3) Gen Hospital'
                  4='(4) Cmmnty Mtl Hth' 5='(5) Alc Mntl Hth Ctr' 6='(6) Drug Trtmt Unt'
                  7='(7) Other' ;
  VALUE v1388fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1389fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1390fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1391fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1392fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1393fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1394fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1395fff  1='(1) Yes' 2='(2) No' ;
  VALUE v1396fff  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE v1397fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1398fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1399fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1400fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1401fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1402fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1403fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1404fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1405fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1406fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1407fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1408fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1409fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1410fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1411fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1412fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1413fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1414fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1415fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1416fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1417fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1418fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1419fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1420fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1421fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1422fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1423fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1424fff  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE v1425fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1433fff  1='(1) Boy/girlfriend' 2='(2) Date' 3='(3) Friend' 4='(4) Acquaintance'
                  5='(5) Stranger' 6='(6) Spouse' 7='(7) Relative' 8='(8) Other' ;
  VALUE v1434fff  1='(1) Male' 2='(2) Female' 3='(3) Both' ;
  VALUE v1435fff  1='(1) Verbal prsuasn' 2='(2) Verb thrts injy' 3='(3) Ht sp md rghnns'
                  4='(4) Phys beatg/chkg' 5='(5) Thrt to use wpn' 6='(6) Used a weapon' ;
  VALUE v1436fff  0='(0) No' ;
  VALUE v1437fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1438fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1439fff  0='(0) No' ;
  VALUE v1442fff  1='(1) Boy/girlfriend' 2='(2) Date' 3='(3) Friend' 4='(4) Acquaintance'
                  5='(5) Stranger' 6='(6) Spouse' 7='(7) Relative' 8='(8) Other' ;
  VALUE v1443fff  1='(1) Male' 2='(2) Female' 3='(3) Both' ;
  VALUE v1444fff  1='(1) Verbal prsuasn' 2='(2) Verb thrts injy' 3='(3) Ht sp md rghnns'
                  4='(4) Phys beatg/chkg' 5='(5) Thrt to use wpn' 6='(6) Used a weapon' ;
  VALUE v1446fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1447fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1450fff  1='(1) Husband/wife' 2='(2) Fiance/fiancee' 3='(3) Stdy dtg prtnr'
                  4='(4) Friend' 5='(5) Teacher' 6='(6) Csl acquntnce' 7='(7) Relative'
                  8='(8) Cmplt strnger' 9='(9) Prostitute' ;
  VALUE v1451fff  1='(1) Forced' 2='(2) Voluntary' ;
  VALUE v1452fff  1='(1) Very positive' 2='(2) Positive' 3='(3) Bth pos and neg'
                  4='(4) Nthr pos or neg' 5='(5) Negative' 6='(6) Very negative' ;
  VALUE v1453fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1455fff  1='(1) Forced' 2='(2) Voluntary' ;
  VALUE v1456fff  1='(1) Very positive' 2='(2) Positive' 3='(3) Bth pos and neg'
                  4='(4) Nthr pos or neg' 5='(5) Negative' 6='(6) Very negative' ;
  VALUE v1460fff  1='(1) Heterosexual' 2='(2) Bisexual' 3='(3) Gay' 4='(4) Uncertain' ;
  VALUE v1461fff  1='(1) Very dsstisfd' 2='(2) Smwht dsstsfd' 3='(3) Nthr stfd dssfd'
                  4='(4) Somewhat satsfd' 5='(5) Very satisfied' ;
  VALUE v1462fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v1463fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1465fff  0='(0) Not in past yr' 999='(999) Sometime/not p yr' ;
  VALUE v1466fff  0='(0) Not in past yr' 999='(999) Sometime/not p yr' ;
  VALUE v1467fff  0='(0) Not in past yr' 999='(999) Sometime/not p yr' ;
  VALUE v1468fff  0='(0) Not in past yr' 999='(999) Sometime/not p yr' ;
  VALUE v1469fff  0='(0) Not in past yr' 999='(999) Sometime/not p yr' ;
  VALUE v1470fff  0='(0) Not in past yr' 999='(999) Sometime/not p yr' ;
  VALUE v1471fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1472fff  1='(1) Drugs' ;
  VALUE v1473fff  1='(1) Sex' ;
  VALUE v1474fff  1='(1) Mental health' ;
  VALUE v1475fff  1='(1) Crim behavior' ;
  VALUE v1476fff  1='(1) Spse violence' ;
  VALUE v1479fff  1='(1) Not at all anxs' 2='(2) Somewht anxs' 3='(3) Very anxious' ;
  VALUE v1480fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1481fff  1='(1) Very low' 2='(2) Below average' 3='(3) Average'
                  4='(4) Above average' 5='(5) Very high' ;
  VALUE v1482fff  1='(1) Diffty wth lngge' ;
  VALUE v1483fff  1='(1) Diffty wth qusts' ;
  VALUE v1484fff  1='(1) Interruptions' ;
  VALUE v1485fff  1='(1) Temp breakoff' ;
  VALUE v1486fff  1='(1) Breakoff' ;
  VALUE v1487fff  1='(1) Other' ;
  VALUE v1488fff  1='(1) Relaxed' 2='(2) Tense' 3='(3) Other' ;
  VALUE v1489fff  1='(1) No' 2='(2) Yes' ;
  VALUE v1508fff  1='(1) Urban' 2='(2) Suburban' 3='(3) Rural' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=3105;
INPUT
        CASEID 3098-3105        V1 1                    V2 2
        V6 3-4                  V7 5-6                  V8 7-8
        V9 9-10                 V10 11-12               V11 13-14
        V12 15-16               V13 17-18               V14 19-20
        V15 21-22               V16 23-24               V17 25-26
        V18 27-28               V19 29-30               V20 31-32
        V21 33-34               V22 35-36               V23 37-38
        V24 39-40               V25 41-42               V26 43-44
        V27 45-46               V28 47-48               V29 49-50
        V30 51-52               V31 53-54               V32 55-56
        V33 57-58               V34 59-60               V35 61-62
        V36 63-64               V37 65-66               V38 67-68
        V39 69-70               V40 71-72               V41 73-74
        V42 75-76               V43 77-78               V44 79-80
        V45 81-82               V46 83-85               V47 86
        V48 87-90               V49 91                  V50 92-93
        V51 94-95               V52 96-97               V53 98-99
        V54 100-101             V55 102-103             V56 104-105
        V57 106-107             V58 108-109             V59 110-111
        V60 112-113             V61 114-115             V62 116-117
        V63 118-119             V64 120-121             V65 122-123
        V66 124-125             V67 126-127             V68 128-129
        V69 130-131             V70 132-133             V71 134-135
        V72 136-137             V73 138-139             V74 140-141
        V75 142-143             V76 144-145             V77 146-147
        V78 148-149             V79 150-151             V80 152-153
        V81 154-155             V82 156                 V83 157-158
        V84 159-160             V85 161-162             V86 163-164
        V87 165-166             V88 167-168             V89 169-170
        V90 171-172             V91 173-174             V92 175-176
        V93 177-178             V94 179-180             V95 181-182
        V96 183-184             V97 185-186             V98 187-188
        V99 189-190             V100 191-192            V101 193-194
        V102 195-196            V103 197-198            V104 199-200
        V105 201-202            V106 203-204            V107 205-206
        V108 207-208            V109 209-210            V110 211-212
        V111 213-214            V112 215-216            V113 217-218
        V114 219-220            V115 221-222            V116 223-224
        V117 225-226            V118 227-228            V119 229-230
        V120 231-232            V121 233-234            V122 235-236
        V123 237-238            V124 239-240            V125 241-242
        V126 243-244            V127 245-246            V128 247-248
        V129 249-250            V130 251-252            V131 253-254
        V132 255-256            V133 257-258            V134 259-260
        V135 261-262            V136 263-264            V137 265-266
        V138 267-268            V139 269-270            V140 271-272
        V141 273-274            V142 275-276            V143 277-278
        V144 279-280            V145 281-282            V146 283-284
        V147 285-286            V148 287-288            V149 289-290
        V150 291-292            V151 293-294            V152 295-296
        V153 297-298            V154 299-300            V155 301-302
        V156 303-304            V157 305-306            V158 307-308
        V159 309-310            V160 311-312            V161 313-314
        V162 315-316            V163 317-318            V164 319-320
        V165 321-322            V166 323-324            V167 325-326
        V168 327-328            V169 329-330            V170 331-332
        V171 333-334            V172 335-336            V173 337-338
        V174 339-340            V175 341-345            V176 346-347
        V177 348-349            V178 350-351            V179 352-353
        V180 354-355            V181 356-357            V182 358-359
        V183 360-361            V184 362-363            V185 364-365
        V186 366-367            V187 368-369            V188 370-371
        V189 372-373            V190 374-375            V191 376-377
        V192 378-379            V193 380-381            V194 382-383
        V195 384-385            V196 386-387            V197 388-389
        V198 390-391            V199 392-393            V200 394-395
        V201 396-397            V202 398-399            V203 400-401
        V204 402-406            V205 407-408            V206 409-410
        V207 411-412            V208 413-414            V209 415-416
        V210 417-418            V211 419-420            V212 421-422
        V213 423-424            V214 425-426            V215 427-428
        V216 429-430            V217 431-432            V218 433-434
        V219 435-436            V220 437-438            V221 439-440
        V222 441-442            V223 443-444            V224 445-446
        V225 447-448            V226 449-450            V227 451-452
        V228 453-454            V229 455-456            V230 457-458
        V231 459-460            V232 461-462            V233 463-464
        V234 465-466            V235 467-468            V236 469-470
        V237 471-472            V238 473-474            V239 475-476
        V240 477-478            V241 479-480            V242 481-482
        V243 483-484            V244 485-486            V245 487-488
        V246 489-490            V247 491-492            V248 493-494
        V249 495-496            V250 497-498            V251 499-500
        V252 501-502            V253 503-504            V254 505-506
        V255 507-508            V256 509-510            V257 511-513
        V258 514-515            V259 516-517            V260 518-519
        V261 520-521            V262 522-523            V263 524-525
        V264 526                V265 527-528            V266 529
        V267 530-531            V268 532                V269 533-534
        V270 535                V271 536-537            V272 538
        V273 539-540            V274 541                V275 542-543
        V276 544                V277 545-546            V278 547
        V279 548-549            V280 550                V281 551-552
        V282 553                V283 554-555            V284 556-557
        V285 558-559            V286 560-561            V287 562-563
        V288 564-565            V289 566-567            V290 568-569
        V291 570-571            V292 572-573            V293 574-575
        V294 576-577            V295 578-579            V296 580-581
        V297 582-583            V298 584-585            V299 586-587
        V300 588-589            V301 590-591            V302 592-593
        V303 594-595            V304 596-597            V305 598-599
        V306 600-601            V307 602-603            V308 604-605
        V309 606-607            V310 608-609            V311 610-611
        V312 612-613            V313 614-615            V314 616-617
        V315 618-619            V316 620-621            V317 622-623
        V318 624-625            V319 626-627            V320 628-629
        V321 630-631            V322 632-633            V323 634-635
        V324 636-637            V325 638-639            V326 640-641
        V327 642-643            V328 644-645            V329 646-647
        V330 648-649            V331 650-651            V332 652-653
        V333 654-655            V334 656-657            V335 658-659
        V336 660-661            V337 662-663            V338 664-665
        V339 666-667            V340 668-669            V341 670-671
        V342 672-673            V343 674-675            V344 676-677
        V345 678-679            V346 680-681            V347 682-683
        V348 684-685            V349 686-687            V350 688-689
        V351 690-691            V352 692-693            V353 694-695
        V354 696-697            V355 698-699            V356 700-701
        V357 702-703            V358 704-705            V359 706-707
        V360 708-709            V361 710-711            V362 712-713
        V363 714-715            V364 716-717            V365 718-719
        V366 720-721            V367 722-723            V368 724-725
        V369 726-727            V370 728-729            V371 730-731
        V372 732-733            V373 734-735            V374 736-737
        V375 738-739            V376 740-741            V377 742-743
        V378 744-745            V379 746-747            V380 748-749
        V381 750-751            V382 752-753            V383 754-755
        V384 756-757            V385 758-759            V386 760-761
        V387 762-763            V388 764-765            V389 766-767
        V390 768-769            V391 770-771            V392 772-773
        V393 774-775            V394 776-777            V395 778-780
        V396 781-782            V397 783-784            V398 785-786
        V399 787-789            V400 790-791            V401 792-794
        V402 795-796            V403 797-798            V404 799-800
        V405 801-802            V406 803-804            V407 805-806
        V408 807-808            V409 809-810            V410 811-812
        V411 813-815            V412 816-817            V413 818-820
        V414 821-822            V415 823-825            V416 826-827
        V417 828-830            V418 831-832            V419 833-835
        V420 836-837            V421 838-839            V422 840-841
        V423 842-843            V424 844-845            V425 846-847
        V426 848-849            V427 850-851            V428 852-853
        V429 854-855            V430 856-857            V431 858-860
        V432 861-862            V433 863-865            V434 866-867
        V435 868-870            V436 871-872            V437 873-874
        V438 875-876            V439 877-879            V440 880-881
        V441 882-884            V442 885-886            V443 887-888
        V444 889-890            V445 891-892            V446 893-894
        V447 895-897            V448 898-899            V449 900-902
        V450 903-904            V451 905-906            V452 907-908
        V453 909-910            V454 911-912            V455 913-914
        V456 915-916            V457 917-918            V458 919-920
        V459 921-922            V460 923-924            V461 925-926
        V462 927-928            V463 929-931            V464 932-933
        V465 934-935            V466 936-937            V467 938-939
        V468 940-941            V469 942-943            V470 944-945
        V471 946-948            V472 949-950            V473 951-952
        V474 953-954            V475 955-956            V476 957-958
        V477 959-960            V478 961-962            V479 963-964
        V480 965-966            V481 967-968            V482 969-970
        V483 971-972            V484 973-974            V485 975-976
        V486 977-978            V487 979-980            V488 981-982
        V489 983-984            V490 985-986            V491 987-988
        V492 989-990            V493 991-992            V494 993-994
        V495 995-996            V496 997-998            V497 999-1000
        V498 1001-1002          V499 1003-1004          V500 1005-1006
        V501 1007-1008          V502 1009-1010          V503 1011-1012
        V504 1013-1014          V505 1015-1016          V506 1017-1018
        V507 1019-1020          V508 1021-1022          V509 1023-1024
        V510 1025-1026          V511 1027-1028          V512 1029-1030
        V513 1031-1032          V514 1033-1034          V515 1035-1036
        V516 1037-1038          V517 1039-1040          V518 1041-1042
        V519 1043-1044          V520 1045-1046          V521 1047-1048
        V522 1049-1050          V523 1051-1052          V524 1053-1055
        V525 1056-1057          V526 1058-1060          V527 1061-1062
        V528 1063-1065          V529 1066-1067          V530 1068-1070
        V531 1071-1072          V532 1073-1076          V533 1077-1078
        V534 1079-1081          V535 1082-1083          V536 1084-1086
        V537 1087-1088          V538 1089-1091          V539 1092-1093
        V540 1094-1095          V541 1096-1097          V542 1098-1099
        V543 1100-1101          V544 1102-1103          V545 1104-1105
        V546 1106-1107          V547 1108-1110          V548 1111-1112
        V549 1113-1114          V550 1115-1116          V551 1117-1118
        V552 1119-1120          V553 1121-1122          V554 1123-1124
        V555 1125-1126          V556 1127-1129          V557 1130-1131
        V558 1132-1133          V559 1134-1135          V560 1136-1137
        V561 1138-1139          V562 1140-1141          V563 1142-1143
        V564 1144-1145          V565 1146-1148          V566 1149-1150
        V567 1151-1153          V568 1154-1155          V569 1156-1157
        V570 1158-1159          V571 1160-1161          V572 1162-1164
        V573 1165-1166          V574 1167-1169          V575 1170-1171
        V576 1172-1173          V577 1174-1175          V578 1176-1177
        V579 1178-1180          V580 1181-1182          V581 1183-1185
        V582 1186-1187          V583 1188-1189          V584 1190-1191
        V585 1192-1193          V586 1194-1196          V587 1197-1198
        V588 1199-1200          V589 1201-1204          V590 1205-1206
        V591 1207-1209          V592 1210-1212          V593 1213-1214
        V594 1215-1216          V595 1217-1218          V596 1219-1220
        V597 1221-1222          V598 1223-1224          V599 1225-1226
        V600 1227-1228          V601 1229-1230          V602 1231-1232
        V603 1233-1235          V604 1236-1237          V605 1238-1239
        V606 1240-1241          V607 1242-1243          V608 1244-1245
        V609 1246-1247          V610 1248-1249          V611 1250-1252
        V612 1253-1254          V613 1255-1256          V614 1257-1258
        V615 1259-1260          V616 1261-1262          V617 1263-1264
        V618 1265-1266          V619 1267-1269          V620 1270-1271
        V621 1272-1273          V622 1274-1275          V623 1276-1277
        V624 1278-1279          V625 1280-1281          V626 1282-1283
        V627 1284-1285          V628 1286-1287          V629 1288-1289
        V630 1290-1291          V631 1292-1293          V632 1294-1295
        V633 1296-1297          V634 1298-1299          V635 1300-1301
        V636 1302-1304          V637 1305-1306          V638 1307-1308
        V639 1309-1310          V640 1311-1312          V641 1313-1314
        V642 1315-1316          V643 1317-1318          V644 1319-1320
        V645 1321-1322          V646 1323-1324          V647 1325-1326
        V648 1327-1328          V649 1329-1330          V650 1331-1332
        V651 1333-1334          V652 1335-1336          V653 1337-1338
        V654 1339-1340          V655 1341-1342          V656 1343-1344
        V657 1345-1347          V658 1348-1349          V659 1350-1352
        V660 1353-1354          V661 1355-1358          V662 1359-1362
        V663 1363-1364          V664 1365-1367          V665 1368-1369
        V666 1370-1371          V667 1372-1374          V668 1375-1376
        V669 1377-1378          V670 1379-1380          V671 1381-1383
        V672 1384-1385          V673 1386-1387          V674 1388-1389
        V675 1390-1392          V676 1393-1394          V677 1395-1396
        V678 1397-1399          V679 1400-1402          V680 1403-1404
        V681 1405-1406          V682 1407-1408          V683 1409-1410
        V684 1411-1412          V685 1413-1414          V686 1415-1416
        V687 1417-1418          V688 1419-1420          V689 1421-1422
        V690 1423-1424          V691 1425-1426          V692 1427-1428
        V693 1429-1430          V694 1431-1432          V695 1433-1434
        V696 1435-1436          V697 1437-1438          V698 1439-1440
        V699 1441-1442          V700 1443-1444          V701 1445-1446
        V702 1447-1448          V703 1449-1450          V704 1451-1452
        V705 1453-1454          V706 1455-1456          V707 1457-1458
        V708 1459-1460          V709 1461-1462          V710 1463-1464
        V711 1465-1466          V712 1467-1469          V713 1470-1471
        V714 1472-1473          V715 1474-1475          V716 1476-1477
        V717 1478-1479          V718 1480-1481          V719 1482-1483
        V720 1484-1485          V721 1486-1487          V722 1488-1489
        V723 1490-1491          V724 1492-1493          V725 1494-1495
        V726 1496-1498          V727 1499-1500          V728 1501-1502
        V729 1503-1504          V730 1505-1506          V731 1507-1508
        V732 1509-1510          V733 1511-1513          V734 1514-1516
        V735 1517-1518          V736 1519-1520          V737 1521-1522
        V738 1523-1524          V739 1525-1526          V740 1527-1529
        V741 1530-1532          V742 1533-1534          V743 1535-1538
        V744 1539-1540          V745 1541-1543          V746 1544-1545
        V747 1546-1547          V748 1548-1551          V749 1552-1555
        V750 1556-1557          V751 1558-1559          V752 1560-1562
        V753 1563-1564          V754 1565-1566          V755 1567-1568
        V756 1569-1570          V757 1571-1572          V758 1573-1574
        V759 1575-1577          V760 1578-1579          V761 1580-1581
        V762 1582-1583          V763 1584-1585          V764 1586-1587
        V765 1588-1589          V766 1590-1591          V767 1592-1593
        V768 1594-1595          V769 1596-1597          V770 1598-1599
        V771 1600-1601          V772 1602-1603          V773 1604-1605
        V774 1606-1607          V775 1608-1609          V776 1610-1611
        V777 1612-1613          V778 1614-1615          V779 1616-1617
        V780 1618-1619          V781 1620-1621          V782 1622-1623
        V783 1624-1625          V784 1626-1627          V785 1628-1629
        V786 1630-1631          V787 1632-1633          V788 1634-1635
        V789 1636-1637          V790 1638-1639          V791 1640-1641
        V792 1642-1643          V793 1644-1645          V794 1646-1647
        V795 1648-1649          V796 1650-1651          V797 1652-1653
        V798 1654-1655          V799 1656-1658          V800 1659-1660
        V801 1661-1662          V802 1663-1664          V803 1665-1666
        V804 1667-1668          V805 1669-1670          V806 1671-1672
        V807 1673-1674          V808 1675-1676          V809 1677-1678
        V810 1679-1680          V811 1681-1682          V812 1683-1684
        V813 1685-1686          V814 1687-1688          V815 1689-1690
        V816 1691-1692          V817 1693-1694          V818 1695-1696
        V819 1697-1698          V820 1699-1700          V821 1701-1702
        V822 1703-1704          V823 1705-1706          V824 1707-1708
        V825 1709-1710          V826 1711-1713          V827 1714-1716
        V828 1717-1718          V829 1719-1721          V830 1722-1723
        V831 1724-1725          V832 1726-1728          V833 1729-1731
        V834 1732-1733          V835 1734-1735          V836 1736-1737
        V837 1738-1739          V838 1740-1741          V839 1742-1744
        V840 1745-1747          V841 1748-1749          V842 1750-1751
        V843 1752-1753          V844 1754-1755          V845 1756-1757
        V846 1758-1760          V847 1761-1762          V848 1763-1764
        V849 1765-1766          V850 1767-1768          V851 1769-1770
        V852 1771-1772          V853 1773-1775          V854 1776-1777
        V855 1778-1779          V856 1780-1782          V857 1783-1784
        V858 1785-1786          V859 1787-1788          V860 1789-1790
        V861 1791-1792          V862 1793-1794          V863 1795-1796
        V864 1797-1798          V865 1799-1800          V866 1801-1803
        V867 1804-1806          V868 1807-1808          V869 1809-1810
        V870 1811-1812          V871 1813-1814          V872 1815-1816
        V873 1817-1818          V874 1819-1820          V875 1821-1822
        V876 1823-1824          V877 1825-1826          V878 1827-1828
        V879 1829-1830          V880 1831-1833          V881 1834-1836
        V882 1837-1839          V883 1840-1841          V884 1842
        V885 1843-1844          V886 1845               V887 1846-1847
        V888 1848-1849          V889 1850-1851          V890 1852-1854
        V891 1855-1856          V892 1857               V893 1858-1860
        V894 1861-1862          V895 1863               V896 1864-1866
        V897 1867-1868          V898 1869               V899 1870-1872
        V900 1873-1874          V901 1875               V902 1876-1878
        V903 1879-1880          V904 1881               V905 1882-1884
        V906 1885-1886          V907 1887               V908 1888-1890
        V909 1891-1892          V910 1893               V911 1894-1896
        V912 1897-1898          V913 1899               V914 1900-1901
        V915 1902-1903          V916 1904               V917 1905-1907
        V918 1908-1909          V919 1910               V920 1911-1912
        V921 1913-1915          V922 1916-1917          V923 1918
        V924 1919-1920          V925 1921-1922          V926 1923-1924
        V927 1925-1926          V928 1927-1928          V929 1929-1930
        V930 1931-1932          V931 1933-1934          V932 1935-1936
        V933 1937-1938          V934 1939-1940          V935 1941-1942
        V936 1943-1944          V937 1945-1946          V938 1947-1948
        V939 1949-1950          V940 1951-1952          V941 1953-1954
        V942 1955-1956          V943 1957-1958          V944 1959-1960
        V945 1961-1962          V946 1963-1964          V947 1965-1966
        V948 1967-1968          V949 1969-1970          V950 1971-1972
        V951 1973               V952 1974               V953 1975
        V954 1976               V955 1977               V956 1978
        V957 1979               V958 1980               V959 1981
        V960 1982               V961 1983               V962 1984
        V963 1985-1987          V964 1988-1990          V965 1991-1993
        V966 1994-1996          V967 1997-1999          V968 2000-2002
        V969 2003-2005          V970 2006-2008          V971 2009-2011
        V972 2012-2013          V973 2014-2015          V974 2016-2017
        V975 2018-2019          V976 2020-2021          V977 2022-2023
        V978 2024-2025          V979 2026-2027          V980 2028-2029
        V981 2030-2031          V982 2032-2033          V983 2034-2035
        V984 2036-2037          V985 2038-2039          V986 2040-2041
        V987 2042-2043          V988 2044-2045          V989 2046-2047
        V990 2048-2049          V991 2050-2051          V992 2052-2053
        V993 2054-2055          V994 2056-2057          V995 2058-2059
        V996 2060-2061          V997 2062-2063          V998 2064-2065
        V999 2066-2067          V1000 2068-2069         V1001 2070-2071
        V1002 2072-2073         V1003 2074-2075         V1004 2076-2077
        V1005 2078-2079         V1006 2080-2081         V1007 2082-2083
        V1008 2084-2085         V1009 2086-2087         V1010 2088-2089
        V1011 2090-2091         V1012 2092-2093         V1013 2094-2095
        V1014 2096-2097         V1015 2098-2099         V1016 2100-2101
        V1017 2102-2103         V1018 2104-2105         V1019 2106-2107
        V1020 2108-2109         V1021 2110-2111         V1022 2112-2113
        V1023 2114-2115         V1024 2116-2117         V1025 2118-2119
        V1026 2120-2121         V1027 2122-2123         V1028 2124-2125
        V1029 2126-2127         V1030 2128-2129         V1031 2130-2131
        V1032 2132-2133         V1033 2134-2135         V1034 2136-2137
        V1035 2138-2139         V1036 2140-2141         V1037 2142-2143
        V1038 2144-2145         V1039 2146-2147         V1040 2148-2149
        V1041 2150-2151         V1042 2152-2153         V1043 2154-2155
        V1044 2156-2157         V1045 2158-2159         V1046 2160-2161
        V1047 2162-2163         V1048 2164-2165         V1049 2166-2167
        V1050 2168-2169         V1051 2170-2171         V1052 2172-2173
        V1053 2174-2175         V1054 2176-2177         V1055 2178-2179
        V1056 2180-2181         V1057 2182-2183         V1058 2184-2185
        V1059 2186-2187         V1060 2188-2189         V1061 2190-2191
        V1062 2192-2193         V1063 2194-2195         V1064 2196-2197
        V1065 2198-2199         V1066 2200-2201         V1067 2202-2203
        V1068 2204-2205         V1069 2206-2207         V1070 2208-2209
        V1071 2210-2211         V1072 2212-2213         V1073 2214-2215
        V1074 2216-2217         V1075 2218-2219         V1076 2220-2221
        V1077 2222-2223         V1078 2224-2225         V1079 2226-2227
        V1080 2228-2229         V1081 2230-2231         V1082 2232-2233
        V1083 2234-2235         V1084 2236-2237         V1085 2238-2239
        V1086 2240-2241         V1087 2242-2243         V1088 2244-2245
        V1089 2246-2247         V1090 2248-2249         V1091 2250-2251
        V1092 2252-2253         V1093 2254-2255         V1094 2256-2257
        V1095 2258-2259         V1096 2260-2261         V1097 2262-2263
        V1098 2264-2265         V1099 2266-2267         V1100 2268-2269
        V1101 2270-2271         V1102 2272-2273         V1103 2274-2275
        V1104 2276-2277         V1105 2278-2279         V1106 2280-2281
        V1107 2282-2283         V1108 2284-2285         V1109 2286-2287
        V1110 2288-2289         V1111 2290-2291         V1112 2292-2293
        V1113 2294-2295         V1114 2296-2297         V1115 2298-2299
        V1116 2300-2301         V1117 2302-2303         V1118 2304-2305
        V1119 2306-2307         V1120 2308-2309         V1121 2310-2311
        V1122 2312-2313         V1123 2314-2315         V1124 2316-2317
        V1125 2318-2319         V1126 2320-2321         V1127 2322-2323
        V1128 2324-2325         V1129 2326-2327         V1130 2328-2329
        V1131 2330-2331         V1132 2332-2333         V1133 2334-2335
        V1134 2336-2337         V1135 2338-2339         V1136 2340-2341
        V1137 2342-2343         V1138 2344-2345         V1139 2346-2347
        V1140 2348-2350         V1141 2351-2352         V1142 2353-2354
        V1143 2355-2356         V1144 2357-2358         V1145 2359-2360
        V1146 2361-2362         V1147 2363-2364         V1148 2365-2366
        V1149 2367-2368         V1150 2369-2370         V1151 2371-2372
        V1152 2373-2374         V1153 2375-2376         V1154 2377-2378
        V1155 2379-2380         V1156 2381-2382         V1157 2383-2384
        V1158 2385-2386         V1159 2387-2388         V1160 2389-2390
        V1161 2391-2392         V1162 2393-2394         V1163 2395-2396
        V1164 2397-2398         V1165 2399-2400         V1166 2401-2402
        V1167 2403-2404         V1168 2405-2406         V1169 2407-2408
        V1170 2409-2410         V1171 2411-2412         V1172 2413-2414
        V1173 2415-2416         V1174 2417-2418         V1175 2419-2420
        V1176 2421-2422         V1177 2423-2424         V1178 2425-2426
        V1179 2427-2428         V1180 2429-2430         V1181 2431-2432
        V1182 2433-2434         V1183 2435-2436         V1184 2437-2438
        V1185 2439-2440         V1186 2441-2442         V1187 2443-2444
        V1188 2445-2446         V1189 2447-2448         V1190 2449-2450
        V1191 2451-2452         V1192 2453-2454         V1193 2455-2456
        V1194 2457-2458         V1195 2459-2461         V1196 2462-2464
        V1197 2465-2466         V1198 2467-2468         V1199 2469-2470
        V1200 2471-2472         V1201 2473-2474         V1202 2475-2476
        V1203 2477-2478         V1204 2479-2480         V1205 2481-2482
        V1206 2483-2484         V1207 2485-2486         V1208 2487-2488
        V1209 2489-2490         V1210 2491              V1211 2492-2493
        V1212 2494-2495         V1213 2496-2497         V1214 2498-2499
        V1215 2500-2501         V1216 2502-2503         V1217 2504-2505
        V1218 2506-2507         V1219 2508-2509         V1220 2510-2511
        V1221 2512-2513         V1222 2514-2515         V1223 2516-2517
        V1224 2518-2519         V1225 2520-2521         V1226 2522-2523
        V1227 2524-2525         V1228 2526-2527         V1229 2528-2529
        V1230 2530-2531         V1231 2532-2533         V1232 2534-2535
        V1233 2536-2537         V1234 2538-2539         V1235 2540-2541
        V1236 2542-2543         V1237 2544-2545         V1238 2546-2547
        V1239 2548-2549         V1240 2550-2551         V1241 2552-2553
        V1242 2554-2555         V1243 2556-2557         V1244 2558-2559
        V1245 2560-2561         V1246 2562-2563         V1247 2564-2565
        V1248 2566-2567         V1249 2568-2569         V1250 2570-2571
        V1251 2572-2573         V1252 2574-2575         V1253 2576-2577
        V1254 2578-2579         V1255 2580-2581         V1256 2582-2583
        V1257 2584-2585         V1258 2586-2587         V1259 2588-2589
        V1260 2590-2591         V1261 2592-2593         V1262 2594-2595
        V1263 2596-2597         V1264 2598-2599         V1265 2600-2601
        V1266 2602-2603         V1267 2604-2605         V1268 2606-2607
        V1269 2608-2609         V1270 2610-2611         V1271 2612-2613
        V1272 2614-2615         V1273 2616-2617         V1274 2618-2619
        V1275 2620-2621         V1276 2622-2623         V1277 2624-2625
        V1278 2626-2627         V1279 2628-2629         V1280 2630-2631
        V1281 2632-2633         V1282 2634-2635         V1283 2636-2637
        V1284 2638-2639         V1285 2640-2641         V1286 2642-2643
        V1287 2644-2645         V1288 2646-2647         V1289 2648-2649
        V1290 2650-2651         V1291 2652-2654         V1292 2655-2656
        V1293 2657-2658         V1294 2659-2660         V1295 2661-2662
        V1296 2663-2665         V1297 2666-2667         V1298 2668-2669
        V1299 2670-2671         V1300 2672-2673         V1301 2674-2676
        V1302 2677-2678         V1303 2679-2680         V1304 2681-2682
        V1305 2683-2684         V1306 2685-2687         V1307 2688-2689
        V1308 2690-2691         V1309 2692-2693         V1310 2694-2695
        V1311 2696-2698         V1312 2699-2700         V1313 2701-2702
        V1314 2703-2704         V1315 2705-2706         V1316 2707-2709
        V1317 2710-2711         V1318 2712-2713         V1319 2714-2715
        V1320 2716-2717         V1321 2718-2720         V1322 2721-2722
        V1323 2723-2724         V1324 2725-2726         V1325 2727-2728
        V1326 2729-2731         V1327 2732-2733         V1328 2734-2735
        V1329 2736-2737         V1330 2738-2739         V1331 2740-2742
        V1332 2743-2744         V1333 2745-2746         V1334 2747-2748
        V1335 2749-2750         V1336 2751-2753         V1337 2754-2755
        V1338 2756-2757         V1339 2758-2759         V1340 2760-2761
        V1341 2762-2764         V1342 2765-2766         V1343 2767-2768
        V1344 2769-2770         V1345 2771-2772         V1346 2773-2775
        V1347 2776-2777         V1348 2778-2779         V1349 2780-2781
        V1350 2782-2783         V1351 2784-2786         V1352 2787-2788
        V1353 2789-2790         V1354 2791-2792         V1355 2793-2794
        V1356 2795-2797         V1357 2798-2799         V1358 2800-2801
        V1359 2802-2803         V1360 2804-2805         V1361 2806-2807
        V1362 2808-2809         V1363 2810-2811         V1364 2812-2813
        V1365 2814-2815         V1366 2816-2818         V1367 2819-2820
        V1368 2821-2822         V1369 2823-2824         V1370 2825-2826
        V1371 2827-2828         V1372 2829-2830         V1373 2831-2832
        V1374 2833-2834         V1375 2835              V1376 2836
        V1377 2837              V1378 2838              V1379 2839
        V1380 2840              V1381 2841              V1382 2842
        V1383 2843-2844         V1384 2845-2846         V1385 2847-2848
        V1386 2849-2850         V1387 2851-2852         V1388 2853
        V1389 2854              V1390 2855              V1391 2856
        V1392 2857              V1393 2858              V1394 2859
        V1395 2860              V1396 2861-2862         V1397 2863-2864
        V1398 2865-2866         V1399 2867-2868         V1400 2869-2870
        V1401 2871-2872         V1402 2873-2874         V1403 2875-2876
        V1404 2877-2878         V1405 2879-2880         V1406 2881-2882
        V1407 2883-2884         V1408 2885-2886         V1409 2887-2888
        V1410 2889-2890         V1411 2891-2892         V1412 2893-2894
        V1413 2895-2896         V1414 2897-2898         V1415 2899-2900
        V1416 2901-2902         V1417 2903-2904         V1418 2905-2906
        V1419 2907-2908         V1420 2909-2910         V1421 2911-2912
        V1422 2913-2914         V1423 2915-2916         V1424 2917-2918
        V1425 2919-2920         V1426 2921-2923         V1427 2924-2925
        V1428 2926-2928         V1429 2929-2930         V1430 2931-2933
        V1431 2934-2935         V1432 2936-2937         V1433 2938-2939
        V1434 2940-2941         V1435 2942-2943         V1436 2944-2945
        V1437 2946-2947         V1438 2948-2949         V1439 2950-2952
        V1440 2953-2954         V1441 2955-2956         V1442 2957-2958
        V1443 2959-2960         V1444 2961-2962         V1445 2963-2964
        V1446 2965-2966         V1447 2967-2968         V1448 2969-2970
        V1449 2971-2972         V1450 2973-2974         V1451 2975-2976
        V1452 2977-2978         V1453 2979-2980         V1454 2981-2982
        V1455 2983-2984         V1456 2985-2986         V1457 2987-2989
        V1458 2990-2991         V1459 2992-2993         V1460 2994-2995
        V1461 2996-2997         V1462 2998-2999         V1463 3000-3001
        V1464 3002-3003         V1465 3004-3006         V1466 3007-3008
        V1467 3009-3011         V1468 3012-3014         V1469 3015-3016
        V1470 3017-3019         V1471 3020-3021         V1472 3022-3023
        V1473 3024-3025         V1474 3026-3027         V1475 3028-3029
        V1476 3030-3031         V1477 3032-3034         V1478 3035-3037
        V1479 3038-3039         V1480 3040-3041         V1481 3042-3043
        V1482 3044-3045         V1483 3046-3047         V1484 3048-3049
        V1485 3050-3051         V1486 3052-3053         V1487 3054-3055
        V1488 3056-3057         V1489 3058-3059         V1490 3060-3061
        V1491 3062-3063         V1492 3064-3065         V1493 3066-3067
        V1494 3068-3069         V1495 3070-3071         V1496 3072-3073
        V1497 3074-3075         V1498 3076-3077         V1499 3078-3079
        V1500 3080-3081         V1501 3082-3083         V1502 3084-3085
        V1503 3086-3087         V1504 3088-3089         V1505 3090-3091
        V1506 3092-3093         V1507 3094-3095         V1508 3096-3097
        ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   V1      = 'Y6-1:SEX'
   V2      = 'Y6-2:ETHNICITY'
   V6      = 'Y6-6:AGE'
   V7      = 'Y6-7:MARITAL STATUS'
   V8      = 'Y6-8:DATE OF 1ST MARRIAGE-MONTH'
   V9      = 'Y6-9:DATE OF 1ST MARRIAGE-YEAR'
   V10     = 'Y6-10:MARRIED MORE THAN ONCE'
   V11     = 'Y6-11:DATE OF OTHER MARRIAGE A-MONTH'
   V12     = 'Y6-12:DATE OF OTHER MARRIAGE A-YEAR'
   V13     = 'Y6-13:DATE OF OTHER MARRIAGE B-MONTH'
   V14     = 'Y6-14:DATE OF OTHER MARRIAGE B-YEAR'
   V15     = 'Y6-15:MARRIED FOR ANY PART OF 1981'
   V16     = 'Y6-16:MARRIED FOR ANY PART OF 1982'
   V17     = 'Y6-17:MARRIED FOR ANY PART OF 1983'
   V18     = 'Y6-18:DIVORCED ANYTIME DURING 1981'
   V19     = 'Y6-19:DIVORCED ANYTIME DURING 1982'
   V20     = 'Y6-20:DIVORCED ANYTIME DURING 1983'
   V21     = 'Y6-21:EVENTS 81/82/83-SERIOUS ACCIDENT'
   V22     = 'Y6-22:SERIOUS ACCIDENT-MONTH'
   V23     = 'Y6-23:SERIOUS ACCIDENT-YEAR'
   V24     = 'Y6-24:EVENTS 81/82/83-SERIOUS ILLNESS'
   V25     = 'Y6-25:SERIOUS ILLNESS-MONTH'
   V26     = 'Y6-26:SERIOUS ILLNESS-YEAR'
   V27     = 'Y6-27:SPOUSE EVENT 81/82/83-SER ACC'
   V28     = 'Y6-28:SPOUSE SERIOUS ACCIDENT-MO'
   V29     = 'Y6-29:SPOUSE SERIOUS ACCIDENT-YR'
   V30     = 'Y6-30:SPOUSE EVENT 81/82/83-SER ILL'
   V31     = 'Y6-31:SPOUSE SERIOUS ILLNESS-MO'
   V32     = 'Y6-32:SPOUSE SERIOUS ILLNESS-YR'
   V33     = 'Y6-33:SPOUSE EVENT 81/82/83-UNEMPLOYED'
   V34     = 'Y6-34:SPOUSE UNEMPLOYED 1981-MOS'
   V35     = 'Y6-35:SPOUSE UNEMPLOYED 1982-MOS'
   V36     = 'Y6-36:SPOUSE UNEMPLOYED 1983-MOS'
   V37     = 'Y6-37:EVENTS PARENTS DIVORCE-1981'
   V38     = 'Y6-38:EVENTS PARENTS DIVORCE-1982'
   V39     = 'Y6-39:EVENTS PARENTS DIVORCE-1983'
   V40     = 'Y6-40:EVENTS PARENTS SEPARATION-1981'
   V41     = 'Y6-41:EVENTS PARENTS SEPARATION-1982'
   V42     = 'Y6-42:EVENTS PARENTS SEPARATION-1983'
   V43     = 'Y6-43:EVENTS PARENTS REMARRIAGE-1981'
   V44     = 'Y6-44:EVENTS PARENTS REMARRIAGE-1982'
   V45     = 'Y6-45:EVENTS PARENTS REMARRIAGE-1983'
   V46     = 'DATA SET NUMBER'
   V47     = 'FUNDING AGENCIES'
   V48     = 'HOUSEHOLD IDENTIFICATION'
   V49     = 'REPONDENT IDENTIFICATION'
   V50     = 'Y6-46:EVENTS PARENTS DEATH-1981'
   V51     = 'Y6-47:EVENTS PARENTS DEATH-1982'
   V52     = 'Y6-48:EVENTS PARENTS DEATH-1983'
   V53     = 'Y6-49:EVENT PARENT SER ACCIDENT-1981'
   V54     = 'Y6-50:EVENT PARENT SER ACCIDENT-1982'
   V55     = 'Y6-51:EVENT PARENT SER ACCIDENT-1983'
   V56     = 'Y6-52:EVENT PARENT SER ILLNESS-1981'
   V57     = 'Y6-53:EVENT PARENT SER ILLNESS-1982'
   V58     = 'Y6-54:EVENT PARENT SER ILLNESS-1983'
   V59     = 'Y6-55:EVENT PAR FATHER LOST JOB-1981'
   V60     = 'Y6-56:EVENT PAR FATHER LOST JOB-1982'
   V61     = 'Y6-57:EVENT PAR FATHER LOST JOB-1983'
   V62     = 'Y6-58:EVENT PAR MOTHER LOST JOB-1981'
   V63     = 'Y6-59:EVENT PAR MOTHER LOST JOB-1982'
   V64     = 'Y6-60:EVENT PAR MOTHER LOST JOB-1983'
   V65     = 'Y6-61:WITH WHOM LIVING'
   V66     = 'Y6-62:NEIGH PROB-HIGH UNEMPLOYMENT'
   V67     = 'Y6-63:NEIGH PROB-RACIAL CONFLICT'
   V68     = 'Y6-64:NEIGH PROB-VANDALISM'
   V69     = 'Y6-65:NEIGH PROB-LAWLESSNESS'
   V70     = 'Y6-66:NEIGH PROB-WINOS AND JUNKIES'
   V71     = 'Y6-67:NEIGH PROB-PROSTITUTION'
   V72     = 'Y6-68:NEIGH PROB-TRAFFIC'
   V73     = 'Y6-69:NEIGH PROB-ABANDONED HOUSES'
   V74     = 'Y6-70:NEIGH PROB-SEX ASSAULTS/RAPES'
   V75     = 'Y6-71:NEIGH PROB-BURGLARIES/THEFTS'
   V76     = 'Y6-72:NEIGH PROB-GAMBLING'
   V77     = 'Y6-73:NEIGH PROB-RUN DOWN BUILDINGS'
   V78     = 'Y6-74:NEIGH PROB-ORGANIZED CRIME'
   V79     = 'Y6-75:NEIGH PROB-ASSAULTS/MUGGINGS'
   V80     = 'Y6-76:NEIGH PROB-DELINQUENT GANGS'
   V81     = 'Y6-77:PARTICULAR GROUP OF FRIENDS'
   V82     = 'Y6-78:ANY CLOSE FRIENDS'
   V83     = 'Y6-79:HOW IMPORTANT TO HAVE FRIENDS'
   V84     = 'Y6-80:STRESS FROM NOT HAVING FRIENDS'
   V85     = 'Y6-81:AFT/WK SPENT W/FRIENDS'
   V86     = 'Y6-82:EVE/WKDAY SPENT W/FRIENDS'
   V87     = 'Y6-83:TIME SPENT W/FRIENDS ON WKENDS'
   V88     = 'Y6-84:HRS PER WK SPENT W/FRIENDS'
   V89     = 'Y6-85:FRIENDS'' INFLUENCE'
   V90     = 'Y6-86:WANT TO BE LIKE CLOSEST FRIENDS'
   V91     = 'Y6-87:HOW IMP WAS IT TO HAVE FRIENDS'
   V92     = 'Y6-88:HOW SATISFIED W/GROUP OF FRIENDS'
   V93     = 'Y6-89:INTEREST/ACTIVITY SHARED W/FRIEND'
   V94     = 'Y6-90:STRESS/PRESSURE W/FRIENDS'
   V95     = 'Y6-91:WARMTH/AFFECTION FROM FRIENDS'
   V96     = 'Y6-92:SUPPORT/ENCOURAGE FROM FRIENDS'
   V97     = 'Y6-93:LOYALTY FOR ONE ANOTHER'
   V98     = 'Y6-94:RESP IN BUSINESS/VOC SCHOOL'
   V99     = 'Y6-95:ATTEND ACADEMIC SCHOOL PROGRAM'
   V100    = 'Y6-96:HIGHEST GRADE COMPLETED'
   V101    = 'Y6-97:LAST YEAR IN SCHOOL'
   V102    = 'Y6-98:SATISFIED W/EDUCATION EXPERIENCE'
   V103    = 'Y6-99:IMP PAST EDUCATION EXPERIENCE'
   V104    = 'Y6-100:STRESS/PRESSURE FROM SIG OTHERS'
   V105    = 'Y6-101:GRADE IN SCHOOL'
   V106    = 'Y6-102:IN SCHOOL DURING SPRING 1983'
   V107    = 'Y6-103:WHAT GRADE'
   V108    = 'Y6-104:HIGHEST GRADE COMPLETED'
   V109    = 'Y6-105:GRADE POINT AVERAGE'
   V110    = 'Y6-106:AFT/SCHOOL WK SPENT STUDYING'
   V111    = 'Y6-107:EVE/SCHOOL WK SPENT STUDYING'
   V112    = 'Y6-108:TIME SPENT STUDYING ON WKENDS'
   V113    = 'Y6-109:HRS PER WK SPENT STUDYING'
   V114    = 'Y6-110:HOW IMP SCHOOL/COLLEGE WORK'
   V115    = 'Y6-111:SATISFIED W/EDUCATION EXPERIENCE'
   V116    = 'Y6-112:STRESS/PRESSURE IN SCHOOL/COLLEGE'
   V117    = 'Y6-113:ANY JOBS IN THE PAST YEAR'
   V118    = 'Y6-114:LOOKED COULDN''T FIND JOB IN 1983'
   V119    = 'Y6-115:LACKED NECESSARY SKILLS'
   V120    = 'Y6-116:LACKED EXPERIENCE'
   V121    = 'Y6-117:LACKED EDUCATIONAL REQUIREMENTS'
   V122    = 'Y6-118:RACIAL DISCRIMINATION'
   V123    = 'Y6-119:SEXUAL DISCRIMINATION'
   V124    = 'Y6-120:JOB DIDN''T PAY ENOUGH'
   V125    = 'Y6-121:NO JOBS AVAILABLE'
   V126    = 'Y6-122:PRISON RECORD'
   V127    = 'Y6-123:TRANSPORTATION PROBLEMS'
   V128    = 'Y6-124:TOO YOUNG'
   V129    = 'Y6-125:TIMING PROBLEMS'
   V130    = 'Y6-126:OTHER'
   V131    = 'Y6-127:RECEIVE WELFARE/PUBLIC ASSISTANCE'
   V132    = 'Y6-128:HOW IMPORTANT TO HAVE A JOB'
   V133    = 'Y6-129:HOW MUCH STRESS/PRESSURE SIG OTH'
   V134    = 'Y6-130:TOTAL NO. JOBS REPORTED FOR 1983'
   V135    = 'Y6-131:HIGHEST HOURLY WAGE IN 1983'
   V136    = 'Y6-132:HOLLINGSHEAD CODE MAJOR JOB 1983'
   V137    = 'Y6-133:DUNCAN SOCIOECONOMIC INDEX 1983'
   V138    = 'Y6-134:HOW IMPORTANT WAS MAJOR JOB'
   V139    = 'Y6-135:HOW SATISFIED WITH MAJOR JOB'
   V140    = 'Y6-136:HOW MUCH PRESSURE/STRESS AT WORK'
   V141    = 'Y6-137:LOOKED COULDN''T FIND JOB IN 1983'
   V142    = 'Y6-138:LACKED NECESSARY SKILLS'
   V143    = 'Y6-139:LACKED EXPERIENCE'
   V144    = 'Y6-140:LACKED EDUCATIONAL REQUIREMENTS'
   V145    = 'Y6-141:RACIAL DISCRIMINATION'
   V146    = 'Y6-142:SEXUAL DISCRIMINATION'
   V147    = 'Y6-143:JOB DIDN''T PAY ENOUGH'
   V148    = 'Y6-144:NO JOBS AVAILABLE'
   V149    = 'Y6-145:PRISON RECORD'
   V150    = 'Y6-146:TRANSPORTATION PROBLEMS'
   V151    = 'Y6-147:TOO YOUNG'
   V152    = 'Y6-148:TIMING PROBLEMS'
   V153    = 'Y6-149:OTHER'
   V154    = 'Y6-150:WELFARE/PUBLIC ASSISTANCE'
   V155    = 'Y6-151:BEEN FIRED/LAID OFF PAST YEAR'
   V156    = 'Y6-152:REDUCTION IN FORCE'
   V157    = 'Y6-153:LOW SENIORITY'
   V158    = 'Y6-154:FOR VIOLATION OF COMPANY RULES'
   V159    = 'Y6-155:RACIAL DISCRIMINATION'
   V160    = 'Y6-156:SEXUAL DISCRIMINATION'
   V161    = 'Y6-157:LACK OF SKILLS FOR THE JOB'
   V162    = 'Y6-158:PERSONALITY CONFLICT'
   V163    = 'Y6-159:USING ALCOHOL/DRUGS ON THE JOB'
   V164    = 'Y6-160:USING ALCOHOL/DRUGS OFF THE JOB'
   V165    = 'Y6-161:THEFT OF COMPANY CASH/PROPERTY'
   V166    = 'Y6-162:SEXUAL HARRASSMENT'
   V167    = 'Y6-163:WAS TERMINATION JUSTIFIED'
   V168    = 'Y6-164:INTERPERSONAL SKILLS'
   V169    = 'Y6-165:JOB SKILLS'
   V170    = 'Y6-166:LEVEL OF EDUCATIONAL ACHIEVEMENT'
   V171    = 'Y6-167:AMOUNT OF JOB EXPERIENCE'
   V172    = 'Y6-168:SEXUAL DISCRIMINATION'
   V173    = 'Y6-169:RACIAL DISCRIMINATION'
   V174    = 'Y6-170:APPEARANCE'
   V175    = 'Y6-171:AMOUNT INCOME OTHER THAN JOB EARN'
   V176    = 'Y6-172:EMPLOYED DURING 1982'
   V177    = 'Y6-173:NUMBER OF JOBS IN 1982'
   V178    = 'Y6-174:HOLLINGSHEAD CODE MAJOR JOB 1982'
   V179    = 'Y6-175:DUNCAN SOCIOECONOMIC INDEX 1982'
   V180    = 'Y6-176:HIGHEST HOURLY WAGE IN 1982'
   V181    = 'Y6-177:EMPLOYED DURING 1981'
   V182    = 'Y6-178:NUMBER OF JOBS IN 1981'
   V183    = 'Y6-179:HOLLINGSHEAD CODE MAJOR JOB 1981'
   V184    = 'Y6-180:DUNCAN SOCIOECONOMIC INDEX 1981'
   V185    = 'Y6-181:HIGHEST HOURLY WAGE IN 1981'
   V186    = 'Y6-182:DURING 1983 MOST RECENT PARTNER'
   V187    = 'Y6-183:MONTHS LIVED WITH PARTNER'
   V188    = 'Y6-184:HOW IMPORTANT ACTIVIT W/PARTNER'
   V189    = 'Y6-185:PARTNER''S INFLUENCE'
   V190    = 'Y6-186:WANT TO BE LIKE PARTNER'
   V191    = 'Y6-187:SATISFIED W/RELATION W/PARTNER'
   V192    = 'Y6-188:INTEREST/ACTIVIT SHARED W/PARTNER'
   V193    = 'Y6-189:HOW MUCH WARMTH/AFF FROM PARTNER'
   V194    = 'Y6-190:HOW SATISFIED W/SEXUAL RELATIONS'
   V195    = 'Y6-191:HOW MUCH SUPP/ENCOURAGE F/PARTNER'
   V196    = 'Y6-192:HOW MUCH LOYALTY BETWN YOU/PART'
   V197    = 'Y6-193:HOW MUCH STRESS/PRESS IN RELATION'
   V198    = 'Y6-194:PARTNER TRY INFLUENCE YOU WRONG'
   V199    = 'Y6-195:PARTNER EMPLOYED DURING 1983'
   V200    = 'Y6-196:NO. JOBS PARTNER HAD IN 1983'
   V201    = 'Y6-197:HOLLINGSHEAD CODE FOR MAJOR JOB'
   V202    = 'Y6-198:DUNCAN SOCIOECONOMIC INDEX'
   V203    = 'Y6-199:HIGHEST GRADE PARTNER COMPLETED'
   V204    = 'Y6-200:PARTNER''S TOTAL INCOME IN 1983'
   V205    = 'Y6-201:FREQ PARTICIPATION FAM ACTIVITY'
   V206    = 'Y6-202:NO. MOS LIVED W/FAMILY'
   V207    = 'Y6-203:FREQ CONTACT W/FAMILY'
   V208    = 'Y6-204:PARENTS'' INFLUENCE'
   V209    = 'Y6-205:IMPORTANCE FAMILY ACTIVITIES'
   V210    = 'Y6-206:HOW SATISFIED W/REL W/PARENTS'
   V211    = 'Y6-207:HOW MUCH STRESS/PRESS REL PARENTS'
   V212    = 'Y6-208:FREQ PARTICIPATION PART FAM ACTIV'
   V213    = 'Y6-209:NO. MOS LIVED W/PARTNER''S FAMILY'
   V214    = 'Y6-210:FREQ CONTACT W/PARTNER''S FAMILY'
   V215    = 'Y6-211:PARTNER''S PARENTS'' INFLUENCE'
   V216    = 'Y6-212:IMPORTANCE PARTNER''S FAM ACTIVITY'
   V217    = 'Y6-213:STRESS/PRESS REL W/PART PAR'
   V218    = 'Y6-214:HOW SATISFIED W/REL W/'
   V219    = 'Y6-215:AFT/SCHOOL WK SPENT W/FAMILY'
   V220    = 'Y6-216:EVE/SCHOOL WK SPENT W/FAMILY'
   V221    = 'Y6-217:TIME WKNDS SPENT W/FAMILY'
   V222    = 'Y6-218:FREQ PARTICIPATION FAM ACTIV'
   V223    = 'Y6-219:NO. MOS LIVED W/FAMILY'
   V224    = 'Y6-220:FREQ OF CONTACT W/FAMILY'
   V225    = 'Y6-221:PARENTS'' INFLUENCE'
   V226    = 'Y6-222:IMPORTANCE OF FAMILY ACTIVITIES'
   V227    = 'Y6-223:HOW SATISFIED W/REL W/PARENTS'
   V228    = 'Y6-224:HOW MUCH WARMTH/AFF FROM PARENTS'
   V229    = 'Y6-225:HOW MUCH SUPPORT/ENCOURAGE F/PAR'
   V230    = 'Y6-226:HOW MUCH STRESS/PRESS REL W/PAR'
   V231    = 'Y6-227:HAVE ANY CHILDREN'
   V232    = 'Y6-228:OLDEST CHILD-BIRTHDATE MO'
   V233    = 'Y6-229:OLDEST CHILD-BIRTHDATE YR'
   V234    = 'Y6-230:OLDEST CHILD-SEX'
   V235    = 'Y6-231:OLDEST CHILD-LIVING W/RESP'
   V236    = 'Y6-232:OLDEST CHILD-BIOLOGICAL'
   V237    = 'Y6-233:NEXT OLDEST CHILD-BIRTHDATE MO'
   V238    = 'Y6-234:NEXT OLDEST CHILD-BIRTHDATE YR'
   V239    = 'Y6-235:NEXT OLDEST CHILD-SEX'
   V240    = 'Y6-236:NEXT OLDEST CHILD-LIVING W/RESP'
   V241    = 'Y6-237:NEXT OLDEST CHILD-BIOLOGICAL'
   V242    = 'Y6-238:NEXT OLDEST CHILD-BIRTHDATE MO'
   V243    = 'Y6-239:NEXT OLDEST CHILD-BIRTHDATE YR'
   V244    = 'Y6-240:NEXT OLDEST CHILD-SEX'
   V245    = 'Y6-241:NEXT OLDEST CHILD-LIVING W/RESP'
   V246    = 'Y6-242:NEXT OLDEST CHILD-BIOLOGICAL'
   V247    = 'Y6-243:NEXT OLDEST CHILD-BIRTHDATE MO'
   V248    = 'Y6-244:NEXT OLDEST CHILD-BIRTHDATE YR'
   V249    = 'Y6-245:NEXT OLDEST CHILD-SEX'
   V250    = 'Y6-246:NEXT OLDEST CHILD-LIVING W/RESP'
   V251    = 'Y6-247:NEXT OLDEST CHILD-BIOLOGICAL'
   V252    = 'Y6-248:NEXT OLDEST CHILD-BIRTHDATE MO'
   V253    = 'Y6-249:NEXT OLDEST CHILD-BIRTHDATE YR'
   V254    = 'Y6-250:NEXT OLDEST CHILD-SEX'
   V255    = 'Y6-251:NEXT OLDEST CHILD-LIVING W/RESP'
   V256    = 'Y6-252:NEXT OLDEST CHILD-BIOLOGICAL'
   V257    = 'Y6-253:HOW MUCH TIME SPENT W/CHILDREN'
   V258    = 'Y6-254:ENJOYED BEING W/CHILDREN'
   V259    = 'Y6-255:HOW SATISFIED W/RELATIONSHIP'
   V260    = 'Y6-256:STRESS/PRESS IN REL W/CHILD'
   V261    = 'Y6-257:ATTENDANCE AT RELIGIOUS SERVICES'
   V262    = 'Y6-258:IMPORTANCE OF RELIGION'
   V263    = 'Y6-259:SUCCESS IN WORK-HOW IMPORTANT'
   V264    = 'Y6-260:SUCCESS IN WORK-HOW DOING'
   V265    = 'Y6-261:HIGH GPA-HOW IMPORTANT'
   V266    = 'Y6-262:HIGH GPA-HOW DOING'
   V267    = 'Y6-263:ABILITIES IN WORK-HOW IMPORTANT'
   V268    = 'Y6-264:ABILITIES IN WORK-HOW DOING'
   V269    = 'Y6-265:GET AHEAD IN WORK-HOW IMPORTANT'
   V270    = 'Y6-266:GET AHEAD IN WORK-HOW DOING'
   V271    = 'Y6-267:HAVE GOOD JOB-HOW IMPORTANT'
   V272    = 'Y6-268:HAVE GOOD JOB-HOW DOING'
   V273    = 'Y6-269:GRAD FROM COLLEGE-HOW IMPORTANT'
   V274    = 'Y6-270:GRAD FROM COLLEGE-HOW DOING'
   V275    = 'Y6-271:GET MARRIED-HOW IMPORTANT'
   V276    = 'Y6-272:GET MARRIED-HOW DOING'
   V277    = 'Y6-273:HAVE LONG TERM REL-HOW IMPORTANT'
   V278    = 'Y6-274:HAVE LONG TERM REL-HOW DOING'
   V279    = 'Y6-275:HAVE CHILDREN-HOW IMPORTANT'
   V280    = 'Y6-276:HAVE CHILDREN-HOW DOING'
   V281    = 'Y6-277:EARN $20K ANNUAL-HOW IMPORTANT'
   V282    = 'Y6-278:EARN $20K ANNUAL-HOW DOING'
   V283    = 'Y6-279:CAN SUCCEED AT WORK W/O CHEATING'
   V284    = 'Y6-280:LIE TO PARTNER AVOID ARGUMENTS'
   V285    = 'Y6-281:LIE TO GET A JOB'
   V286    = 'Y6-282:W/FRIENDS GOOD IMPRESS FOREMOST'
   V287    = 'Y6-283:TO AVOID TROUBLE LIE TO TEACHERS'
   V288    = 'Y6-284:W/PARENTS GOOD IMPRESS FOREMOST'
   V289    = 'Y6-285:LIKING WORKERS REQUIRES COVER UP'
   V290    = 'Y6-286:LIE OK KEEP PARTNER OUT/O TROUBLE'
   V291    = 'Y6-287:CAN SUCCEED SCHOOL W/O CHEATING'
   V292    = 'Y6-288:IMPORTANT TO BE HONEST W/PARENTS'
   V293    = 'Y6-289:TO BE POPULAR MUST BREAK RULES'
   V294    = 'Y6-290:OWN WORK MORE IMPORTANT'
   V295    = 'Y6-291:BEAT UP KIDS GAIN RESPECT'
   V296    = 'Y6-292:BREAK RULES TO SUCCEED AT WORK'
   V297    = 'Y6-293:TO HAVE GOOD REL MUST DECEIVE'
   V298    = 'Y6-294:PLAY DIRTY TO WIN AT SCHOOL'
   V299    = 'Y6-295:LIE TO PARENTS TO KEEP TRUST'
   V300    = 'Y6-296:W/TEACHERS GOOD IMPRESS FOREMOST'
   V301    = 'Y6-297:BREAK PROMISE GET ALONG W/PARTNER'
   V302    = 'Y6-298:LIE OK KEEP FRIEND OUT OF TROUBLE'
   V303    = 'Y6-299:BREAK PARENT RULE KEEP FRIENDS'
   V304    = 'Y6-300:WELL-LIKED'
   V305    = 'Y6-301:NEED HELP'
   V306    = 'Y6-302:BAD KID'
   V307    = 'Y6-303:OFTEN UPSET'
   V308    = 'Y6-304:GOOD CITIZEN'
   V309    = 'Y6-305:GET ALONG WELL W/OTHERS'
   V310    = 'Y6-306:MESSED UP'
   V311    = 'Y6-307:BREAK RULES'
   V312    = 'Y6-308:PERSONAL PROBLEMS'
   V313    = 'Y6-309:GET INTO TROUBLE'
   V314    = 'Y6-310:LIKELY TO SUCCEED'
   V315    = 'Y6-311:DO THINGS AGAINST THE LAW'
   V316    = 'Y6-312:CHEATED'
   V317    = 'Y6-313:STOLE SOMETHING WORTH < $5'
   V318    = 'Y6-314:SOLD HARD DRUGS'
   V319    = 'Y6-315:USED MARIJUANA'
   V320    = 'Y6-316:STOLE SOMETHING WORTH > $50'
   V321    = 'Y6-317:HIT SOMEONE'
   V322    = 'Y6-318:USED ALCOHOL'
   V323    = 'Y6-319:DESTROYED PROPERTY'
   V324    = 'Y6-320:BROKE INTO VEHICLE'
   V325    = 'Y6-321:CHEATED'
   V326    = 'Y6-322:STOLE SOMETHING WORTH < $5'
   V327    = 'Y6-323:SOLD HARD DRUGS'
   V328    = 'Y6-324:USED MARIJUANA'
   V329    = 'Y6-325:STOLE SOMETHING WORTH > $50'
   V330    = 'Y6-326:HIT SOMEONE'
   V331    = 'Y6-327:USED ALCOHOL'
   V332    = 'Y6-328:PRESSURED SOMEONE SEXUALLY'
   V333    = 'Y6-329:DESTROYED PROPERTY'
   V334    = 'Y6-330:BROKE INTO VEHICLE'
   V335    = 'Y6-331:HAD SEXUAL INTERCOURSE'
   V336    = 'Y6-332:CHEATED'
   V337    = 'Y6-333:STOLE SOMETHING WORTH < $5'
   V338    = 'Y6-334:SOLD HARD DRUGS'
   V339    = 'Y6-335:USED MARIJUANA'
   V340    = 'Y6-336:STOLE SOMETHING WORTH > $50'
   V341    = 'Y6-337:HIT SOMEONE'
   V342    = 'Y6-338:USED ALCOHOL'
   V343    = 'Y6-339:DESTROYED PROPERTY'
   V344    = 'Y6-340:BROKE INTO VEHICLE'
   V345    = 'Y6-341:CHEATED'
   V346    = 'Y6-342:STOLE SOMETHING WORTH < $5'
   V347    = 'Y6-343:SOLD HARD DRUGS'
   V348    = 'Y6-344:USED MARIJUANA'
   V349    = 'Y6-345:STOLE SOMETHING WORTH > $50'
   V350    = 'Y6-346:HIT SOMEONE'
   V351    = 'Y6-347:USED ALCOHOL'
   V352    = 'Y6-348:DESTROYED PROPERTY'
   V353    = 'Y6-349:BROKE INTO VEHICLE'
   V354    = 'Y6-350:CHEAT ON SCHOOL TESTS'
   V355    = 'Y6-351:DESTROY PROPERTY'
   V356    = 'Y6-352:USE MARIJUANA'
   V357    = 'Y6-353:STEAL SOMETHING'
   V358    = 'Y6-354:HOW WRONG-HIT SOMEONE'
   V359    = 'Y6-355:HOW WRONG-USE ALCOHOL'
   V360    = 'Y6-356:HOW WRONG-BREAK INTO VEHICLE'
   V361    = 'Y6-357:HOW WRONG-SELL HARD DRUGS'
   V362    = 'Y6-358:HOW WRONG-STEAL > $50'
   V363    = 'Y6-359:HOW WRONG-GET DRUNK'
   V364    = 'Y6-360:HOW WRONG-USE PRESCRIPTION DRUG'
   V365    = 'Y6-361:HOW WRONG-GIVE/SELL ALCOHOL'
   V366    = 'Y6-362:HOW WRONG-ATTACK TO HURT/KILL'
   V367    = 'Y6-363:HOW WRONG-EXCEED SPEED 10-20 MPH'
   V368    = 'Y6-364:HOW WRONG-STRONGARM OTHER PEOPLE'
   V369    = 'Y6-365:FRIENDS-CHEATED ON SCHOOL TESTS'
   V370    = 'Y6-366:FRIENDS-DESTROYED PROPERTY'
   V371    = 'Y6-367:FRIENDS-USED MARIJUANA'
   V372    = 'Y6-368:FRIENDS-STOLEN < $5'
   V373    = 'Y6-369:FRIENDS-HIT SOMEONE'
   V374    = 'Y6-370:FRIENDS-USED ALCOHOL'
   V375    = 'Y6-371:FRIENDS-BROKEN INTO VEHICLE'
   V376    = 'Y6-372:FRIENDS-SOLD HARD DRUGS'
   V377    = 'Y6-373:FRIENDS-STOLEN > $50'
   V378    = 'Y6-374:FRIENDS-SUGGEST YOU BREAK LAW'
   V379    = 'Y6-375:FRIENDS-GOTTEN DRUNK'
   V380    = 'Y6-376:FRIENDS-USED PRESCRIPTION DRUG'
   V381    = 'Y6-377:FRIENDS-GIVEN OR SOLD ALCOHOL'
   V382    = 'Y6-378:FRIENDS-PRESSURED SOMEONE SEX'
   V383    = 'Y6-379:DAMAGED FAMILY PROP-FREQ'
   V384    = 'Y6-380:DAMAGED FAMILY PROP-RATE'
   V385    = 'Y6-381:DAMAGED SCHOOL PROP-FREQ'
   V386    = 'Y6-382:DAMAGED SCHOOL PROP-RATE'
   V387    = 'Y6-383:DAMAGED EMPLOYER PROP-FREQ'
   V388    = 'Y6-384:DAMAGED EMPLOYER PROP-RATE'
   V389    = 'Y6-385:DAMAGED OTHER PROP-FREQ'
   V390    = 'Y6-386:DAMAGED OTHER PROP-RATE'
   V391    = 'Y6-387:STOLEN MOTOR VEHICLE-FREQ'
   V392    = 'Y6-388:STOLEN MOTOR VEHICLE-RATE'
   V393    = 'Y6-389:STOLEN > $50-FREQ'
   V394    = 'Y6-390:STOLEN > $50-RATE'
   V395    = 'Y6-391:BOUGHT STOLEN GOODS-FREQ'
   V396    = 'Y6-392:BOUGHT STOLEN GOODS-RATE'
   V397    = 'Y6-393:SET FIRE TO PROPERTY-FREQ'
   V398    = 'Y6-394:SET FIRE TO PROPERTY-RATE'
   V399    = 'Y6-395:CARRIED HIDDEN WEAPON-FREQ'
   V400    = 'Y6-396:CARRIED HIDDEN WEAPON-RATE'
   V401    = 'Y6-397:STOLEN < $5-FREQ'
   V402    = 'Y6-398:STOLEN < $5-RATE'
   V403    = 'Y6-399:ATTACKED SOMEONE-FREQ'
   V404    = 'Y6-400:ATTACKED SOMEONE-RATE'
   V405    = 'Y6-401:BEEN PAID SEX RELATIONS-FREQ'
   V406    = 'Y6-402:BEEN PAID SEX RELATIONS-RATE'
   V407    = 'Y6-403:PAID FOR SEX RELATIONS-FREQ'
   V408    = 'Y6-404:PAID FOR SEX RELATIONS-RATE'
   V409    = 'Y6-405:BEEN IN GANG FIGHTS-FREQ'
   V410    = 'Y6-406:BEEN IN GANG FIGHTS-RATE'
   V411    = 'Y6-407:USED CHECKS ILLEGALLY-FREQ'
   V412    = 'Y6-408:USED CHECKS ILLEGALLY-RATE'
   V413    = 'Y6-409:SOLD MARIJUANA-FREQ'
   V414    = 'Y6-410:SOLD MARIJUANA-RATE'
   V415    = 'Y6-411:HITCHHIKED WHERE ILLEGAL-FREQ'
   V416    = 'Y6-412:HITCHHIKED WHERE ILLEGAL-RATE'
   V417    = 'Y6-413:STOLEN MONEY FROM FAMILY-FREQ'
   V418    = 'Y6-414:STOLEN MONEY FROM FAMILY-RATE'
   V419    = 'Y6-415:STOLEN MONEY FROM EMPLOYER-FREQ'
   V420    = 'Y6-416:STOLEN MONEY FROM EMPLOYER-RATE'
   V421    = 'Y6-417:SEX AGAINST SOMEONE''S WILL-FREQ'
   V422    = 'Y6-418:SEX AGAINST SOMEONE''S WILL-RATE'
   V423    = 'Y6-419:HIT TEACHER-FREQ'
   V424    = 'Y6-420:HIT TEACHER-RATE'
   V425    = 'Y6-421:HIT PARENT-FREQ'
   V426    = 'Y6-422:HIT PARENT-RATE'
   V427    = 'Y6-423:HIT OTHER STUDENTS-FREQ'
   V428    = 'Y6-424:HIT OTHER STUDENTS-RATE'
   V429    = 'Y6-425:HIT SOMEONE AT WORK-FREQ'
   V430    = 'Y6-426:HIT SOMEONE AT WORK-RATE'
   V431    = 'Y6-427:HIT ANYONE ELSE-FREQ'
   V432    = 'Y6-428:HIT ANYONE ELSE-RATE'
   V433    = 'Y6-429:BEEN LOUD/ROWDY-FREQ'
   V434    = 'Y6-430:BEEN LOUD/ROWDY-RATE'
   V435    = 'Y6-431:SOLD HARD DRUGS-FREQ'
   V436    = 'Y6-432:SOLD HARD DRUGS-RATE'
   V437    = 'Y6-433:TRIED TO SELL WORTHLESS-FREQ'
   V438    = 'Y6-434:TRIED TO SELL WORTHLESS-RATE'
   V439    = 'Y6-435:TAKEN VEHICLE-FREQ'
   V440    = 'Y6-436:TAKEN VEHICLE-RATE'
   V441    = 'Y6-437:BOUGHT LIQUOR FOR MINOR-FREQ'
   V442    = 'Y6-438:BOUGHT LIQUOR FOR MINOR-RATE'
   V443    = 'Y6-439:USED FORCE ON STUDENTS-FREQ'
   V444    = 'Y6-440:USED FORCE ON STUDENTS-RATE'
   V445    = 'Y6-441:USED FORCE ON OTHERS-FREQ'
   V446    = 'Y6-442:USED FORCE ON OTHERS-RATE'
   V447    = 'Y6-443:AVOIDED PAYING FOR THINGS-FREQ'
   V448    = 'Y6-444:AVOIDED PAYING FOR THINGS-RATE'
   V449    = 'Y6-445:BEEN DRUNK-FREQ'
   V450    = 'Y6-446:BEEN DRUNK-RATE'
   V451    = 'Y6-447:STOLEN THINGS $5 TO $50-FREQ'
   V452    = 'Y6-448:STOLEN THINGS $5 TO $50-RATE'
   V453    = 'Y6-449:STOLEN THINGS AT SCHOOL-FREQ'
   V454    = 'Y6-450:STOLEN THINGS AT SCHOOL-RATE'
   V455    = 'Y6-451:BROKEN INTO BUILDING-FREQ'
   V456    = 'Y6-452:BROKEN INTO BUILDING-RATE'
   V457    = 'Y6-453:BEGGED FOR MONEY-FREQ'
   V458    = 'Y6-454:BEGGED FOR MONEY-RATE'
   V459    = 'Y6-455:FAILED TO RETURN CHANGE-FREQ'
   V460    = 'Y6-456:FAILED TO RETURN CHANGE-RATE'
   V461    = 'Y6-457:USED CREDIT W/O PERMISSION-FREQ'
   V462    = 'Y6-458:USED CREDIT W/O PERMISSION-RATE'
   V463    = 'Y6-459:OBSCENE PHONE CALLS-FREQ'
   V464    = 'Y6-460:OBSCENE PHONE CALLS-RATE'
   V465    = 'Y6-461:PICKED SOMEONE''S POCKET-FREQ'
   V466    = 'Y6-462:PICKED SOMEONE''S POCKET-RATE'
   V467    = 'Y6-463:EMBEZZLED MONEY/FUNDS-FREQ'
   V468    = 'Y6-464:EMBEZZLED MONEY/FUNDS-RATE'
   V469    = 'Y6-465:FORCE TO ROB PERSON/BUSINESS-FREQ'
   V470    = 'Y6-466:FORCE TO ROB PERSON/BUSINESS-RATE'
   V471    = 'Y6-467:BURGLARIZED BUILDINGS-FREQ'
   V472    = 'Y6-468:BURGLARIZED BUILDINGS-RATE'
   V473    = 'Y6-469:DAMAGED FAMILY PROPERTY'
   V474    = 'Y6-470:DAMAGED SCHOOL PROPERTY'
   V475    = 'Y6-471:DAMAGED EMPLOYER''S PROPERTY'
   V476    = 'Y6-472:DAMAGED OTHER PROPERTY'
   V477    = 'Y6-473:STOLEN MV-THE LAST TIME'
   V478    = 'Y6-474:STOLEN MV-NEXT TO LAST TIME'
   V479    = 'Y6-475:STOLEN MV-TIME BEFORE THAT'
   V480    = 'Y6-476:STOLEN > $50-THE LAST TIME'
   V481    = 'Y6-477:STOLEN > $50-NEXT TO LAST TIME'
   V482    = 'Y6-478:STOLEN > $50-TIME BEFORE THAT'
   V483    = 'Y6-479:BOUGHT STOLEN GOODS'
   V484    = 'Y6-480:SET FIRE TO PROPERTY'
   V485    = 'Y6-481:CARRIED A HIDDEN WEAPON'
   V486    = 'Y6-482:STOLEN < $5'
   V487    = 'Y6-483:ATTACK SOMEONE-THE LAST TIME'
   V488    = 'Y6-484:ATTACK SOMEONE-NEXT TO LAST TIME'
   V489    = 'Y6-485:ATTACK SOMEONE-TIME BEFORE THAT'
   V490    = 'Y6-486:IN GANG FIGHTS-THE LAST TIME'
   V491    = 'Y6-487:IN GANG FIGHTS-NEXT TO LAST TIME'
   V492    = 'Y6-488:IN GANG FIGHTS-TIME BEFORE THAT'
   V493    = 'Y6-489:USED CHECKS ILLEGALLY'
   V494    = 'Y6-490:SOLD MARIJUANA'
   V495    = 'Y6-491:STOLEN MONEY FROM FAMILY'
   V496    = 'Y6-492:STOLEN MONEY FROM EMPLOYER'
   V497    = 'Y6-493:SEX AGAINST WILL-THE LAST TIME'
   V498    = 'Y6-494:SEX AGAINST WILL-NEXT/LAST TIME'
   V499    = 'Y6-495:SEX AGAINST WILL-TIME BEFORE THAT'
   V500    = 'Y6-496:HIT TEACHER'
   V501    = 'Y6-497:HIT PARENT'
   V502    = 'Y6-498:HIT OTHER STUDENTS'
   V503    = 'Y6-499:HIT SOMEONE AT WORK'
   V504    = 'Y6-500:HIT ANYONE ELSE'
   V505    = 'Y6-501:SOLD HARD DRUGS'
   V506    = 'Y6-502:TRIED SELL SOMETHING WORTHLESS'
   V507    = 'Y6-503:TAKEN VEHICLE'
   V508    = 'Y6-504:FORCE STUDENTS-THE LAST TIME'
   V509    = 'Y6-505:FORCE STUDENTS-NEXT TO LAST TIME'
   V510    = 'Y6-506:FORCE STUDENTS-TIME BEFORE THAT'
   V511    = 'Y6-507:FORCE OTHERS-THE LAST TIME'
   V512    = 'Y6-508:FORCE OTHERS-NEXT TO LAST TIME'
   V513    = 'Y6-509:FORCE OTHERS-TIME BEFORE THAT'
   V514    = 'Y6-510:STOLEN THINGS WORTH FROM $5-$50'
   V515    = 'Y6-511:STOLEN THINGS AT SCHOOL'
   V516    = 'Y6-512:BROKEN INTO BLDG-THE LAST TIME'
   V517    = 'Y6-513:BROKEN INTO BLDG-NEXT/LAST TIME'
   V518    = 'Y6-514:BROKEN INTO BLDG-TIME BEFORE THAT'
   V519    = 'Y6-515:CREDIT CARDS WITHOUT PERMISSION'
   V520    = 'Y6-516:PICKED SOMEONE''S POCKET'
   V521    = 'Y6-517:EMBEZZLED MONEY OR FUNDS'
   V522    = 'Y6-518:FORCE TO ROB PERSONS/BUSINESS'
   V523    = 'Y6-519:BURGLARIZED BUILDINGS'
   V524    = 'Y6-520:DAMAGE FAM PROP-HOW MUCH WORTH'
   V525    = 'Y6-521:DAMAGE FAM PROP-OTHERS INVOLVED'
   V526    = 'Y6-522:DAMAGE FAM PROP-1ST ITEM NO.'
   V527    = 'Y6-523:DAMAGE FAM PROP-2ND ITEM NO.'
   V528    = 'Y6-524:DAMAGE SCHOOL PROP-HOW MUCH WORTH'
   V529    = 'Y6-525:DAMAGE SCHOOL PROP-OTH INVOLVE'
   V530    = 'Y6-526:DAMAGE SCHOOL PROP-1ST ITEM NO.'
   V531    = 'Y6-527:DAMAGE SCHOOL PROP-2ND ITEM NO.'
   V532    = 'Y6-528:DAMAGE EMPLOY PROP-HOW MUCH WORTH'
   V533    = 'Y6-529:DAMAGE EMPLOY PROP-OTH INVOLVE'
   V534    = 'Y6-530:DAMAGE EMPLOY PROP-1ST ITEM NO.'
   V535    = 'Y6-531:DAMAGE EMPLOY PROP-2ND ITEM NO.'
   V536    = 'Y6-532:DAMAGE OTHER PROP-HOW MUCH WORTH'
   V537    = 'Y6-533:DAMAGE OTHER PROP-OTH INVOLVE'
   V538    = 'Y6-534:DAMAGE OTHER PROP-1ST ITEM NO.'
   V539    = 'Y6-535:DAMAGE OTHER PROP-2ND ITEM NO.'
   V540    = 'Y6-536:STOLE MV/LAST TIME-KIND O/VEHICLE'
   V541    = 'Y6-537:STOLE MV/LAST TIME-ACTUALLY STEAL'
   V542    = 'Y6-538:STOLE MV/LAST TIME-VEHICLE OWNER'
   V543    = 'Y6-539:STOLE MV/LAST TIME-START VEHICLE'
   V544    = 'Y6-540:STOLE MV/LAST TIME-INTENT'
   V545    = 'Y6-541:STOLE MV/LAST TIME-OTH INVOLVE'
   V546    = 'Y6-542:STOLE MV/LAST TIME-DRINK/DRUGS'
   V547    = 'Y6-543:STOLE MV/LAST TIME-1ST ITEM NO.'
   V548    = 'Y6-544:STOLE MV/LAST TIME-2ND ITEM NO.'
   V549    = 'Y6-545:STOLE MV/NEXT LAST-KIND VEHICLE'
   V550    = 'Y6-546:STOLE MV/NEXT LAST-ACTUALLY STEAL'
   V551    = 'Y6-547:STOLE MV/NEXT LAST-VEHICLE OWNER'
   V552    = 'Y6-548:STOLE MV/NEXT LAST-START VEHICLE'
   V553    = 'Y6-549:STOLE MV/NEXT LAST-INTENT'
   V554    = 'Y6-550:STOLE MV/NEXT LAST-OTH INVOLVE'
   V555    = 'Y6-551:STOLE MV/NEXT LAST-DRINK/DRUGS'
   V556    = 'Y6-552:STOLE MV/NEXT LAST-1ST ITEM NO.'
   V557    = 'Y6-553:STOLE MV/NEXT LAST-2ND ITEM NO.'
   V558    = 'Y6-554:STOLE MV/TIME BEF-KIND VEHICLE'
   V559    = 'Y6-555:STOLE MV/TIME BEF-ACTUALLY STEAL'
   V560    = 'Y6-556:STOLE MV/TIME BEF-VEHICLE OWNER'
   V561    = 'Y6-557:STOLE MV/TIME BEF-START VEHICLE'
   V562    = 'Y6-558:STOLE MV/TIME BEF-INTENT'
   V563    = 'Y6-559:STOLE MV/TIME BEF-OTH INVOLVE'
   V564    = 'Y6-560:STOLE MV/TIME BEF-DRINK/DRUGS'
   V565    = 'Y6-561:STOLE MV/TIME BEF-1ST ITEM NO.'
   V566    = 'Y6-562:STOLE MV/TIME BEF-2ND ITEM NO.'
   V567    = 'Y6-563:STOLE > $50/LAST TIME-VALUE'
   V568    = 'Y6-564:STOLE > $50/LAST TME-ACTUAL STEAL'
   V569    = 'Y6-565:STOLE > $50/LAST TIME-STOLEN FROM'
   V570    = 'Y6-566:STOLE > $50/LAST TIME-OTH INVOLVE'
   V571    = 'Y6-567:STOLE > $50/LAST TIME-DRINK/DRUGS'
   V572    = 'Y6-568:STOLE > $50/LAST TIME-1ST ITEM NO'
   V573    = 'Y6-569:STOLE > $50/LAST TIME-2ND ITEM NO'
   V574    = 'Y6-570:STOLE > $50/NEXT LAST-VALUE'
   V575    = 'Y6-571:STOLE > $50/NEXT LST-ACTUAL STEAL'
   V576    = 'Y6-572:STOLE > $50/NEXT LAST-STOLEN FROM'
   V577    = 'Y6-573:STOLE > $50/NEXT LAST-OTH INVOLVE'
   V578    = 'Y6-574:STOLE > $50/NEXT LAST-DRINK/DRUGS'
   V579    = 'Y6-575:STOLE > $50/NEXT LAST-1ST ITEM NO'
   V580    = 'Y6-576:STOLE > $50/NEXT LAST-2ND ITEM NO'
   V581    = 'Y6-577:STOLE > $50/TIME BEF-VALUE'
   V582    = 'Y6-578:STOLE > $50/TIME BEF-ACTUAL STEAL'
   V583    = 'Y6-579:STOLE > $50/TIME BEF-STOLEN FROM'
   V584    = 'Y6-580:STOLE > $50/TIME BEF-OTH INVOLVE'
   V585    = 'Y6-581:STOLE > $50/TIME BEF-DRINK/DRUGS'
   V586    = 'Y6-582:STOLE > $50/TIME BEF-1ST ITEM NO.'
   V587    = 'Y6-583:STOLE > $50/TIME BEF-2ND ITEM NO.'
   V588    = 'Y6-584:BOUGHT STOLEN-WHAT DID YOU DO'
   V589    = 'Y6-585:BOUGHT STOLEN-VALUE'
   V590    = 'Y6-586:BOUGHT STOLEN-OTH INVOLVE'
   V591    = 'Y6-587:BOUGHT STOLEN-1ST ITEM NO.'
   V592    = 'Y6-588:BOUGHT STOLEN-2ND ITEM NO.'
   V593    = 'Y6-589:SET FIRE TO PROP-ACTUALLY SET'
   V594    = 'Y6-590:SET FIRE TO PROP-OTH INVOLVE'
   V595    = 'Y6-591:SET FIRE TO PROP-DRINK/DRUGS'
   V596    = 'Y6-592:SET FIRE TO PROP-1ST ITEM NO.'
   V597    = 'Y6-593:SET FIRE TO PROP-2ND ITEM NO.'
   V598    = 'Y6-594:CARRIED HIDDEN WEAPON-KIND'
   V599    = 'Y6-595:STOLE < $5-VALUE'
   V600    = 'Y6-596:STOLE < $5-ACTUALLY STEAL'
   V601    = 'Y6-597:STOLE < $5-OTH INVOLVE'
   V602    = 'Y6-598:STOLE < $5-DRINK/DRUGS'
   V603    = 'Y6-599:STOLE < $5-1ST ITEM NO.'
   V604    = 'Y6-600:STOLE < $5-2ND ITEM NO.'
   V605    = 'Y6-601:ATTACK/LAST TIME-FORM OF ATTACK'
   V606    = 'Y6-602:ATTACK/LAST TIME-HURT PERSON'
   V607    = 'Y6-603:ATTACK/LAST TIME-EXTENT INJURY'
   V608    = 'Y6-604:ATTACK/LAST TIME-WAS THE PERSON'
   V609    = 'Y6-605:ATTACK/LAST TIME-OTH INVOLVE'
   V610    = 'Y6-606:ATTACK/LAST TIME-DRINK/DRUGS'
   V611    = 'Y6-607:ATTACK/LAST TIME-1ST ITEM NO.'
   V612    = 'Y6-608:ATTACK/LAST TIME-2ND ITEM NO.'
   V613    = 'Y6-609:ATTACK/NEXT LAST-FORM OF ATTACK'
   V614    = 'Y6-610:ATTACK/NEXT LAST-HURT PERSON'
   V615    = 'Y6-611:ATTACK/NEXT LAST-EXTENT OF INJURY'
   V616    = 'Y6-612:ATTACK/NEXT LAST-WAS THE PERSON'
   V617    = 'Y6-613:ATTACK/NEXT LAST-OTH INVOLVE'
   V618    = 'Y6-614:ATTACK/NEXT LAST-DRINK/DRUGS'
   V619    = 'Y6-615:ATTACK/NEXT LAST-1ST ITEM NO.'
   V620    = 'Y6-616:ATTACK/NEXT LAST-2ND ITEM NO.'
   V621    = 'Y6-617:ATTACK/TIME BEF-FORM OF ATTACK'
   V622    = 'Y6-618:ATTACK/TIME BEF-HURT PERSON'
   V623    = 'Y6-619:ATTACK/TIME BEF-EXTENT OF INJURY'
   V624    = 'Y6-620:ATTACK/TIME BEF-WAS THE PERSON'
   V625    = 'Y6-621:ATTACK/TIME BEF-OTH INVOLVE'
   V626    = 'Y6-622:ATTACK/TIME BEF-DRINK/DRUGS'
   V627    = 'Y6-623:ATTACK/TIME BEF-1ST ITEM NO.'
   V628    = 'Y6-624:ATTACK/TIME BEF-2ND ITEM NO.'
   V629    = 'Y6-625:GANG FIGHT/LAST-NO. GROUP'
   V630    = 'Y6-626:GANG FIGHT/LAST-NO. OTH GROUP'
   V631    = 'Y6-627:GANG FIGHT/LAST-USE WEAPONS'
   V632    = 'Y6-628:GANG FIGHT/LAST-NATURE OF WEAPONS'
   V633    = 'Y6-629:GANG FIGHT/LAST-ANYONE HURT'
   V634    = 'Y6-630:GANG FIGHT/LAST-EXTENT OF INJURY'
   V635    = 'Y6-631:GANG FIGHT/LAST-DRINK/DRUGS'
   V636    = 'Y6-632:GANG FIGHT/LAST-1ST ITEM NO.'
   V637    = 'Y6-633:GANG FIGHT/LAST-2ND ITEM NO.'
   V638    = 'Y6-634:GANG FIGHT/NEXT-NO. GROUP'
   V639    = 'Y6-635:GANG FIGHT/NEXT-NO. OTH GROUP'
   V640    = 'Y6-636:GANG FIGHT/NEXT-USE WEAPONS'
   V641    = 'Y6-637:GANG FIGHT/NEXT-NATURE OF WEAPONS'
   V642    = 'Y6-638:GANG FIGHT/NEXT-ANYONE HURT'
   V643    = 'Y6-639:GANG FIGHT/NEXT-EXTENT OF INJURY'
   V644    = 'Y6-640:GANG FIGHT/NEXT-DRINK/DRUGS'
   V645    = 'Y6-641:GANG FIGHT/NEXT-1ST ITEM NO.'
   V646    = 'Y6-642:GANG FIGHT/NEXT-2ND ITEM NO.'
   V647    = 'Y6-643:GANG FIGHT/BEF-NO. GROUP'
   V648    = 'Y6-644:GANG FIGHT/BEF-NO. OTH GROUP'
   V649    = 'Y6-645:GANG FIGHT/BEF-USE WEAPONS'
   V650    = 'Y6-646:GANG FIGHT/BEF-NATURE OF WEAPONS'
   V651    = 'Y6-647:GANG FIGHT/BEF-ANYONE HURT'
   V652    = 'Y6-648:GANG FIGHT/BEF-EXTENT OF INJURY'
   V653    = 'Y6-649:GANG FIGHT/BEF-DRINK/DRUGS'
   V654    = 'Y6-650:GANG FIGHT/BEF-1ST ITEM NO.'
   V655    = 'Y6-651:GANG FIGHT/BEF-2ND ITEM NO.'
   V656    = 'Y6-652:USE CHECK ILLEGALLY-HOW USED'
   V657    = 'Y6-653:USE CHECK ILLEGALLY-VALUE'
   V658    = 'Y6-654:USE CHECK ILLEGALLY-OTH INVOLVE'
   V659    = 'Y6-655:USE CHECK ILLEGALLY-1ST ITEM NO.'
   V660    = 'Y6-656:USE CHECK ILLEGALLY-2ND ITEM NO.'
   V661    = 'Y6-657:SOLD MARIJUANA-VALUE'
   V662    = 'Y6-658:SOLD MARIJUANA-AMOUNT/OUNCES'
   V663    = 'Y6-659:SOLD MARIJUANA-OTH INVOLVE'
   V664    = 'Y6-660:SOLD MARIJUANA-1ST ITEM NO.'
   V665    = 'Y6-661:SOLD MARIJUANA-2ND ITEM NO.'
   V666    = 'Y6-662:STOLE F/FAMILY-WHAT DID YOU STEAL'
   V667    = 'Y6-663:STOLE F/FAMILY-AMOUNT STOLEN'
   V668    = 'Y6-664:STOLE F/FAMILY-VALUE OF OTHER'
   V669    = 'Y6-665:STOLE F/FAMILY-OTH INVOLVE'
   V670    = 'Y6-666:STOLE F/FAMILY-DRINK/DRUGS'
   V671    = 'Y6-667:STOLE F/FAMILY-1ST ITEM NO.'
   V672    = 'Y6-668:STOLE F/FAMILY-2ND ITEM NO.'
   V673    = 'Y6-669:STOLE F/EMPLOY-WHAT DID YOU STEAL'
   V674    = 'Y6-670:STOLE F/EMPLOY-AMOUNT STOLEN'
   V675    = 'Y6-671:STOLE F/EMPLOY-VALUE OF OTHER'
   V676    = 'Y6-672:STOLE F/EMPLOY-OTH INVOLVE'
   V677    = 'Y6-673:STOLE F/EMPLOY-DRINK/DRUGS'
   V678    = 'Y6-674:STOLE F/EMPLOY-1ST ITEM NO.'
   V679    = 'Y6-675:STOLE F/EMPLOY-2ND ITEM NO.'
   V680    = 'Y6-676:SEX AGAINST/LAST-OUTCOME ATTEMPT'
   V681    = 'Y6-677:SEX AGAINST/LAST-MEANS FORCE'
   V682    = 'Y6-678:SEX AGAINST/LAST-HURT PERSON'
   V683    = 'Y6-679:SEX AGAINST/LAST-EXTENT INJURY'
   V684    = 'Y6-680:SEX AGAINST/LAST-OTH INVOLVE'
   V685    = 'Y6-681:SEX AGAINST/LAST-WAS PERSON'
   V686    = 'Y6-682:SEX AGAINST/LAST-DRINK/DRUGS'
   V687    = 'Y6-683:SEX AGAINST/LAST-1ST ITEM NO.'
   V688    = 'Y6-684:SEX AGAINST/LAST-2ND ITEM NO.'
   V689    = 'Y6-685:SEX AGAINST/NEXT-OUTCOME ATTEMPT'
   V690    = 'Y6-686:SEX AGAINST/NEXT-MEANS FORCE'
   V691    = 'Y6-687:SEX AGAINST/NEXT-HURT PERSON'
   V692    = 'Y6-688:SEX AGAINST/NEXT-EXTENT INJURY'
   V693    = 'Y6-689:SEX AGAINST/NEXT-OTH INVOLVE'
   V694    = 'Y6-690:SEX AGAINST/NEXT-WAS PERSON'
   V695    = 'Y6-691:SEX AGAINST/NEXT-DRINK/DRUGS'
   V696    = 'Y6-692:SEX AGAINST/NEXT-1ST ITEM NO.'
   V697    = 'Y6-693:SEX AGAINST/NEXT-2ND ITEM NO.'
   V698    = 'Y6-694:SEX AGAINST/BEF-OUTCOME ATTEMPT'
   V699    = 'Y6-695:SEX AGAINST/BEF-MEANS FORCE'
   V700    = 'Y6-696:SEX AGAINST/BEF-HURT PERSON'
   V701    = 'Y6-697:SEX AGAINST/BEF-EXTENT INJURY'
   V702    = 'Y6-698:SEX AGAINST/BEF-OTH INVOLVE'
   V703    = 'Y6-699:SEX AGAINST/BEF-WAS THE PERSON'
   V704    = 'Y6-700:SEX AGAINST/BEF-DRINK/DRUGS'
   V705    = 'Y6-701:SEX AGAINST/BEF-1ST ITEM NO.'
   V706    = 'Y6-702:SEX AGAINST/BEF-2ND ITEM NO.'
   V707    = 'Y6-703:HIT TEACHER-OUTCOME ATTEMPT'
   V708    = 'Y6-704:HIT TEACHER-HURT PERSON'
   V709    = 'Y6-705:HIT TEACHER-EXTENT INJURY'
   V710    = 'Y6-706:HIT TEACHER-OTH INVOLVE'
   V711    = 'Y6-707:HIT TEACHER-DRINK/DRUGS'
   V712    = 'Y6-708:HIT TEACHER-1ST ITEM NO.'
   V713    = 'Y6-709:HIT TEACHER-2ND ITEM NO.'
   V714    = 'Y6-710:HIT PARENTS-OUTCOME ATTEMPT'
   V715    = 'Y6-711:HIT PARENTS-HURT PERSON'
   V716    = 'Y6-712:HIT PARENTS-EXTENT INJURY'
   V717    = 'Y6-713:HIT PARENTS-OTH INVOLVE'
   V718    = 'Y6-714:HIT PARENTS-DRINK/DRUGS'
   V719    = 'Y6-715:HIT PARENTS-1ST ITEM NO.'
   V720    = 'Y6-716:HIT PARENTS-2ND ITEM NO.'
   V721    = 'Y6-717:HIT STUDENTS-OUTCOME ATTEMPT'
   V722    = 'Y6-718:HIT STUDENTS-HURT PERSON'
   V723    = 'Y6-719:HIT STUDENTS-EXTENT INJURY'
   V724    = 'Y6-720:HIT STUDENTS-OTH INVOLVE'
   V725    = 'Y6-721:HIT STUDENTS-DRINK/DRUGS'
   V726    = 'Y6-722:HIT STUDENTS-1ST ITEM NO.'
   V727    = 'Y6-723:HIT STUDENTS-2ND ITEM NO.'
   V728    = 'Y6-724:HIT AT WORK-OUTCOME ATTEMPT'
   V729    = 'Y6-725:HIT AT WORK-HURT PERSON'
   V730    = 'Y6-726:HIT AT WORK-EXTENT INJURY'
   V731    = 'Y6-727:HIT AT WORK-OTH INVOLVE'
   V732    = 'Y6-728:HIT AT WORK-DRINK/DRUGS'
   V733    = 'Y6-729:HIT AT WORK-1ST ITEM NO.'
   V734    = 'Y6-730:HIT AT WORK-2ND ITEM NO.'
   V735    = 'Y6-731:HIT ELSE-OUTCOME ATTEMPT'
   V736    = 'Y6-732:HIT ELSE-HURT PERSON'
   V737    = 'Y6-733:HIT ELSE-EXTENT INJURY'
   V738    = 'Y6-734:HIT ELSE-OTH INVOLVE'
   V739    = 'Y6-735:HIT ELSE-DRINK/DRUGS'
   V740    = 'Y6-736:HIT ELSE-1ST ITEM NO.'
   V741    = 'Y6-737:HIT ELSE-2ND ITEM NO.'
   V742    = 'Y6-738:SOLD HARD DRUGS-WHAT DRUGS'
   V743    = 'Y6-739:SOLD HARD DRUGS-VALUE'
   V744    = 'Y6-740:SOLD HARD DRUGS-OTH INVOLVE'
   V745    = 'Y6-741:SOLD HARD DRUGS-1ST ITEM NO.'
   V746    = 'Y6-742:SOLD HARD DRUGS-2ND ITEM NO.'
   V747    = 'Y6-743:SOLD WORTHLESS-SOLD TO WHOM'
   V748    = 'Y6-744:SOLD WORTHLESS-REAL VALUE'
   V749    = 'Y6-745:SOLD WORTHLESS-ASKING PRICE'
   V750    = 'Y6-746:SOLD WORTHLESS-OUTCOME O/ATTEMPT'
   V751    = 'Y6-747:SOLD WORTHLESS-OTH INVOLVE'
   V752    = 'Y6-748:SOLD WORTHLESS-1ST ITEM NO.'
   V753    = 'Y6-749:SOLD WORTHLESS-2ND ITEM NO.'
   V754    = 'Y6-750:TAKEN VEHICLE-KIND OF VEHICLE'
   V755    = 'Y6-751:TAKEN VEHICLE-VEHICLE OWNER'
   V756    = 'Y6-752:TAKEN VEHICLE-STARTED VEHICLE'
   V757    = 'Y6-753:TAKEN VEHICLE-OTH INVOLVE'
   V758    = 'Y6-754:TAKEN VEHICLE-DRINK/DRUGS'
   V759    = 'Y6-755:TAKEN VEHICLE-1ST ITEM NO.'
   V760    = 'Y6-756:TAKEN VEHICLE-2ND ITEM NO.'
   V761    = 'Y6-757:FORCE STUDENT/LAST-TYPE FORCE'
   V762    = 'Y6-758:FORCE STUDENT/LAST-USE WEAPONS'
   V763    = 'Y6-759:FORCE STUDENT/LAST-NATURE WEAPONS'
   V764    = 'Y6-760:FORCE STUDENT/LAST-PURPOSE'
   V765    = 'Y6-761:FORCE STUDENT/LAST-HURT PERSON'
   V766    = 'Y6-762:FORCE STUDENT/LAST-EXTENT INJURY'
   V767    = 'Y6-763:FORCE STUDENT/LAST-OTH INVOLVE'
   V768    = 'Y6-764:FORCE STUDENT/LAST-DRINK/DRUGS'
   V769    = 'Y6-765:FORCE STUDENT/LAST-1ST ITEM NO.'
   V770    = 'Y6-766:FORCE STUDENT/LAST-2ND ITEM NO.'
   V771    = 'Y6-767:FORCE STUDENT/NEXT-TYPE FORCE'
   V772    = 'Y6-768:FORCE STUDENT/NEXT-USE WEAPONS'
   V773    = 'Y6-769:FORCE STUDENT/NEXT-NATURE WEAPONS'
   V774    = 'Y6-770:FORCE STUDENT/NEXT-PURPOSE'
   V775    = 'Y6-771:FORCE STUDENT/NEXT-HURT PERSON'
   V776    = 'Y6-772:FORCE STUDENT/NEXT-EXTENT INJURY'
   V777    = 'Y6-773:FORCE STUDENT/NEXT-OTH INVOLVE'
   V778    = 'Y6-774:FORCE STUDENT/NEXT-DRINK/DRUGS'
   V779    = 'Y6-775:FORCE STUDENT/NEXT-1ST ITEM NO.'
   V780    = 'Y6-776:FORCE STUDENT/NEXT-2ND ITEM NO.'
   V781    = 'Y6-777:FORCE STUDENT/BEF-TYPE FORCE'
   V782    = 'Y6-778:FORCE STUDENT/BEF-USE WEAPONS'
   V783    = 'Y6-779:FORCE STUDENT/BEF-NATURE WEAPONS'
   V784    = 'Y6-780:FORCE STUDENT/BEF-PURPOSE'
   V785    = 'Y6-781:FORCE STUDENT/BEF-HURT PERSON'
   V786    = 'Y6-782:FORCE STUDENT/BEF-EXTENT INJURY'
   V787    = 'Y6-783:FORCE STUDENT/BEF-OTH INVOLVE'
   V788    = 'Y6-784:FORCE STUDENT/BEF-DRINK/DRUGS'
   V789    = 'Y6-785:FORCE STUDENT/BEF-1ST ITEM NO.'
   V790    = 'Y6-786:FORCE STUDENT/BEF-2ND ITEM NO.'
   V791    = 'Y6-787:FORCE OTHERS/LAST-TYPE FORCE'
   V792    = 'Y6-788:FORCE OTHERS/LAST-USE WEAPONS'
   V793    = 'Y6-789:FORCE OTHERS/LAST-NATURE WEAPONS'
   V794    = 'Y6-790:FORCE OTHERS/LAST-PURPOSE'
   V795    = 'Y6-791:FORCE OTHERS/LAST-HURT PERSON'
   V796    = 'Y6-792:FORCE OTHERS/LAST-EXTENT INJURY'
   V797    = 'Y6-793:FORCE OTHERS/LAST-OTH INVOLVE'
   V798    = 'Y6-794:FORCE OTHERS/LAST-DRINK/DRUGS'
   V799    = 'Y6-795:FORCE OTHERS/LAST-1ST ITEM NO.'
   V800    = 'Y6-796:FORCE OTHERS/LAST-2ND ITEM NO.'
   V801    = 'Y6-797:FORCE OTHERS/NEXT-TYPE FORCE'
   V802    = 'Y6-798:FORCE OTHERS/NEXT-USE WEAPONS'
   V803    = 'Y6-799:FORCE OTHERS/NEXT-NATURE WEAPONS'
   V804    = 'Y6-800:FORCE OTHERS/NEXT-PURPOSE'
   V805    = 'Y6-801:FORCE OTHERS/NEXT-HURT PERSON'
   V806    = 'Y6-802:FORCE OTHERS/NEXT-EXTENT INJURY'
   V807    = 'Y6-803:FORCE OTHERS/NEXT-OTH INVOLVE'
   V808    = 'Y6-804:FORCE OTHERS/NEXT-DRINK/DRUGS'
   V809    = 'Y6-805:FORCE OTHERS/NEXT-1ST ITEM NO.'
   V810    = 'Y6-806:FORCE OTHERS/NEXT-2ND ITEM NO.'
   V811    = 'Y6-807:FORCE OTHERS/BEF-TYPE FORCE'
   V812    = 'Y6-808:FORCE OTHERS/BEF-USE WEAPONS'
   V813    = 'Y6-809:FORCE OTHERS/BEF-NATURE WEAPONS'
   V814    = 'Y6-810:FORCE OTHERS/BEF-PURPOSE'
   V815    = 'Y6-811:FORCE OTHERS/BEF-HURT PERSON'
   V816    = 'Y6-812:FORCE OTHERS/BEF-EXTENT INJURY'
   V817    = 'Y6-813:FORCE OTHERS/BEF-OTH INVOLVE'
   V818    = 'Y6-814:FORCE OTHERS/BEF-DRINK/DRUGS'
   V819    = 'Y6-815:FORCE OTHERS/BEF-1ST ITEM NO.'
   V820    = 'Y6-816:FORCE OTHERS/BEF-2ND ITEM NO.'
   V821    = 'Y6-817:STOLE $5 TO $50-VALUE'
   V822    = 'Y6-818:STOLE $5 TO $50-STOLEN FROM'
   V823    = 'Y6-819:STOLE $5 TO $50-ACTUALLY STEAL'
   V824    = 'Y6-820:STOLE $5 TO $50-OTH INVOLVE'
   V825    = 'Y6-821:STOLE $5 TO $50-DRINK/DRUGS'
   V826    = 'Y6-822:STOLE $5 TO $50-1ST ITEM NO.'
   V827    = 'Y6-823:STOLE $5 TO $50-2ND ITEM NO.'
   V828    = 'Y6-824:STOLE AT SCHOOL-ACTUALLY STEAL'
   V829    = 'Y6-825:STOLE AT SCHOOL-VALUE'
   V830    = 'Y6-826:STOLE AT SCHOOL-OTH INVOLVE'
   V831    = 'Y6-827:STOLE AT SCHOOL-DRINK/DRUGS'
   V832    = 'Y6-828:STOLE AT SCHOOL-1ST ITEM NO.'
   V833    = 'Y6-829:STOLE AT SCHOOL-2ND ITEM NO.'
   V834    = 'Y6-830:BROKE BLDG/LAST-BROKE INTO WHAT'
   V835    = 'Y6-831:BROKE BLDG/LAST-ACTUAL BREAK IN'
   V836    = 'Y6-832:BROKE BLDG/LAST-REASON'
   V837    = 'Y6-833:BROKE BLDG/LAST-OTH INVOLVE'
   V838    = 'Y6-834:BROKE BLDG/LAST-DRINK/DRUGS'
   V839    = 'Y6-835:BROKE BLDG/LAST-1ST ITEM NO.'
   V840    = 'Y6-836:BROKE BLDG/LAST-2ND ITEM NO.'
   V841    = 'Y6-837:BROKE BLDG/NEXT-BROKE INTO WHAT'
   V842    = 'Y6-838:BROKE BLDG/NEXT-ACTUAL BREAK IN'
   V843    = 'Y6-839:BROKE BLDG/NEXT-REASON'
   V844    = 'Y6-840:BROKE BLDG/NEXT-OTH INVOLVE'
   V845    = 'Y6-841:BROKE BLDG/NEXT-DRINK/DRUGS'
   V846    = 'Y6-842:BROKE BLDG/NEXT-1ST ITEM NO.'
   V847    = 'Y6-843:BROKE BLDG/NEXT-2ND ITEM NO.'
   V848    = 'Y6-844:BROKE BLDG/BEF-BROKE INTO WHAT'
   V849    = 'Y6-845:BROKE BLDG/BEF-ACTUAL BREAK IN'
   V850    = 'Y6-846:BROKE BLDG/BEF-REASON'
   V851    = 'Y6-847:BROKE BLDG/BEF-OTH INVOLVE'
   V852    = 'Y6-848:BROKE BLDG/BEF-DRINK/DRUGS'
   V853    = 'Y6-849:BROKE BLDG/BEF-1ST ITEM NO.'
   V854    = 'Y6-850:BROKE BLDG/BEF-2ND ITEM NO.'
   V855    = 'Y6-851:CREDIT W/O PERMISSION-WHOSE CARD'
   V856    = 'Y6-852:CREDIT W/O PERMISSION-$ CHARGED'
   V857    = 'Y6-853:CREDIT W/O PERMISSION-OTH INVOLVE'
   V858    = 'Y6-854:CREDIT W/O PERMISSION-1ST ITEM NO'
   V859    = 'Y6-855:CREDIT W/O PERMISSION-2ND ITEM NO'
   V860    = 'Y6-856:PICKED POCKET-WHAT DID YOU DO'
   V861    = 'Y6-857:PICKED POCKET-WHAT WAS TAKEN'
   V862    = 'Y6-858:PICKED POCKET-OTH INVOLVE'
   V863    = 'Y6-859:PICKED POCKET-DRINK/DRUGS'
   V864    = 'Y6-860:PICKED POCKET-1ST ITEM NO.'
   V865    = 'Y6-861:PICKED POCKET-2ND ITEM NO.'
   V866    = 'Y6-862:EMBEZZLED MONEY/FUNDS-VALUE'
   V867    = 'Y6-863:EMBEZZLED MONEY/FUNDS-1ST ITEM NO'
   V868    = 'Y6-864:EMBEZZLED MONEY/FUNDS-2ND ITEM NO'
   V869    = 'Y6-865:FORCE TO ROB-TYPE OF FORCE'
   V870    = 'Y6-866:FORCE TO ROB-USE WEAPONS'
   V871    = 'Y6-867:FORCE TO ROB-NATURE OF WEAPONS'
   V872    = 'Y6-868:FORCE TO ROB-PURPOSE'
   V873    = 'Y6-869:FORCE TO ROB-HURT THE PERSON'
   V874    = 'Y6-870:FORCE TO ROB-EXTENT OF INJURY'
   V875    = 'Y6-871:FORCE TO ROB-OTH INVOLVE'
   V876    = 'Y6-872:FORCE TO ROB-1ST ITEM NO.'
   V877    = 'Y6-873:FORCE TO ROB-2ND ITEM NO.'
   V878    = 'Y6-874:BURGLARIZED BLDG-REASON'
   V879    = 'Y6-875:BURGLARIZED BLDG-OTH INVOLVE'
   V880    = 'Y6-876:BURGLARIZED BLDG-1ST ITEM NO.'
   V881    = 'Y6-877:BURGLARIZED BLDG-2ND ITEM NO.'
   V882    = 'Y6-878:ALCOHOLIC BEVERAGES-FREQ'
   V883    = 'Y6-879:ALCOHOLIC BEVERAGES-RATE'
   V884    = 'Y6-880:ALCOHOLIC BEVERAGES-EPISODIC'
   V885    = 'Y6-881:TOBACCO-USED TOBACCO'
   V886    = 'Y6-882:TOBACCO-EPISODIC'
   V887    = 'Y6-883:TOBACCO-# CIGS PER DAY'
   V888    = 'Y6-884:TOBACCO-# CIGARS/PIPES PER DAY'
   V889    = 'Y6-885:TOBACCO-CANS CHEW TOBACCO/MO'
   V890    = 'Y6-886:MARIJUANA-FREQ'
   V891    = 'Y6-887:MARIJUANA-RATE'
   V892    = 'Y6-888:MARIJUANA-EPISODIC'
   V893    = 'Y6-889:HALLUCINOGENS-FREQ'
   V894    = 'Y6-890:HALLUCINOGENS-RATE'
   V895    = 'Y6-891:HALLUCINOGENS-EPISODIC'
   V896    = 'Y6-892:TRANQUILIZERS-FREQ'
   V897    = 'Y6-893:TRANQUILIZERS-RATE'
   V898    = 'Y6-894:TRANQUILIZERS-EPISODIC'
   V899    = 'Y6-895:AMPHETAMINES-FREQ'
   V900    = 'Y6-896:AMPHETAMINES-RATE'
   V901    = 'Y6-897:AMPHETAMINES-EPISODIC'
   V902    = 'Y6-898:BARBITURATES-FREQ'
   V903    = 'Y6-899:BARBITURATES-RATE'
   V904    = 'Y6-900:BARBITURATES-EPISODIC'
   V905    = 'Y6-901:CODEINE-FREQ'
   V906    = 'Y6-902:CODEINE-RATE'
   V907    = 'Y6-903:CODEINE-EPISODIC'
   V908    = 'Y6-904:HEROIN-FREQ'
   V909    = 'Y6-905:HEROIN-RATE'
   V910    = 'Y6-906:HEROIN-EPISODIC'
   V911    = 'Y6-907:COCAINE-FREQ'
   V912    = 'Y6-908:COCAINE-RATE'
   V913    = 'Y6-909:COCAINE-EPISODIC'
   V914    = 'Y6-910:INHALANTS-FREQ'
   V915    = 'Y6-911:INHALANTS-RATE'
   V916    = 'Y6-912:INHALANTS-EPISODIC'
   V917    = 'Y6-913:ANGEL DUST-FREQ'
   V918    = 'Y6-914:ANGEL DUST-RATE'
   V919    = 'Y6-915:ANGEL DUST-EPISODIC'
   V920    = 'Y6-916:OTHER DRUGS-SUBSTANCE'
   V921    = 'Y6-917:OTHER DRUGS-FREQ'
   V922    = 'Y6-918:OTHER DRUGS-RATE'
   V923    = 'Y6-919:OTHER DRUGS-EPISODIC'
   V924    = 'Y6-920:TROUBLE W/GIRL/BOYFRIEND-ALCOHOL'
   V925    = 'Y6-921:TROUBLE W/GIRL/BOYFRIEND-MARIJ'
   V926    = 'Y6-922:TROUBLE W/GIRL/BOYFRIEND-DRUGS'
   V927    = 'Y6-923:TROUBLE W/FRIENDS-ALCOHOL'
   V928    = 'Y6-924:TROUBLE W/FRIENDS-MARIJUANA'
   V929    = 'Y6-925:TROUBLE W/FRIENDS-DRUGS'
   V930    = 'Y6-926:PROBLEMS W/FAMILY-ALCOHOL'
   V931    = 'Y6-927:PROBLEMS W/FAMILY-MARIJUANA'
   V932    = 'Y6-928:PROBLEMS W/FAMILY-DRUGS'
   V933    = 'Y6-929:GOTTEN INTO FIGHTS-ALCOHOL'
   V934    = 'Y6-930:GOTTEN INTO FIGHTS-MARIJUANA'
   V935    = 'Y6-931:GOTTEN INTO FIGHTS-DRUGS'
   V936    = 'Y6-932:PROBS W/PHYS HEALTH-ALCOHOL'
   V937    = 'Y6-933:PROBS W/PHYS HEALTH-MARIJUANA'
   V938    = 'Y6-934:PROBS W/PHYS HEALTH-DRUGS'
   V939    = 'Y6-935:TROUBLE W/POLICE-ALCOHOL'
   V940    = 'Y6-936:TROUBLE W/POLICE-MARIJUANA'
   V941    = 'Y6-937:TROUBLE W/POLICE-DRUGS'
   V942    = 'Y6-938:ACCIDENTS WHILE DRIVE-ALCOHOL'
   V943    = 'Y6-939:ACCIDENTS WHILE DRIVE-MARIJUANA'
   V944    = 'Y6-940:ACCIDENTS WHILE DRIVE-DRUGS'
   V945    = 'Y6-941:CALLED IN SICK WORK-ALCOHOL'
   V946    = 'Y6-942:CALLED IN SICK WORK-MARIJUANA'
   V947    = 'Y6-943:CALLED IN SICK WORK-DRUGS'
   V948    = 'Y6-944:DONE ILLEGAL-ALCOHOL'
   V949    = 'Y6-945:DONE ILLEGAL-MARIJUANA'
   V950    = 'Y6-946:DONE ILLEGAL-DRUGS'
   V951    = 'Y6-947:STEAL SOMETHING'
   V952    = 'Y6-948:PROSTITUTION'
   V953    = 'Y6-949:GAMBLE'
   V954    = 'Y6-950:SELL DRUGS OR ALCOHOL'
   V955    = 'Y6-951:SELL THINGS NOT YOURS'
   V956    = 'Y6-952:BEAT SOMEONE UP'
   V957    = 'Y6-953:BOUGHT ALCOHOL WHILE UNDERAGE'
   V958    = 'Y6-954:USE FAKE ID'
   V959    = 'Y6-955:STEAL ALCOHOL OR DRUGS'
   V960    = 'Y6-956:FAKE PRESCRIPTION'
   V961    = 'Y6-957:FAKE ILLNESS'
   V962    = 'Y6-958:OTHER'
   V963    = 'Y6-959:DRUNK ON ALCOHOL PAST YEAR'
   V964    = 'Y6-960:DRUNK WHILE DRIVING'
   V965    = 'Y6-961:DRUNK WHILE AT WORK'
   V966    = 'Y6-962:HIGH ON MARIJUANA PAST YEAR'
   V967    = 'Y6-963:HIGH ON MARIJUANA WHILE DRIVING'
   V968    = 'Y6-964:HIGH ON MARIJUANA WHILE AT WORK'
   V969    = 'Y6-965:HIGH ON OTHER DRUGS PAST YEAR'
   V970    = 'Y6-966:HIGH ON OTHER DRUGS WHILE DRIVING'
   V971    = 'Y6-967:HIGH ON OTHER DRUGS WHILE AT WORK'
   V972    = 'Y6-968:DAMAGE FAMILY PROPERTY-1981'
   V973    = 'Y6-969:DAMAGE FAMILY PROPERTY-1982'
   V974    = 'Y6-970:DAMAGE SCHOOL PROPERTY-1981'
   V975    = 'Y6-971:DAMAGE SCHOOL PROPERTY-1982'
   V976    = 'Y6-972:DAMAGE EMPLOYER''S PROPERTY-1981'
   V977    = 'Y6-973:DAMAGE EMPLOYER''S PROPERTY-1982'
   V978    = 'Y6-974:DAMAGE OTHER PROPERTY-1981'
   V979    = 'Y6-975:DAMAGE OTHER PROPERTY-1982'
   V980    = 'Y6-976:STOLEN MOTOR VEHICLE-1981'
   V981    = 'Y6-977:STOLEN MOTOR VEHICLE-1982'
   V982    = 'Y6-978:STOLEN SOMETHING > $50-1981'
   V983    = 'Y6-979:STOLEN SOMETHING > $50-1982'
   V984    = 'Y6-980:BOUGHT STOLEN GOODS-1981'
   V985    = 'Y6-981:BOUGHT STOLEN GOODS-1982'
   V986    = 'Y6-982:SET FIRE TO PROPERTY-1981'
   V987    = 'Y6-983:SET FIRE TO PROPERTY-1982'
   V988    = 'Y6-984:CARRIED A HIDDEN WEAPON-1981'
   V989    = 'Y6-985:CARRIED A HIDDEN WEAPON-1982'
   V990    = 'Y6-986:STOLEN SOMETHING < $5-1981'
   V991    = 'Y6-987:STOLEN SOMETHING < $5-1982'
   V992    = 'Y6-988:ATTACKED SOMEONE-1981'
   V993    = 'Y6-989:ATTACKED SOMEONE-1982'
   V994    = 'Y6-990:BEEN PAID FOR SEX RELATIONS-1981'
   V995    = 'Y6-991:BEEN PAID FOR SEX RELATIONS-1982'
   V996    = 'Y6-992:BEEN IN GANG FIGHTS-1981'
   V997    = 'Y6-993:BEEN IN GANG FIGHTS-1982'
   V998    = 'Y6-994:USED CHECKS ILLEGALLY-1981'
   V999    = 'Y6-995:USED CHECKS ILLEGALLY-1982'
   V1000   = 'Y6-996:SOLD MARIJUANA-1981'
   V1001   = 'Y6-997:SOLD MARIJUANA-1982'
   V1002   = 'Y6-998:HITCHHIKED WHERE ILLEGAL-1981'
   V1003   = 'Y6-999:HITCHHIKED WHERE ILLEGAL-1982'
   V1004   = 'Y6-1000:STOLEN MONEY F/FAMILY-1981'
   V1005   = 'Y6-1001:STOLEN MONEY F/FAMILY-1982'
   V1006   = 'Y6-1002:STOLEN MONEY F/EMPOLYER-1981'
   V1007   = 'Y6-1003:STOLEN MONEY F/EMPOLYER-1982'
   V1008   = 'Y6-1004:SEX RELATIONS AGAINST WILL-1981'
   V1009   = 'Y6-1005:SEX RELATIONS AGAINST WILL-1982'
   V1010   = 'Y6-1006:HIT TEACHER-1981'
   V1011   = 'Y6-1007:HIT TEACHER-1982'
   V1012   = 'Y6-1008:HIT PARENT-1981'
   V1013   = 'Y6-1009:HIT PARENT-1982'
   V1014   = 'Y6-1010:HIT OTHER STUDENTS-1981'
   V1015   = 'Y6-1011:HIT OTHER STUDENTS-1982'
   V1016   = 'Y6-1012:HIT SOMEONE AT WORK-1981'
   V1017   = 'Y6-1013:HIT SOMEONE AT WORK-1982'
   V1018   = 'Y6-1014:HIT ANYONE ELSE-1981'
   V1019   = 'Y6-1015:HIT ANYONE ELSE-1982'
   V1020   = 'Y6-1016:BEEN LOWD/ROWDY-1981'
   V1021   = 'Y6-1017:BEEN LOWD/ROWDY-1982'
   V1022   = 'Y6-1018:SOLD HARD DRUGS-1981'
   V1023   = 'Y6-1019:SOLD HARD DRUGS-1982'
   V1024   = 'Y6-1020:TRIED SELL WORTHLESS-1981'
   V1025   = 'Y6-1021:TRIED SELL WORTHLESS-1982'
   V1026   = 'Y6-1022:TAKEN VEHICLE-1981'
   V1027   = 'Y6-1023:TAKEN VEHICLE-1982'
   V1028   = 'Y6-1024:BOUGHT LIQUOR-1981'
   V1029   = 'Y6-1025:BOUGHT LIQUOR-1982'
   V1030   = 'Y6-1026:USED FORCE ON STUDENTS-1981'
   V1031   = 'Y6-1027:USED FORCE ON STUDENTS-1982'
   V1032   = 'Y6-1028:USED FORCE ON OTHERS-1981'
   V1033   = 'Y6-1029:USED FORCE ON OTHERS-1982'
   V1034   = 'Y6-1030:AVOIDED PAYING FOR THINGS-1981'
   V1035   = 'Y6-1031:AVOIDED PAYING FOR THINGS-1982'
   V1036   = 'Y6-1032:BEEN DRUNK IN PUBLIC-1981'
   V1037   = 'Y6-1033:BEEN DRUNK IN PUBLIC-1982'
   V1038   = 'Y6-1034:STOLEN THINGS-1981'
   V1039   = 'Y6-1035:STOLEN THINGS-1982'
   V1040   = 'Y6-1036:STOLEN THINGS AT SCHOOL-1981'
   V1041   = 'Y6-1037:STOLEN THINGS AT SCHOOL-1982'
   V1042   = 'Y6-1038:BROKEN INTO BUILDING-1981'
   V1043   = 'Y6-1039:BROKEN INTO BUILDING-1982'
   V1044   = 'Y6-1040:BEGGED FOR MONEY-1981'
   V1045   = 'Y6-1041:BEGGED FOR MONEY-1982'
   V1046   = 'Y6-1042:FAILED TO RETURN CHANGE-1981'
   V1047   = 'Y6-1043:FAILED TO RETURN CHANGE-1982'
   V1048   = 'Y6-1044:USED CREDIT W/O PERMISSION-1981'
   V1049   = 'Y6-1045:USED CREDIT W/O PERMISSION-1982'
   V1050   = 'Y6-1046:OBSCENE PHONE CALLS-1981'
   V1051   = 'Y6-1047:OBSCENE PHONE CALLS-1982'
   V1052   = 'Y6-1048:USED ALCOHOLIC BEVERAGES-1981'
   V1053   = 'Y6-1049:USED ALCOHOLIC BEVERAGES-1982'
   V1054   = 'Y6-1050:USED MARIJUANA-1981'
   V1055   = 'Y6-1051:USED MARIJUANA-1982'
   V1056   = 'Y6-1052:USED HALLUCINOGENS-1981'
   V1057   = 'Y6-1053:USED HALLUCINOGENS-1982'
   V1058   = 'Y6-1054:USED TRANQUILIZERS-1981'
   V1059   = 'Y6-1055:USED TRANQUILIZERS-1981'
   V1060   = 'Y6-1056:USED AMPHETAMINES-1981'
   V1061   = 'Y6-1057:USED AMPHETAMINES-1982'
   V1062   = 'Y6-1058:USED BARBITURATES-1981'
   V1063   = 'Y6-1059:USED BARBITURATES-1982'
   V1064   = 'Y6-1060:USED COCAINE-1981'
   V1065   = 'Y6-1061:USED COCAINE-1982'
   V1066   = 'Y6-1062:EVER ARRESTED'
   V1067   = 'Y6-1063:ARRESTS 1ST EVENT-MONTH'
   V1068   = 'Y6-1064:ARRESTS 1ST EVENT-YEAR'
   V1069   = 'Y6-1065:ARREST 1ST EVENT-1ST THING DOING'
   V1070   = 'Y6-1066:ARREST 1ST EVENT-2ND THING DOING'
   V1071   = 'Y6-1067:ARREST 1ST EVENT-3RD THING DOING'
   V1072   = 'Y6-1068:ARRESTS 1ST EVENT-1ST CHARGE'
   V1073   = 'Y6-1069:ARRESTS 1ST EVENT-2ND CHARGE'
   V1074   = 'Y6-1070:ARRESTS 1ST EVENT-3RD CHARGE'
   V1075   = 'Y6-1071:ARRESTS 1ST EVENT-DO POL CHARGE'
   V1076   = 'Y6-1072:ARRESTS 2ND EVENT-MONTH'
   V1077   = 'Y6-1073:ARRESTS 2ND EVENT-YEAR'
   V1078   = 'Y6-1074:ARREST 2ND EVENT-1ST THING DOING'
   V1079   = 'Y6-1075:ARREST 2ND EVENT-2ND THING DOING'
   V1080   = 'Y6-1076:ARREST 2ND EVENT-3RD THING DOING'
   V1081   = 'Y6-1077:ARRESTS 2ND EVENT-1ST CHARGE'
   V1082   = 'Y6-1078:ARRESTS 2ND EVENT-2ND CHARGE'
   V1083   = 'Y6-1079:ARRESTS 2ND EVENT-3RD CHARGE'
   V1084   = 'Y6-1080:ARRESTS 2ND EVENT-DO POL CHARGE'
   V1085   = 'Y6-1081:ARRESTS 3RD EVENT-MONTH'
   V1086   = 'Y6-1082:ARRESTS 3RD EVENT-YEAR'
   V1087   = 'Y6-1083:ARRESTS 3RD EVENT-1ST THING'
   V1088   = 'Y6-1084:ARRESTS 3RD EVENT-2ND THING'
   V1089   = 'Y6-1085:ARRESTS 3RD EVENT-3RD THING'
   V1090   = 'Y6-1086:ARRESTS 3RD EVENT-1ST CHARGE'
   V1091   = 'Y6-1087:ARRESTS 3RD EVENT-2ND CHARGE'
   V1092   = 'Y6-1088:ARRESTS 3RD EVENT-3RD CHARGE'
   V1093   = 'Y6-1089:ARRESTS 3RD EVENT-DO POL CHARGE'
   V1094   = 'Y6-1090:Q. POLICE 1ST EVENT-EVER QUEST'
   V1095   = 'Y6-1091:Q. POLICE 1ST EVENT-MONTH'
   V1096   = 'Y6-1092:Q. POLICE 1ST EVENT-YEAR'
   V1097   = 'Y6-1093:Q. POL 1ST EVENT-Q. ABOUT WHAT'
   V1098   = 'Y6-1094:Q. POLICE 1ST EVENT-COMMIT OFF'
   V1099   = 'Y6-1095:Q. POLICE 1ST EVENT-POLICE DO'
   V1100   = 'Y6-1096:Q. POLICE 2ND EVENT-MONTH'
   V1101   = 'Y6-1097:Q. POLICE 2ND EVENT-YEAR'
   V1102   = 'Y6-1098:Q. POL 2ND EVENT-Q. ABOUT WHAT'
   V1103   = 'Y6-1099:Q. POLICE 2ND EVENT-COMMIT OFF'
   V1104   = 'Y6-1100:Q. POLICE 2ND EVENT-POLICE DO'
   V1105   = 'Y6-1101:Q. POLICE 3RD EVENT-MONTH'
   V1106   = 'Y6-1102:Q. POLICE 3RD EVENT-YEAR'
   V1107   = 'Y6-1103:Q. POL 3RD EVENT-Q. ABOUT WHAT'
   V1108   = 'Y6-1104:Q. POLICE 3RD EVENT-COMMIT OFF'
   V1109   = 'Y6-1105:Q. POLICE 3RD EVENT-POLICE DO'
   V1110   = 'Y6-1106:CHANCE ARR-EXCD LIMIT 10-20 MPH'
   V1111   = 'Y6-1107:CHANCE ARR-STEAL < $5'
   V1112   = 'Y6-1108:CHANCE ARR-STEAL > $50'
   V1113   = 'Y6-1109:CHANCE ARR-BREAK INTO BUILDING'
   V1114   = 'Y6-1110:CHANCE ARR-STRONGARM OTHERS'
   V1115   = 'Y6-1111:CHANCE ARR-ATTACK SOMEONE'
   V1116   = 'Y6-1112:PUNISHMENT-EXCD LIMIT 10-20 MPH'
   V1117   = 'Y6-1113:PUNISHMENT-STEAL < $5'
   V1118   = 'Y6-1114:PUNISHMENT-STEAL > $50'
   V1119   = 'Y6-1115:PUNISHMENT-BREAK INTO BUILDING'
   V1120   = 'Y6-1116:PUNISHMENT-STRONGARM OTHERS'
   V1121   = 'Y6-1117:PUNISHMENT-ATTACK SOMEONE'
   V1122   = 'Y6-1118:GUILT-EXCEED LIMIT 10-20 MPH'
   V1123   = 'Y6-1119:GUILT-STEAL SOMETHING < $5'
   V1124   = 'Y6-1120:GUILT-STEAL SOMETHING > $50'
   V1125   = 'Y6-1121:GUILT-BREAK INTO BUILDING'
   V1126   = 'Y6-1122:GUILT-STRONGARM OTHERS'
   V1127   = 'Y6-1123:GUILT-ATTACK SOMEONE'
   V1128   = 'Y6-1124:GUILT-EXCD LIMIT 10-20 MPH HELP'
   V1129   = 'Y6-1125:GUILT-STEAL < $5 STORE OVERCHRGE'
   V1130   = 'Y6-1126:GUILT-STEAL > $50 COVER INSURNCE'
   V1131   = 'Y6-1127:GUILT-BREAK INTO BLDG OWN CROOK'
   V1132   = 'Y6-1128:GUILT-STRONGARM TO GET CAN''T PAY'
   V1133   = 'Y6-1129:GUILT-ATTACK BECAUSE OF ARGUMENT'
   V1134   = 'Y6-1130:THINGS TAKEN FROM YOU'
   V1135   = 'Y6-1131:BEATEN UP BY PARENT'
   V1136   = 'Y6-1132:BEATEN BY PARENT-FORCED SEX'
   V1137   = 'Y6-1133:PAR/FORCED SEX-THREAT/INJ WEAPON'
   V1138   = 'Y6-1134:PAR/FORCED SEX-SERIOUSLY INJURED'
   V1139   = 'Y6-1135:PAR/FORCED SEX-FORCED SEX REL'
   V1140   = 'Y6-1136:BEATEN UP BY OTHERS'
   V1141   = 'Y6-1137:BEATEN UP BY OTHS-BROTHER'
   V1142   = 'Y6-1138:BEATEN UP BY OTHS-SISTER'
   V1143   = 'Y6-1139:BEATEN UP BY OTHS-TEACHER'
   V1144   = 'Y6-1140:BEATEN UP BY OTHS-SPOUSE'
   V1145   = 'Y6-1141:BEATEN UP BY OTHS-STUDENT'
   V1146   = 'Y6-1142:BEATEN UP BY OTHS-GANG'
   V1147   = 'Y6-1143:BEATEN UP BY OTHS-OTHER ADULT'
   V1148   = 'Y6-1144:BEATEN UP BY OTHS-BOY/GIRLFRIEND'
   V1149   = 'Y6-1145:BEATEN UP BY OTHS-OTHER YOUTH'
   V1150   = 'Y6-1146:BEATEN UP BY OTHS-OTHER'
   V1151   = 'Y6-1147:BEATEN UP BY OTHERS-FORCED SEX'
   V1152   = 'Y6-1148:BEAT OTHS/FOR SEX-THRT/INJ WEAP'
   V1153   = 'Y6-1149:BEAT OTHS/FORCE SEX-SERIOUS INJ'
   V1154   = 'Y6-1150:BEAT OTHS/FORCE SEX-FORCED SEX'
   V1155   = 'Y6-1151:ATTACKED W/WEAPON'
   V1156   = 'Y6-1152:ATTACK W/WEAPON-BROTHER'
   V1157   = 'Y6-1153:ATTACK W/WEAPON-SISTER'
   V1158   = 'Y6-1154:ATTACK W/WEAPON-TEACHER'
   V1159   = 'Y6-1155:ATTACK W/WEAPON-SPOUSE'
   V1160   = 'Y6-1156:ATTACK W/WEAPON-STUDENT'
   V1161   = 'Y6-1157:ATTACK W/WEAPON-GANG'
   V1162   = 'Y6-1158:ATTACK W/WEAPON-OTHER ADULT'
   V1163   = 'Y6-1159:ATTACK W/WEAPON-BOY/GIRLFRIEND'
   V1164   = 'Y6-1160:ATTACK W/WEAPON-OTHER YOUTH'
   V1165   = 'Y6-1161:ATTACK W/WEAPON-OTHER'
   V1166   = 'Y6-1162:ATTACK W/WEAPON-FORCED SEX'
   V1167   = 'Y6-1163:ATTACK/FORCE SEX-THREAT/INJ WEAP'
   V1168   = 'Y6-1164:ATTACK/FORCE SEX-SERIOUS INJURY'
   V1169   = 'Y6-1165:ATTACK/FORCE SEX-FORCED SEX'
   V1170   = 'Y6-1166:MOTOR VEHICLE OR BIKE STOLEN'
   V1171   = 'Y6-1167:THINGS TAKEN FROM CAR'
   V1172   = 'Y6-1168:SEXUALLY ATTACKED'
   V1173   = 'Y6-1169:SEXUALLY ATTACKED-BROTHER'
   V1174   = 'Y6-1170:SEXUALLY ATTACKED-SISTER'
   V1175   = 'Y6-1171:SEXUALLY ATTACKED-TEACHER'
   V1176   = 'Y6-1172:SEXUALLY ATTACKED-SPOUSE'
   V1177   = 'Y6-1173:SEXUALLY ATTACKED-STUDENT'
   V1178   = 'Y6-1174:SEXUALLY ATTACKED-GANG'
   V1179   = 'Y6-1175:SEXUALLY ATTACKED-OTHER ADULT'
   V1180   = 'Y6-1176:SEXUALLY ATTACKED-BOY/GIRLFRIEND'
   V1181   = 'Y6-1177:SEXUALLY ATTACKED-OTHER YOUTH'
   V1182   = 'Y6-1178:SEXUALLY ATTACKED-OTHER'
   V1183   = 'Y6-1179:SEX ATTACK-THREAT/INJURED WEAPON'
   V1184   = 'Y6-1180:SEX ATTACK-SERIOUSLY INJURED'
   V1185   = 'Y6-1181:SEX ATTACK-FORCED SEX'
   V1186   = 'Y6-1182:THINGS DAMAGED'
   V1187   = 'Y6-1183:THINGS STOLEN FROM PUBLIC PLACE'
   V1188   = 'Y6-1184:SEXUALLY PRESSURED'
   V1189   = 'Y6-1185:SEX PRESSURE-THREAT/INJ WEAPON'
   V1190   = 'Y6-1186:SEX PRESSURE-SERIOUSLY INJURED'
   V1191   = 'Y6-1187:SEX PRESSURE-FORCED SEX'
   V1192   = 'Y6-1188:POCKET PICKED'
   V1193   = 'Y6-1189:SEX ASSAULT-MORE THAN 1 BOX ITEM'
   V1194   = 'Y6-1190:SEX ASSAULTS-NO. NONREDUNDANT'
   V1195   = 'Y6-1191:SEX ASSAULT-ITEM NO. MOST RECENT'
   V1196   = 'Y6-1192:WHAT IS YOUR CURRENT WEIGHT'
   V1197   = 'Y6-1193:WHAT IS YOUR HEIGHT'
   V1198   = 'Y6-1194:EAT TOO MUCH JUNK FOOD'
   V1199   = 'Y6-1195:EAT WELL BALANCED MEALS'
   V1200   = 'Y6-1196:EXERCISE ON A REGULAR BASIS'
   V1201   = 'Y6-1197:PHYS PROBLEMS RESTRICT ACTIVITY'
   V1202   = 'Y6-1198:1ST PHYSICAL PROBLEM'
   V1203   = 'Y6-1199:2ND PHYSICAL PROBLEM'
   V1204   = 'Y6-1200:3RD PHYSICAL PROBLEM'
   V1205   = 'Y6-1201:4TH PHYSICAL PROBLEM'
   V1206   = 'Y6-1202:EVER HAD A VENERAL DISEASE'
   V1207   = 'Y6-1203:IF YES:WHAT TYPE OF V.D.'
   V1208   = 'Y6-1204:PROBLEMS BECAUSE OF IT'
   V1209   = 'Y6-1205:GENERAL PHYSICAL HEALTH'
   V1210   = 'Y6-1206:HAVE YOU EVER BEEN PREGNANT'
   V1211   = 'Y6-1207:PREGNANCY 1ST-YEAR'
   V1212   = 'Y6-1208:PREGNANCY 1ST-OUTCOME'
   V1213   = 'Y6-1209:PREGNANCY 1ST-1ST PROBLEM'
   V1214   = 'Y6-1210:PREGNANCY 1ST-2ND PROBLEM'
   V1215   = 'Y6-1211:PREGNANCY 1ST-VOLUNTARY ABORTION'
   V1216   = 'Y6-1212:PREGNANCY 2ND-YEAR'
   V1217   = 'Y6-1213:PREGNANCY 2ND-OUTCOME'
   V1218   = 'Y6-1214:PREGNANCY 2ND-1ST PROBLEM'
   V1219   = 'Y6-1215:PREGNANCY 2ND-2ND PROBLEM'
   V1220   = 'Y6-1216:PREGNANCY 2ND-VOLUNTARY ABORTION'
   V1221   = 'Y6-1217:PREGNANCY 3RD-YEAR'
   V1222   = 'Y6-1218:PREGNANCY 3RD-OUTCOME'
   V1223   = 'Y6-1219:PREGNANCY 3RD-1ST PROBLEM'
   V1224   = 'Y6-1220:PREGNANCY 3RD-2ND PROBLEM'
   V1225   = 'Y6-1221:PREGNANCY 3RD-VOLUNTARY ABORTION'
   V1226   = 'Y6-1222:PREGNANCY 4TH-YEAR'
   V1227   = 'Y6-1223:PREGNANCY 4TH-OUTCOME'
   V1228   = 'Y6-1224:PREGNANCY 4TH-PROBLEM'
   V1229   = 'Y6-1225:PREGNANCY 4TH-VOLUNTARY ABORTION'
   V1230   = 'Y6-1226:PREGNANCY 5TH-YEAR'
   V1231   = 'Y6-1227:PREGNANCY 5TH-OUTCOME'
   V1232   = 'Y6-1228:PREGNANCY 5TH-PROBLEM'
   V1233   = 'Y6-1229:PREGNANCY 5TH-VOLUNTARY ABORTION'
   V1234   = 'Y6-1230:EFFECTS FROM 1ST EVENT'
   V1235   = 'Y6-1231:EFFECTS 1ST EVENT-1ST EFFECT'
   V1236   = 'Y6-1232:EFFECTS 1ST EVENT-2ND EFFECT'
   V1237   = 'Y6-1233:EFFECTS 1ST EVENT-3RD EFFECT'
   V1238   = 'Y6-1234:EFFECTS FROM 2ND EVENT'
   V1239   = 'Y6-1235:EFFECTS F/2ND EVENT-ONE EFFECT'
   V1240   = 'Y6-1236:EFFECTS AT PRESENT FROM EVENT'
   V1241   = 'Y6-1237:EFFECTS PRESENT EVENT-1ST EFFECT'
   V1242   = 'Y6-1238:EFFECTS PRESENT EVENT-2ND EFFECT'
   V1243   = 'Y6-1239:DIDN''T CARE ABOUT GOALS PAST YR'
   V1244   = 'Y6-1240:GOALS-RELATED TO MARIJUANA'
   V1245   = 'Y6-1241:GOALS-RELATED TO ALCOHOL'
   V1246   = 'Y6-1242:GOALS-RELATED TO OTHER DRUGS'
   V1247   = 'Y6-1243:EVER DEPRESSED FOR 2 WKS OR MORE'
   V1248   = 'Y6-1244:DEPRESSION-LOSS OF APPETITE'
   V1249   = 'Y6-1245:DEPRESSION-LOSS OF WEIGHT'
   V1250   = 'Y6-1246:DEPRESSION-WEIGHT GAIN'
   V1251   = 'Y6-1247:DEPRESSION-APPETITE SUMMARY'
   V1252   = 'Y6-1248:DEPRESSION-INSOMNIA'
   V1253   = 'Y6-1249:DEPRESSION-SLEEP TOO MUCH'
   V1254   = 'Y6-1250:DEPRESSION-SLEEP SUMMARY'
   V1255   = 'Y6-1251:DEPRESSION-TIRED ALL THE TIME'
   V1256   = 'Y6-1252:DEPRESSION-TIRED SUMMARY'
   V1257   = 'Y6-1253:DEPRESSION-TALK/MOVE SLOWER'
   V1258   = 'Y6-1254:DEPRESSION-UNABLE TO BE STILL'
   V1259   = 'Y6-1255:DEPRESSION-SLOW/RESTLESS SUMMARY'
   V1260   = 'Y6-1256:DEPRESSION-LOST INTEREST IN SEX'
   V1261   = 'Y6-1257:DEPRESSION-LOST INTEREST SUMMARY'
   V1262   = 'Y6-1258:DEPRESSION-TROUBLE CONCENTRATING'
   V1263   = 'Y6-1259:DEPRESSION-THOUGHTS SLOW/MIX UP'
   V1264   = 'Y6-1260:DEPRESSION-TROUBLE THINK SUMMARY'
   V1265   = 'Y6-1261:DEPRESSION-FELT WORTHLESS/GUILTY'
   V1266   = 'Y6-1262:DEPRESSION-WORTHLESS SUMMARY'
   V1267   = 'Y6-1263:DEPRESSION-THOUGHT DEATH GENERAL'
   V1268   = 'Y6-1264:DEPRESSION-WANTED TO DIE'
   V1269   = 'Y6-1265:DEPRESSION-THOUGHT OF SUICIDE'
   V1270   = 'Y6-1266:DEPRESSION-ATTEMPTED SUICIDE'
   V1271   = 'Y6-1267:DEPRESSION-THOUGHT DEATH SUMMARY'
   V1272   = 'Y6-1268:FLAG FOR DEPRESSION'
   V1273   = 'Y6-1269:DEPRESS OTH PROBS OCCUR TOGETHER'
   V1274   = 'Y6-1270:NOT BLUE PLUS OTHER SYMPTOMS'
   V1275   = 'Y6-1271:LONG TIME DEPRESS/OTH SYMP-YRS'
   V1276   = 'Y6-1272:LONG TIME DEPRESS/OTH SYMP-MOS'
   V1277   = 'Y6-1273:LONG TIME DEPRESS/OTH SYMP-WKS'
   V1278   = 'Y6-1274:LONG TIME DEPRESS/OTH SYMP-DYS'
   V1279   = 'Y6-1275:NO. EPISODE DEPRESS/OTH SYMPTOMS'
   V1280   = 'Y6-1276:SEE DOCTOR ABOUT ANY EPISODES'
   V1281   = 'Y6-1277:SEE PROFESSIONAL ABOUT EPISODES'
   V1282   = 'Y6-1278:MEDICINE > ONCE FOR FOR EPISODES'
   V1283   = 'Y6-1279:EPISODES INTERFERE W/LIFE'
   V1284   = 'Y6-1280:AGE AT 1ST EPISODE'
   V1285   = 'Y6-1281:EPISODE OCCR AFT DEATH LOVED ONE'
   V1286   = 'Y6-1282:ANY EPISODE NOT ASSOC W/DEATH'
   V1287   = 'Y6-1283:DEPRESSED PLUS OTHER SYMPTOM NOW'
   V1288   = 'Y6-1284:WHEN LAST SUCH EPISODE ENDED'
   V1289   = 'Y6-1285:HOW OLD THEN'
   V1290   = 'Y6-1286:SEEING PROFESSIONAL FOR EPISODE'
   V1291   = 'Y6-1288:HELP FRIEND/RELATIVE-FREQ'
   V1292   = 'Y6-1289:HELP FRIEND/RELATIVE-1ST PROB'
   V1293   = 'Y6-1290:HELP FRIEND/RELATIVE-2ND PROB'
   V1294   = 'Y6-1291:HELP FRIEND/RELATIVE-3RD PROB'
   V1295   = 'Y6-1292:HELP FRIEND/RELATIVE-AMOUNT HELP'
   V1296   = 'Y6-1293:HELP MINISTER/RABBI-FREQ'
   V1297   = 'Y6-1294:HELP MINISTER/RABBI-1ST PROB'
   V1298   = 'Y6-1295:HELP MINISTER/RABBI-2ND PROB'
   V1299   = 'Y6-1296:HELP MINISTER/RABBI-3RD PROB'
   V1300   = 'Y6-1297:HELP MINISTER/RABBI-AMOUNT HELP'
   V1301   = 'Y6-1298:HELP PYSCH/COUNSEL-FREQ'
   V1302   = 'Y6-1299:HELP PYSCH/COUNSEL-1ST PROB'
   V1303   = 'Y6-1300:HELP PYSCH/COUNSEL-2ND PROB'
   V1304   = 'Y6-1301:HELP PYSCH/COUNSEL-3RD PROB'
   V1305   = 'Y6-1302:HELP PYSCH/COUNSEL-AMOUNT HELP'
   V1306   = 'Y6-1303:HELP MEDICAL DR-FREQ'
   V1307   = 'Y6-1304:HELP MEDICAL DR-1ST PROB'
   V1308   = 'Y6-1305:HELP MEDICAL DR-2ND PROB'
   V1309   = 'Y6-1306:HELP MEDICAL DR-3RD PROB'
   V1310   = 'Y6-1307:HELP MEDICAL DR-AMOUNT HELP'
   V1311   = 'Y6-1308:HELP SPIRIT/HEALER-FREQ'
   V1312   = 'Y6-1309:HELP SPIRIT/HEALER-1ST PROB'
   V1313   = 'Y6-1310:HELP SPIRIT/HEALER-2ND PROB'
   V1314   = 'Y6-1311:HELP SPIRIT/HEALER-3RD PROB'
   V1315   = 'Y6-1312:HELP SPIRIT/HEALER-AMOUNT HELP'
   V1316   = 'Y6-1313:HELP ANYONE ELSE-FREQ'
   V1317   = 'Y6-1314:HELP ANYONE ELSE-1ST PROB'
   V1318   = 'Y6-1315:HELP ANYONE ELSE-2ND PROB'
   V1319   = 'Y6-1316:HELP ANYONE ELSE-3RD PROB'
   V1320   = 'Y6-1317:HELP ANYONE ELSE-AMOUNT HELP'
   V1321   = 'Y6-1318:HELP MENTAL HEALTH-FREQ'
   V1322   = 'Y6-1319:HELP MENTAL HEALTH-1ST PROB'
   V1323   = 'Y6-1320:HELP MENTAL HEALTH-2ND PROB'
   V1324   = 'Y6-1321:HELP MENTAL HEALTH-3RD PROB'
   V1325   = 'Y6-1322:HELP MENTAL HEALTH-AMOUNT HELP'
   V1326   = 'Y6-1323:HELP PSYCH/OUT CLINIC-FREQ'
   V1327   = 'Y6-1324:HELP PSYCH/OUT CLINIC-1ST PROB'
   V1328   = 'Y6-1325:HELP PSYCH/OUT CLINIC-2ND PROB'
   V1329   = 'Y6-1326:HELP PSYCH/OUT CLINIC-3RD PROB'
   V1330   = 'Y6-1327:HELP PSYCH/OUT CLINIC-AMOUNT HLP'
   V1331   = 'Y6-1328:HELP OUT CLINIC PSYCH-FREQ'
   V1332   = 'Y6-1329:HELP OUT CLINIC PSYCH-1ST PROB'
   V1333   = 'Y6-1330:HELP OUT CLINIC PSYCH-2ND PROB'
   V1334   = 'Y6-1331:HELP OUT CLINIC PSYCH-3RD PROB'
   V1335   = 'Y6-1332:HELP OUT CLINIC PSYCH-AMOUNT HLP'
   V1336   = 'Y6-1333:HELP DRUG CLINIC-FREQ'
   V1337   = 'Y6-1334:HELP DRUG CLINIC-1ST PROB'
   V1338   = 'Y6-1335:HELP DRUG CLINIC-2ND PROB'
   V1339   = 'Y6-1336:HELP DRUG CLINIC-3RD PROB'
   V1340   = 'Y6-1337:HELP DRUG CLINIC-AMOUNT HELP'
   V1341   = 'Y6-1338:HELP ALCOHOLIC CLINIC-FREQ'
   V1342   = 'Y6-1339:HELP ALCOHOLIC CLINIC-1ST PROB'
   V1343   = 'Y6-1340:HELP ALCOHOLIC CLINIC-2ND PROB'
   V1344   = 'Y6-1341:HELP ALCOHOLIC CLINIC-3RD PROB'
   V1345   = 'Y6-1342:HELP ALCOHOLIC CLINIC-AMOUNT HLP'
   V1346   = 'Y6-1343:HELP EMERGENCY ROOM-FREQ'
   V1347   = 'Y6-1344:HELP EMERGENCY ROOM-1ST PROB'
   V1348   = 'Y6-1345:HELP EMERGENCY ROOM-2ND PROB'
   V1349   = 'Y6-1346:HELP EMERGENCY ROOM-3RD PROB'
   V1350   = 'Y6-1347:HELP EMERGENCY ROOM-AMOUNT HELP'
   V1351   = 'Y6-1348:HELP FAM/SOC AGENCY-FREQ'
   V1352   = 'Y6-1349:HELP FAM/SOC AGENCY-1ST PROB'
   V1353   = 'Y6-1350:HELP FAM/SOC AGENCY-2ND PROB'
   V1354   = 'Y6-1351:HELP FAM/SOC AGENCY-3RD PROB'
   V1355   = 'Y6-1352:HELP FAM/SOC AGENCY-AMOUNT HELP'
   V1356   = 'Y6-1353:HELP SELF-HELP GROUP-FREQ'
   V1357   = 'Y6-1354:HELP SELF-HELP GROUP-1ST PROB'
   V1358   = 'Y6-1355:HELP SELF-HELP GROUP-2ND PROB'
   V1359   = 'Y6-1356:HELP SELF-HELP GROUP-3RD PROB'
   V1360   = 'Y6-1357:HELP SELF-HELP GROUP-AMOUNT HELP'
   V1361   = 'Y6-1358:HELP CRISIS/HOTLINE-FREQ'
   V1362   = 'Y6-1359:HELP CRISIS/HOTLINE-1ST PROB'
   V1363   = 'Y6-1360:HELP CRISIS/HOTLINE-2ND PROB'
   V1364   = 'Y6-1361:HELP CRISIS/HOTLINE-3RD PROB'
   V1365   = 'Y6-1362:HELP CRISIS/HOTLINE-AMOUNT HELP'
   V1366   = 'Y6-1363:HELP OTH AGENCY/PROG-FREQ'
   V1367   = 'Y6-1364:HELP OTH AGENCY/PROG-1ST PROB'
   V1368   = 'Y6-1365:HELP OTH AGENCY/PROG-2ND PROB'
   V1369   = 'Y6-1366:HELP OTH AGENCY/PROG-3RD PROB'
   V1370   = 'Y6-1367:HELP OTH AGENCY/PROG-AMOUNT HELP'
   V1371   = 'Y6-1368:EVER ADMIT HOSP/TREAT OVERNIGHT'
   V1372   = 'Y6-1369:IF YES:WHERE (MOST RECENT)'
   V1373   = 'Y6-1370:HOW MANY NIGHTS THERE'
   V1374   = 'Y6-1371:WHAT YEAR'
   V1375   = 'Y6-1372:HELP W/PROBS-DRUGS'
   V1376   = 'Y6-1373:HELP W/PROBS-ALCOHOL'
   V1377   = 'Y6-1374:HELP W/PROBS-FAMILY RELATIONSHIP'
   V1378   = 'Y6-1375:HELP W/PROBS-TROUBLE W/THE LAW'
   V1379   = 'Y6-1376:HELP W/PROBS-DEPRESSION'
   V1380   = 'Y6-1377:HELP W/PROBS-SEXUAL RELATIONSHIP'
   V1381   = 'Y6-1378:HELP W/PROBS-PERS STRESS/NERVES'
   V1382   = 'Y6-1379:HELP W/PROBS-OTHER'
   V1383   = 'Y6-1380:HOW MUCH HELP DID YOU GET'
   V1384   = 'Y6-1381:ANY OTHER TIME ADMIT TO HOSPITAL'
   V1385   = 'Y6-1382:IF YES:WHERE (TIME BEFORE LAST)'
   V1386   = 'Y6-1383:HOW MANY NIGHTS THERE'
   V1387   = 'Y6-1384:WHAT YEAR'
   V1388   = 'Y6-1385:HELP W/PROBS-DRUGS'
   V1389   = 'Y6-1386:HELP W/PROBS-ALCOHOL'
   V1390   = 'Y6-1387:HELP W/PROBS-FAMILY RELATIONSHIP'
   V1391   = 'Y6-1388:HELP W/PROBS-TROUBLE W/THE LAW'
   V1392   = 'Y6-1389:HELP W/PROBS-DEPRESSION'
   V1393   = 'Y6-1390:HELP W/PROBS-SEXUAL RELATIONSHIP'
   V1394   = 'Y6-1391:HELP W/PROBS-PERS STRESS/NERVES'
   V1395   = 'Y6-1392:HELP W/PROBS-OTHER'
   V1396   = 'Y6-1393:HOW MUCH HELP DID YOU GET'
   V1397   = 'Y6-1394:ANY TIME NOT SEEK PROF SHOULD'
   V1398   = 'Y6-1395:PROBLEM GET BETTER BY ITSELF'
   V1399   = 'Y6-1396:CONCERNED ABOUT THE COST'
   V1400   = 'Y6-1397:DIDN''T KNOW WHERE TO GO'
   V1401   = 'Y6-1398:PROBABLY WOULDN''T DO ANY GOOD'
   V1402   = 'Y6-1399:AFRAID OTHERS WOULD FIND OUT'
   V1403   = 'Y6-1400:WANTED TO WORK IT ON OWN'
   V1404   = 'Y6-1401:OTHER'
   V1405   = 'Y6-1402:TIMES YOU-INSULT/SWORE'
   V1406   = 'Y6-1403:TIMES YOU-THREAT HIT/THROW'
   V1407   = 'Y6-1404:TIMES YOU-THREW SOMETHING'
   V1408   = 'Y6-1405:TIMES YOU-PUSHED/GRABBED/SHOVED'
   V1409   = 'Y6-1406:TIMES YOU-SLAPPED PARTNER'
   V1410   = 'Y6-1407:TIMES YOU-KICKED/BIT/HIT'
   V1411   = 'Y6-1408:TIMES YOU-HIT W/SOMETHING'
   V1412   = 'Y6-1409:TIMES YOU-BEAT UP PARTNER'
   V1413   = 'Y6-1410:TIMES YOU-THREATENED W/A GUN'
   V1414   = 'Y6-1411:TIMES YOU-USED KNIFE/FIRED GUN'
   V1415   = 'Y6-1412:TIMES PART-INSULT/SWORE'
   V1416   = 'Y6-1413:TIMES PART-THREAT HIT/THROW'
   V1417   = 'Y6-1414:TIMES PART-THREW SOMETHING'
   V1418   = 'Y6-1415:TIMES PART-PUSHED/GRABBED/SHOVED'
   V1419   = 'Y6-1416:TIMES PART-SLAPPED PARTNER'
   V1420   = 'Y6-1417:TIMES PART-KICKED/BIT/HIT'
   V1421   = 'Y6-1418:TIMES PART-HIT W/SOMETHING'
   V1422   = 'Y6-1419:TIMES PART-BEAT UP PARTNER'
   V1423   = 'Y6-1420:TIMES PART-THREATENED W/A GUN'
   V1424   = 'Y6-1421:TIMES PART-USED KNIFE/FIRED GUN'
   V1425   = 'Y6-1422:SEXUAL INTERCOURSE/OPPOSITE SEX'
   V1426   = 'Y6-1423:SEX INTER (NOT SPOUSE)-FREQ'
   V1427   = 'Y6-1424:SEX INTER (NOT SPOUSE)-RATE'
   V1428   = 'Y6-1425:SEX INTERCOURSE (SPOUSE)-FREQ'
   V1429   = 'Y6-1426:SEX INTERCOURSE (SPOUSE)-RATE'
   V1430   = 'Y6-1427:HOW MANY SEXUAL PARTNERS'
   V1431   = 'Y6-1428:PRESSURED SOMEONE SEXUALLY-FREQ'
   V1432   = 'Y6-1429:PRESSURED SOMEONE SEXUALLY-RATE'
   V1433   = 'Y6-1430:RELATIONSHIP TO PERSON PRESSURED'
   V1434   = 'Y6-1431:SEX OF PERSON PRESSURED'
   V1435   = 'Y6-1432:KIND OF PRESSURE/FORCE USED'
   V1436   = 'Y6-1433:OTHERS INVOLVED W/PRESSURING'
   V1437   = 'Y6-1434:WAS THE PERSON INJURED'
   V1438   = 'Y6-1435:SUCCEED IN FORCING SEX RELATIONS'
   V1439   = 'Y6-1436:EVENT REPORT ANY OTH QUEST ITEM'
   V1440   = 'Y6-1437:THREATENED SOMEONE FOR SEX-FREQ'
   V1441   = 'Y6-1438:THREATENED SOMEONE FOR SEX-RATE'
   V1442   = 'Y6-1439:RELATIONSHIP TO PERS THREATENED'
   V1443   = 'Y6-1440:SEX OF PERSON THREATENED'
   V1444   = 'Y6-1441:KIND OF PRESSURE/FORCE USED'
   V1445   = 'Y6-1442:OTHERS INVOLVED W/THREATENING'
   V1446   = 'Y6-1443:WAS THE PERSON INJURED'
   V1447   = 'Y6-1444:SUCCEED IN FORCING SEX RELATIONS'
   V1448   = 'Y6-1445:EVENT REPORT ANY OTH QUEST ITEM'
   V1449   = 'Y6-1446:AGE 1ST SEX INTER W/OPPOSITE SEX'
   V1450   = 'Y6-1447:RELATIONSHIP TO THAT PERSON'
   V1451   = 'Y6-1448:1ST SEXUAL EXPERIENCE VOLUNTARY'
   V1452   = 'Y6-1449:FEELINGS ABOUT THAT EXPERIENCE'
   V1453   = 'Y6-1450:SEXUAL RELATIONS W/SAME SEX'
   V1454   = 'Y6-1451:AGE 1ST TIME SEX REL W/SAME SEX'
   V1455   = 'Y6-1452:1ST EXPERIENCE VOLUNTARY'
   V1456   = 'Y6-1453:FEELINGS ABOUT THAT EXPERIENCE'
   V1457   = 'Y6-1454:HOW OFTN SEX REL W/SAME SEX-FREQ'
   V1458   = 'Y6-1455:HOW OFTN SEX REL W/SAME SEX-RATE'
   V1459   = 'Y6-1456:NO. OF SAME-SEX SEX PART LAST YR'
   V1460   = 'Y6-1457:SEXUAL IDENTITY'
   V1461   = 'Y6-1458:SATISFIED W/SEX LIFE'
   V1462   = 'Y6-1459:AMOUNT OF STRESS/PRESS SEX LIFE'
   V1463   = 'Y6-1460:EXP SERIOUS FUNCTIONAL SEX PROB'
   V1464   = 'Y6-1461:NO. TIMES SEX BEHAV AFF PAST YR'
   V1465   = 'Y6-1462:PEEP OTHS DRESSING/ENGAGED SEX'
   V1466   = 'Y6-1463:TRIED ENGAGE CHILD SEX ACTIVITY'
   V1467   = 'Y6-1464:SEXUALLY EXPOSED TO STRANGERS'
   V1468   = 'Y6-1465:WATCH PORNOGRAHIC MOVIES/OTHER'
   V1469   = 'Y6-1466:BEEN CRUEL/HURTFUL TO SEX PART'
   V1470   = 'Y6-1467:SOUGHT CRUEL/PAIN FROM SEX PART'
   V1471   = 'Y6-1473:FURTHER EXPLANATION OF ANSWERS'
   V1472   = 'Y6-1474:UNCOMFORT Q.-DRUGS'
   V1473   = 'Y6-1475:UNCOMFORT Q.-SEX'
   V1474   = 'Y6-1476:UNCOMFORT Q.-MENTAL HEALTH'
   V1475   = 'Y6-1477:UNCOMFORT Q.-CRIMINAL BEHAVIOR'
   V1476   = 'Y6-1478:UNCOMFORT Q.-SPOUSE VIOLENCE'
   V1477   = 'Y6-1479:UNCOMFORT Q.-SPECIFIC ITEM'
   V1478   = 'Y6-1480:UNCOMFORT Q.-SPECIFIC ITEM'
   V1479   = 'Y6-1495:RESP''S ANXIETY BEFORE INTERVIEW'
   V1480   = 'Y6-1496:WAS RESPONDENT HOSTILE'
   V1481   = 'Y6-1497:RESPONDENT''S INTEREST'
   V1482   = 'Y6-1498:PROBS-DIFFICULTY W/LANGUAGE'
   V1483   = 'Y6-1499:PROBS-DIFFICULTY W/QUESTIONS'
   V1484   = 'Y6-1500:PROBS-INTERRUPTIONS'
   V1485   = 'Y6-1501:PROBS-TEMPORARY BREAKOFF'
   V1486   = 'Y6-1502:PROBS-BREAKOFF'
   V1487   = 'Y6-1503:PROBS-OTHER'
   V1488   = 'Y6-1504:RESP''S ANXIETY AFTER INTERVIEW'
   V1489   = 'Y6-1505:ADDITIONAL COMMENTS'
   V1490   = 'Y6-1663:WEEKS WORKED MAJOR JOB IN 1983'
   V1491   = 'Y6-1664:HOURS WORKED MAJOR JOB IN 1983'
   V1492   = 'Y6-1665:PAY PER HOUR MAJOR JOB IN 1983'
   V1493   = 'Y6-1666:TOTAL NO. OF JOBS IN 1983'
   V1494   = 'Y6-1667:TOTAL INCOME NEAR THOUSAND-1983'
   V1495   = 'Y6-1668:WEEKS WORKED MAJOR JOB IN 1982'
   V1496   = 'Y6-1669:HOURS WORKED MAJOR JOB IN 1982'
   V1497   = 'Y6-1670:PAY PER HOUR MAJOR JOB IN 1982'
   V1498   = 'Y6-1671:TOTAL NO. OF JOBS IN 1982'
   V1499   = 'Y6-1672:TOTAL INCOME NEAR THOUSAND-1982'
   V1500   = 'Y6-1673:WEEKS WORKED MAJOR JOB IN 1981'
   V1501   = 'Y6-1674:HOURS WORKED MAJOR JOB IN 1981'
   V1502   = 'Y6-1675:PAY PER HOUR MAJOR JOB IN 1981'
   V1503   = 'Y6-1676:TOTAL NO. OF JOBS IN 1981'
   V1504   = 'Y6-1677:TOTAL INCOME NEAR THOUSAND-1981'
   V1505   = 'Y6-1678:WKS WORKED SPOUSE MAJOR JOB-1983'
   V1506   = 'Y6-1679:HRS WORKED SPOUSE MAJOR JOB-1983'
   V1507   = 'Y6-1680:TOTAL NO. JOBS SPOUSE IN 1983'
   V1508   = 'Y6-1689:NYS URBAN SUBURBAN RURAL CODE'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (V6 = -1) THEN V6 = .;
   IF (V7 = -1) THEN V7 = .;
   IF (V8 = -1) THEN V8 = .;
   IF (V9 = -1) THEN V9 = .;
   IF (V10 = -1) THEN V10 = .;
   IF (V11 = -1) THEN V11 = .;
   IF (V12 = -1) THEN V12 = .;
   IF (V13 = -1) THEN V13 = .;
   IF (V14 = -1) THEN V14 = .;
   IF (V15 = -1) THEN V15 = .;
   IF (V16 = -1) THEN V16 = .;
   IF (V17 = -1) THEN V17 = .;
   IF (V18 = -1) THEN V18 = .;
   IF (V19 = -1) THEN V19 = .;
   IF (V20 = -1) THEN V20 = .;
   IF (V21 = -1) THEN V21 = .;
   IF (V22 = -1) THEN V22 = .;
   IF (V23 = -1) THEN V23 = .;
   IF (V24 = -1) THEN V24 = .;
   IF (V25 = -1) THEN V25 = .;
   IF (V26 = -1) THEN V26 = .;
   IF (V27 = -1) THEN V27 = .;
   IF (V28 = -1) THEN V28 = .;
   IF (V29 = -1) THEN V29 = .;
   IF (V30 = -1) THEN V30 = .;
   IF (V31 = -1) THEN V31 = .;
   IF (V32 = -1) THEN V32 = .;
   IF (V33 = -1) THEN V33 = .;
   IF (V34 = -1) THEN V34 = .;
   IF (V35 = -1) THEN V35 = .;
   IF (V36 = -1) THEN V36 = .;
   IF (V37 = -1) THEN V37 = .;
   IF (V38 = -1) THEN V38 = .;
   IF (V39 = -1) THEN V39 = .;
   IF (V40 = -1) THEN V40 = .;
   IF (V41 = -1) THEN V41 = .;
   IF (V42 = -1) THEN V42 = .;
   IF (V43 = -1) THEN V43 = .;
   IF (V44 = -1) THEN V44 = .;
   IF (V45 = -1) THEN V45 = .;
   IF (V46 = -1) THEN V46 = .;
   IF (V48 = -1) THEN V48 = .;
   IF (V50 = -1) THEN V50 = .;
   IF (V51 = -1) THEN V51 = .;
   IF (V52 = -1) THEN V52 = .;
   IF (V53 = -1) THEN V53 = .;
   IF (V54 = -1) THEN V54 = .;
   IF (V55 = -1) THEN V55 = .;
   IF (V56 = -1) THEN V56 = .;
   IF (V57 = -1) THEN V57 = .;
   IF (V58 = -1) THEN V58 = .;
   IF (V59 = -1) THEN V59 = .;
   IF (V60 = -1) THEN V60 = .;
   IF (V61 = -1) THEN V61 = .;
   IF (V62 = -1) THEN V62 = .;
   IF (V63 = -1) THEN V63 = .;
   IF (V64 = -1) THEN V64 = .;
   IF (V65 = -1) THEN V65 = .;
   IF (V66 = -1) THEN V66 = .;
   IF (V67 = -1) THEN V67 = .;
   IF (V68 = -1) THEN V68 = .;
   IF (V69 = -1) THEN V69 = .;
   IF (V70 = -1) THEN V70 = .;
   IF (V71 = -1) THEN V71 = .;
   IF (V72 = -1) THEN V72 = .;
   IF (V73 = -1) THEN V73 = .;
   IF (V74 = -1) THEN V74 = .;
   IF (V75 = -1) THEN V75 = .;
   IF (V76 = -1) THEN V76 = .;
   IF (V77 = -1) THEN V77 = .;
   IF (V78 = -1) THEN V78 = .;
   IF (V79 = -1) THEN V79 = .;
   IF (V80 = -1) THEN V80 = .;
   IF (V81 = -1) THEN V81 = .;
   IF (V83 = -1) THEN V83 = .;
   IF (V84 = -1) THEN V84 = .;
   IF (V85 = -1) THEN V85 = .;
   IF (V86 = -1) THEN V86 = .;
   IF (V87 = -1) THEN V87 = .;
   IF (V88 = -1) THEN V88 = .;
   IF (V89 = -1) THEN V89 = .;
   IF (V90 = -1) THEN V90 = .;
   IF (V91 = -1) THEN V91 = .;
   IF (V92 = -1) THEN V92 = .;
   IF (V93 = -1) THEN V93 = .;
   IF (V94 = -1) THEN V94 = .;
   IF (V95 = -1) THEN V95 = .;
   IF (V96 = -1) THEN V96 = .;
   IF (V97 = -1) THEN V97 = .;
   IF (V98 = -1) THEN V98 = .;
   IF (V99 = -1) THEN V99 = .;
   IF (V100 = -1) THEN V100 = .;
   IF (V101 = -1) THEN V101 = .;
   IF (V102 = -1) THEN V102 = .;
   IF (V103 = -1) THEN V103 = .;
   IF (V104 = -1) THEN V104 = .;
   IF (V105 = -1) THEN V105 = .;
   IF (V106 = -1) THEN V106 = .;
   IF (V107 = -1) THEN V107 = .;
   IF (V108 = -1) THEN V108 = .;
   IF (V109 = -1) THEN V109 = .;
   IF (V110 = -1) THEN V110 = .;
   IF (V111 = -1) THEN V111 = .;
   IF (V112 = -1) THEN V112 = .;
   IF (V113 = -1) THEN V113 = .;
   IF (V114 = -1) THEN V114 = .;
   IF (V115 = -1) THEN V115 = .;
   IF (V116 = -1) THEN V116 = .;
   IF (V117 = -1) THEN V117 = .;
   IF (V118 = -1) THEN V118 = .;
   IF (V119 = -1) THEN V119 = .;
   IF (V120 = -1) THEN V120 = .;
   IF (V121 = -1) THEN V121 = .;
   IF (V122 = -1) THEN V122 = .;
   IF (V123 = -1) THEN V123 = .;
   IF (V124 = -1) THEN V124 = .;
   IF (V125 = -1) THEN V125 = .;
   IF (V126 = -1) THEN V126 = .;
   IF (V127 = -1) THEN V127 = .;
   IF (V128 = -1) THEN V128 = .;
   IF (V129 = -1) THEN V129 = .;
   IF (V130 = -1) THEN V130 = .;
   IF (V131 = -1) THEN V131 = .;
   IF (V132 = -1) THEN V132 = .;
   IF (V133 = -1) THEN V133 = .;
   IF (V134 = -1) THEN V134 = .;
   IF (V135 = -1) THEN V135 = .;
   IF (V136 = -1) THEN V136 = .;
   IF (V137 = -1) THEN V137 = .;
   IF (V138 = -1) THEN V138 = .;
   IF (V139 = -1) THEN V139 = .;
   IF (V140 = -1) THEN V140 = .;
   IF (V141 = -1) THEN V141 = .;
   IF (V142 = -1) THEN V142 = .;
   IF (V143 = -1) THEN V143 = .;
   IF (V144 = -1) THEN V144 = .;
   IF (V145 = -1) THEN V145 = .;
   IF (V146 = -1) THEN V146 = .;
   IF (V147 = -1) THEN V147 = .;
   IF (V148 = -1) THEN V148 = .;
   IF (V149 = -1) THEN V149 = .;
   IF (V150 = -1) THEN V150 = .;
   IF (V151 = -1) THEN V151 = .;
   IF (V152 = -1) THEN V152 = .;
   IF (V153 = -1) THEN V153 = .;
   IF (V154 = -1) THEN V154 = .;
   IF (V155 = -1) THEN V155 = .;
   IF (V156 = -1) THEN V156 = .;
   IF (V157 = -1) THEN V157 = .;
   IF (V158 = -1) THEN V158 = .;
   IF (V159 = -1) THEN V159 = .;
   IF (V160 = -1) THEN V160 = .;
   IF (V161 = -1) THEN V161 = .;
   IF (V162 = -1) THEN V162 = .;
   IF (V163 = -1) THEN V163 = .;
   IF (V164 = -1) THEN V164 = .;
   IF (V165 = -1) THEN V165 = .;
   IF (V166 = -1) THEN V166 = .;
   IF (V167 = -1) THEN V167 = .;
   IF (V168 = -1) THEN V168 = .;
   IF (V169 = -1) THEN V169 = .;
   IF (V170 = -1) THEN V170 = .;
   IF (V171 = -1) THEN V171 = .;
   IF (V172 = -1) THEN V172 = .;
   IF (V173 = -1) THEN V173 = .;
   IF (V174 = -1) THEN V174 = .;
   IF (V175 = -1) THEN V175 = .;
   IF (V176 = -1) THEN V176 = .;
   IF (V177 = -1) THEN V177 = .;
   IF (V178 = -1) THEN V178 = .;
   IF (V179 = -1) THEN V179 = .;
   IF (V180 = -1) THEN V180 = .;
   IF (V181 = -1) THEN V181 = .;
   IF (V182 = -1) THEN V182 = .;
   IF (V183 = -1) THEN V183 = .;
   IF (V184 = -1) THEN V184 = .;
   IF (V185 = -1) THEN V185 = .;
   IF (V186 = -1) THEN V186 = .;
   IF (V187 = -1) THEN V187 = .;
   IF (V188 = -1) THEN V188 = .;
   IF (V189 = -1) THEN V189 = .;
   IF (V190 = -1) THEN V190 = .;
   IF (V191 = -1) THEN V191 = .;
   IF (V192 = -1) THEN V192 = .;
   IF (V193 = -1) THEN V193 = .;
   IF (V194 = -1) THEN V194 = .;
   IF (V195 = -1) THEN V195 = .;
   IF (V196 = -1) THEN V196 = .;
   IF (V197 = -1) THEN V197 = .;
   IF (V198 = -1) THEN V198 = .;
   IF (V199 = -1) THEN V199 = .;
   IF (V200 = -1) THEN V200 = .;
   IF (V201 = -1) THEN V201 = .;
   IF (V202 = -1) THEN V202 = .;
   IF (V203 = -1) THEN V203 = .;
   IF (V204 = -1) THEN V204 = .;
   IF (V205 = -1) THEN V205 = .;
   IF (V206 = -1) THEN V206 = .;
   IF (V207 = -1) THEN V207 = .;
   IF (V208 = -1) THEN V208 = .;
   IF (V209 = -1) THEN V209 = .;
   IF (V210 = -1) THEN V210 = .;
   IF (V211 = -1) THEN V211 = .;
   IF (V212 = -1) THEN V212 = .;
   IF (V213 = -1) THEN V213 = .;
   IF (V214 = -1) THEN V214 = .;
   IF (V215 = -1) THEN V215 = .;
   IF (V216 = -1) THEN V216 = .;
   IF (V217 = -1) THEN V217 = .;
   IF (V218 = -1) THEN V218 = .;
   IF (V219 = -1) THEN V219 = .;
   IF (V220 = -1) THEN V220 = .;
   IF (V221 = -1) THEN V221 = .;
   IF (V222 = -1) THEN V222 = .;
   IF (V223 = -1) THEN V223 = .;
   IF (V224 = -1) THEN V224 = .;
   IF (V225 = -1) THEN V225 = .;
   IF (V226 = -1) THEN V226 = .;
   IF (V227 = -1) THEN V227 = .;
   IF (V228 = -1) THEN V228 = .;
   IF (V229 = -1) THEN V229 = .;
   IF (V230 = -1) THEN V230 = .;
   IF (V231 = -1) THEN V231 = .;
   IF (V232 = -1) THEN V232 = .;
   IF (V233 = -1) THEN V233 = .;
   IF (V234 = -1) THEN V234 = .;
   IF (V235 = -1) THEN V235 = .;
   IF (V236 = -1) THEN V236 = .;
   IF (V237 = -1) THEN V237 = .;
   IF (V238 = -1) THEN V238 = .;
   IF (V239 = -1) THEN V239 = .;
   IF (V240 = -1) THEN V240 = .;
   IF (V241 = -1) THEN V241 = .;
   IF (V242 = -1) THEN V242 = .;
   IF (V243 = -1) THEN V243 = .;
   IF (V244 = -1) THEN V244 = .;
   IF (V245 = -1) THEN V245 = .;
   IF (V246 = -1) THEN V246 = .;
   IF (V247 = -1) THEN V247 = .;
   IF (V248 = -1) THEN V248 = .;
   IF (V249 = -1) THEN V249 = .;
   IF (V250 = -1) THEN V250 = .;
   IF (V251 = -1) THEN V251 = .;
   IF (V252 = -1) THEN V252 = .;
   IF (V253 = -1) THEN V253 = .;
   IF (V254 = -1) THEN V254 = .;
   IF (V255 = -1) THEN V255 = .;
   IF (V256 = -1) THEN V256 = .;
   IF (V257 = -1) THEN V257 = .;
   IF (V258 = -1) THEN V258 = .;
   IF (V259 = -1) THEN V259 = .;
   IF (V260 = -1) THEN V260 = .;
   IF (V261 = -1) THEN V261 = .;
   IF (V262 = -1) THEN V262 = .;
   IF (V263 = -1) THEN V263 = .;
   IF (V265 = -1) THEN V265 = .;
   IF (V267 = -1) THEN V267 = .;
   IF (V269 = -1) THEN V269 = .;
   IF (V271 = -1) THEN V271 = .;
   IF (V273 = -1) THEN V273 = .;
   IF (V275 = -1) THEN V275 = .;
   IF (V277 = -1) THEN V277 = .;
   IF (V279 = -1) THEN V279 = .;
   IF (V281 = -1) THEN V281 = .;
   IF (V283 = -1) THEN V283 = .;
   IF (V284 = -1) THEN V284 = .;
   IF (V285 = -1) THEN V285 = .;
   IF (V286 = -1) THEN V286 = .;
   IF (V287 = -1) THEN V287 = .;
   IF (V288 = -1) THEN V288 = .;
   IF (V289 = -1) THEN V289 = .;
   IF (V290 = -1) THEN V290 = .;
   IF (V291 = -1) THEN V291 = .;
   IF (V292 = -1) THEN V292 = .;
   IF (V293 = -1) THEN V293 = .;
   IF (V294 = -1) THEN V294 = .;
   IF (V295 = -1) THEN V295 = .;
   IF (V296 = -1) THEN V296 = .;
   IF (V297 = -1) THEN V297 = .;
   IF (V298 = -1) THEN V298 = .;
   IF (V299 = -1) THEN V299 = .;
   IF (V300 = -1) THEN V300 = .;
   IF (V301 = -1) THEN V301 = .;
   IF (V302 = -1) THEN V302 = .;
   IF (V303 = -1) THEN V303 = .;
   IF (V304 = -1) THEN V304 = .;
   IF (V305 = -1) THEN V305 = .;
   IF (V306 = -1) THEN V306 = .;
   IF (V307 = -1) THEN V307 = .;
   IF (V308 = -1) THEN V308 = .;
   IF (V309 = -1) THEN V309 = .;
   IF (V310 = -1) THEN V310 = .;
   IF (V311 = -1) THEN V311 = .;
   IF (V312 = -1) THEN V312 = .;
   IF (V313 = -1) THEN V313 = .;
   IF (V314 = -1) THEN V314 = .;
   IF (V315 = -1) THEN V315 = .;
   IF (V316 = -1) THEN V316 = .;
   IF (V317 = -1) THEN V317 = .;
   IF (V318 = -1) THEN V318 = .;
   IF (V319 = -1) THEN V319 = .;
   IF (V320 = -1) THEN V320 = .;
   IF (V321 = -1) THEN V321 = .;
   IF (V322 = -1) THEN V322 = .;
   IF (V323 = -1) THEN V323 = .;
   IF (V324 = -1) THEN V324 = .;
   IF (V325 = -1) THEN V325 = .;
   IF (V326 = -1) THEN V326 = .;
   IF (V327 = -1) THEN V327 = .;
   IF (V328 = -1) THEN V328 = .;
   IF (V329 = -1) THEN V329 = .;
   IF (V330 = -1) THEN V330 = .;
   IF (V331 = -1) THEN V331 = .;
   IF (V332 = -1) THEN V332 = .;
   IF (V333 = -1) THEN V333 = .;
   IF (V334 = -1) THEN V334 = .;
   IF (V335 = -1) THEN V335 = .;
   IF (V336 = -1) THEN V336 = .;
   IF (V337 = -1) THEN V337 = .;
   IF (V338 = -1) THEN V338 = .;
   IF (V339 = -1) THEN V339 = .;
   IF (V340 = -1) THEN V340 = .;
   IF (V341 = -1) THEN V341 = .;
   IF (V342 = -1) THEN V342 = .;
   IF (V343 = -1) THEN V343 = .;
   IF (V344 = -1) THEN V344 = .;
   IF (V345 = -1) THEN V345 = .;
   IF (V346 = -1) THEN V346 = .;
   IF (V347 = -1) THEN V347 = .;
   IF (V348 = -1) THEN V348 = .;
   IF (V349 = -1) THEN V349 = .;
   IF (V350 = -1) THEN V350 = .;
   IF (V351 = -1) THEN V351 = .;
   IF (V352 = -1) THEN V352 = .;
   IF (V353 = -1) THEN V353 = .;
   IF (V354 = -1) THEN V354 = .;
   IF (V355 = -1) THEN V355 = .;
   IF (V356 = -1) THEN V356 = .;
   IF (V357 = -1) THEN V357 = .;
   IF (V358 = -1) THEN V358 = .;
   IF (V359 = -1) THEN V359 = .;
   IF (V360 = -1) THEN V360 = .;
   IF (V361 = -1) THEN V361 = .;
   IF (V362 = -1) THEN V362 = .;
   IF (V363 = -1) THEN V363 = .;
   IF (V364 = -1) THEN V364 = .;
   IF (V365 = -1) THEN V365 = .;
   IF (V366 = -1) THEN V366 = .;
   IF (V367 = -1) THEN V367 = .;
   IF (V368 = -1) THEN V368 = .;
   IF (V369 = -1) THEN V369 = .;
   IF (V370 = -1) THEN V370 = .;
   IF (V371 = -1) THEN V371 = .;
   IF (V372 = -1) THEN V372 = .;
   IF (V373 = -1) THEN V373 = .;
   IF (V374 = -1) THEN V374 = .;
   IF (V375 = -1) THEN V375 = .;
   IF (V376 = -1) THEN V376 = .;
   IF (V377 = -1) THEN V377 = .;
   IF (V378 = -1) THEN V378 = .;
   IF (V379 = -1) THEN V379 = .;
   IF (V380 = -1) THEN V380 = .;
   IF (V381 = -1) THEN V381 = .;
   IF (V382 = -1) THEN V382 = .;
   IF (V383 = -1) THEN V383 = .;
   IF (V384 = -1) THEN V384 = .;
   IF (V385 = -1) THEN V385 = .;
   IF (V386 = -1) THEN V386 = .;
   IF (V387 = -1) THEN V387 = .;
   IF (V388 = -1) THEN V388 = .;
   IF (V389 = -1) THEN V389 = .;
   IF (V390 = -1) THEN V390 = .;
   IF (V391 = -1) THEN V391 = .;
   IF (V392 = -1) THEN V392 = .;
   IF (V393 = -1) THEN V393 = .;
   IF (V394 = -1) THEN V394 = .;
   IF (V395 = -1) THEN V395 = .;
   IF (V396 = -1) THEN V396 = .;
   IF (V397 = -1) THEN V397 = .;
   IF (V398 = -1) THEN V398 = .;
   IF (V399 = -1) THEN V399 = .;
   IF (V400 = -1) THEN V400 = .;
   IF (V401 = -1) THEN V401 = .;
   IF (V402 = -1) THEN V402 = .;
   IF (V403 = -1) THEN V403 = .;
   IF (V404 = -1) THEN V404 = .;
   IF (V405 = -1) THEN V405 = .;
   IF (V406 = -1) THEN V406 = .;
   IF (V407 = -1) THEN V407 = .;
   IF (V408 = -1) THEN V408 = .;
   IF (V409 = -1) THEN V409 = .;
   IF (V410 = -1) THEN V410 = .;
   IF (V411 = -1) THEN V411 = .;
   IF (V412 = -1) THEN V412 = .;
   IF (V413 = -1) THEN V413 = .;
   IF (V414 = -1) THEN V414 = .;
   IF (V415 = -1) THEN V415 = .;
   IF (V416 = -1) THEN V416 = .;
   IF (V417 = -1) THEN V417 = .;
   IF (V418 = -1) THEN V418 = .;
   IF (V419 = -1) THEN V419 = .;
   IF (V420 = -1) THEN V420 = .;
   IF (V421 = -1) THEN V421 = .;
   IF (V422 = -1) THEN V422 = .;
   IF (V423 = -1) THEN V423 = .;
   IF (V424 = -1) THEN V424 = .;
   IF (V425 = -1) THEN V425 = .;
   IF (V426 = -1) THEN V426 = .;
   IF (V427 = -1) THEN V427 = .;
   IF (V428 = -1) THEN V428 = .;
   IF (V429 = -1) THEN V429 = .;
   IF (V430 = -1) THEN V430 = .;
   IF (V431 = -1) THEN V431 = .;
   IF (V432 = -1) THEN V432 = .;
   IF (V433 = -1) THEN V433 = .;
   IF (V434 = -1) THEN V434 = .;
   IF (V435 = -1) THEN V435 = .;
   IF (V436 = -1) THEN V436 = .;
   IF (V437 = -1) THEN V437 = .;
   IF (V438 = -1) THEN V438 = .;
   IF (V439 = -1) THEN V439 = .;
   IF (V440 = -1) THEN V440 = .;
   IF (V441 = -1) THEN V441 = .;
   IF (V442 = -1) THEN V442 = .;
   IF (V443 = -1) THEN V443 = .;
   IF (V444 = -1) THEN V444 = .;
   IF (V445 = -1) THEN V445 = .;
   IF (V446 = -1) THEN V446 = .;
   IF (V447 = -1) THEN V447 = .;
   IF (V448 = -1) THEN V448 = .;
   IF (V449 = -1) THEN V449 = .;
   IF (V450 = -1) THEN V450 = .;
   IF (V451 = -1) THEN V451 = .;
   IF (V452 = -1) THEN V452 = .;
   IF (V453 = -1) THEN V453 = .;
   IF (V454 = -1) THEN V454 = .;
   IF (V455 = -1) THEN V455 = .;
   IF (V456 = -1) THEN V456 = .;
   IF (V457 = -1) THEN V457 = .;
   IF (V458 = -1) THEN V458 = .;
   IF (V459 = -1) THEN V459 = .;
   IF (V460 = -1) THEN V460 = .;
   IF (V461 = -1) THEN V461 = .;
   IF (V462 = -1) THEN V462 = .;
   IF (V463 = -1) THEN V463 = .;
   IF (V464 = -1) THEN V464 = .;
   IF (V465 = -1) THEN V465 = .;
   IF (V466 = -1) THEN V466 = .;
   IF (V467 = -1) THEN V467 = .;
   IF (V468 = -1) THEN V468 = .;
   IF (V469 = -1) THEN V469 = .;
   IF (V470 = -1) THEN V470 = .;
   IF (V471 = -1) THEN V471 = .;
   IF (V472 = -1) THEN V472 = .;
   IF (V473 = -1) THEN V473 = .;
   IF (V474 = -1) THEN V474 = .;
   IF (V475 = -1) THEN V475 = .;
   IF (V476 = -1) THEN V476 = .;
   IF (V477 = -1) THEN V477 = .;
   IF (V478 = -1) THEN V478 = .;
   IF (V479 = -1) THEN V479 = .;
   IF (V480 = -1) THEN V480 = .;
   IF (V481 = -1) THEN V481 = .;
   IF (V482 = -1) THEN V482 = .;
   IF (V483 = -1) THEN V483 = .;
   IF (V484 = -1) THEN V484 = .;
   IF (V485 = -1) THEN V485 = .;
   IF (V486 = -1) THEN V486 = .;
   IF (V487 = -1) THEN V487 = .;
   IF (V488 = -1) THEN V488 = .;
   IF (V489 = -1) THEN V489 = .;
   IF (V490 = -1) THEN V490 = .;
   IF (V491 = -1) THEN V491 = .;
   IF (V492 = -1) THEN V492 = .;
   IF (V493 = -1) THEN V493 = .;
   IF (V494 = -1) THEN V494 = .;
   IF (V495 = -1) THEN V495 = .;
   IF (V496 = -1) THEN V496 = .;
   IF (V497 = -1) THEN V497 = .;
   IF (V498 = -1) THEN V498 = .;
   IF (V499 = -1) THEN V499 = .;
   IF (V500 = -1) THEN V500 = .;
   IF (V501 = -1) THEN V501 = .;
   IF (V502 = -1) THEN V502 = .;
   IF (V503 = -1) THEN V503 = .;
   IF (V504 = -1) THEN V504 = .;
   IF (V505 = -1) THEN V505 = .;
   IF (V506 = -1) THEN V506 = .;
   IF (V507 = -1) THEN V507 = .;
   IF (V508 = -1) THEN V508 = .;
   IF (V509 = -1) THEN V509 = .;
   IF (V510 = -1) THEN V510 = .;
   IF (V511 = -1) THEN V511 = .;
   IF (V512 = -1) THEN V512 = .;
   IF (V513 = -1) THEN V513 = .;
   IF (V514 = -1) THEN V514 = .;
   IF (V515 = -1) THEN V515 = .;
   IF (V516 = -1) THEN V516 = .;
   IF (V517 = -1) THEN V517 = .;
   IF (V518 = -1) THEN V518 = .;
   IF (V519 = -1) THEN V519 = .;
   IF (V520 = -1) THEN V520 = .;
   IF (V521 = -1) THEN V521 = .;
   IF (V522 = -1) THEN V522 = .;
   IF (V523 = -1) THEN V523 = .;
   IF (V524 = -1) THEN V524 = .;
   IF (V525 = -1) THEN V525 = .;
   IF (V526 = -1) THEN V526 = .;
   IF (V527 = -1) THEN V527 = .;
   IF (V528 = -1) THEN V528 = .;
   IF (V529 = -1) THEN V529 = .;
   IF (V530 = -1) THEN V530 = .;
   IF (V531 = -1) THEN V531 = .;
   IF (V532 = -1) THEN V532 = .;
   IF (V533 = -1) THEN V533 = .;
   IF (V534 = -1) THEN V534 = .;
   IF (V535 = -1) THEN V535 = .;
   IF (V536 = -1) THEN V536 = .;
   IF (V537 = -1) THEN V537 = .;
   IF (V538 = -1) THEN V538 = .;
   IF (V539 = -1) THEN V539 = .;
   IF (V540 = -1) THEN V540 = .;
   IF (V541 = -1) THEN V541 = .;
   IF (V542 = -1) THEN V542 = .;
   IF (V543 = -1) THEN V543 = .;
   IF (V544 = -1) THEN V544 = .;
   IF (V545 = -1) THEN V545 = .;
   IF (V546 = -1) THEN V546 = .;
   IF (V547 = -1) THEN V547 = .;
   IF (V548 = -1) THEN V548 = .;
   IF (V549 = -1) THEN V549 = .;
   IF (V550 = -1) THEN V550 = .;
   IF (V551 = -1) THEN V551 = .;
   IF (V552 = -1) THEN V552 = .;
   IF (V553 = -1) THEN V553 = .;
   IF (V554 = -1) THEN V554 = .;
   IF (V555 = -1) THEN V555 = .;
   IF (V556 = -1) THEN V556 = .;
   IF (V557 = -1) THEN V557 = .;
   IF (V558 = -1) THEN V558 = .;
   IF (V559 = -1) THEN V559 = .;
   IF (V560 = -1) THEN V560 = .;
   IF (V561 = -1) THEN V561 = .;
   IF (V562 = -1) THEN V562 = .;
   IF (V563 = -1) THEN V563 = .;
   IF (V564 = -1) THEN V564 = .;
   IF (V565 = -1) THEN V565 = .;
   IF (V566 = -1) THEN V566 = .;
   IF (V567 = -1) THEN V567 = .;
   IF (V568 = -1) THEN V568 = .;
   IF (V569 = -1) THEN V569 = .;
   IF (V570 = -1) THEN V570 = .;
   IF (V571 = -1) THEN V571 = .;
   IF (V572 = -1) THEN V572 = .;
   IF (V573 = -1) THEN V573 = .;
   IF (V574 = -1) THEN V574 = .;
   IF (V575 = -1) THEN V575 = .;
   IF (V576 = -1) THEN V576 = .;
   IF (V577 = -1) THEN V577 = .;
   IF (V578 = -1) THEN V578 = .;
   IF (V579 = -1) THEN V579 = .;
   IF (V580 = -1) THEN V580 = .;
   IF (V581 = -1) THEN V581 = .;
   IF (V582 = -1) THEN V582 = .;
   IF (V583 = -1) THEN V583 = .;
   IF (V584 = -1) THEN V584 = .;
   IF (V585 = -1) THEN V585 = .;
   IF (V586 = -1) THEN V586 = .;
   IF (V587 = -1) THEN V587 = .;
   IF (V588 = -1) THEN V588 = .;
   IF (V589 = -1) THEN V589 = .;
   IF (V590 = -1) THEN V590 = .;
   IF (V591 = -1) THEN V591 = .;
   IF (V592 = -1) THEN V592 = .;
   IF (V593 = -1) THEN V593 = .;
   IF (V594 = -1) THEN V594 = .;
   IF (V595 = -1) THEN V595 = .;
   IF (V596 = -1) THEN V596 = .;
   IF (V597 = -1) THEN V597 = .;
   IF (V598 = -1) THEN V598 = .;
   IF (V599 = -1) THEN V599 = .;
   IF (V600 = -1) THEN V600 = .;
   IF (V601 = -1) THEN V601 = .;
   IF (V602 = -1) THEN V602 = .;
   IF (V603 = -1) THEN V603 = .;
   IF (V604 = -1) THEN V604 = .;
   IF (V605 = -1) THEN V605 = .;
   IF (V606 = -1) THEN V606 = .;
   IF (V607 = -1) THEN V607 = .;
   IF (V608 = -1) THEN V608 = .;
   IF (V609 = -1) THEN V609 = .;
   IF (V610 = -1) THEN V610 = .;
   IF (V611 = -1) THEN V611 = .;
   IF (V612 = -1) THEN V612 = .;
   IF (V613 = -1) THEN V613 = .;
   IF (V614 = -1) THEN V614 = .;
   IF (V615 = -1) THEN V615 = .;
   IF (V616 = -1) THEN V616 = .;
   IF (V617 = -1) THEN V617 = .;
   IF (V618 = -1) THEN V618 = .;
   IF (V619 = -1) THEN V619 = .;
   IF (V620 = -1) THEN V620 = .;
   IF (V621 = -1) THEN V621 = .;
   IF (V622 = -1) THEN V622 = .;
   IF (V623 = -1) THEN V623 = .;
   IF (V624 = -1) THEN V624 = .;
   IF (V625 = -1) THEN V625 = .;
   IF (V626 = -1) THEN V626 = .;
   IF (V627 = -1) THEN V627 = .;
   IF (V628 = -1) THEN V628 = .;
   IF (V629 = -1) THEN V629 = .;
   IF (V630 = -1) THEN V630 = .;
   IF (V631 = -1) THEN V631 = .;
   IF (V632 = -1) THEN V632 = .;
   IF (V633 = -1) THEN V633 = .;
   IF (V634 = -1) THEN V634 = .;
   IF (V635 = -1) THEN V635 = .;
   IF (V636 = -1) THEN V636 = .;
   IF (V637 = -1) THEN V637 = .;
   IF (V638 = -1) THEN V638 = .;
   IF (V639 = -1) THEN V639 = .;
   IF (V640 = -1) THEN V640 = .;
   IF (V641 = -1) THEN V641 = .;
   IF (V642 = -1) THEN V642 = .;
   IF (V643 = -1) THEN V643 = .;
   IF (V644 = -1) THEN V644 = .;
   IF (V645 = -1) THEN V645 = .;
   IF (V646 = -1) THEN V646 = .;
   IF (V647 = -1) THEN V647 = .;
   IF (V648 = -1) THEN V648 = .;
   IF (V649 = -1) THEN V649 = .;
   IF (V650 = -1) THEN V650 = .;
   IF (V651 = -1) THEN V651 = .;
   IF (V652 = -1) THEN V652 = .;
   IF (V653 = -1) THEN V653 = .;
   IF (V654 = -1) THEN V654 = .;
   IF (V655 = -1) THEN V655 = .;
   IF (V656 = -1) THEN V656 = .;
   IF (V657 = -1) THEN V657 = .;
   IF (V658 = -1) THEN V658 = .;
   IF (V659 = -1) THEN V659 = .;
   IF (V660 = -1) THEN V660 = .;
   IF (V661 = -1) THEN V661 = .;
   IF (V662 = -1) THEN V662 = .;
   IF (V663 = -1) THEN V663 = .;
   IF (V664 = -1) THEN V664 = .;
   IF (V665 = -1) THEN V665 = .;
   IF (V666 = -1) THEN V666 = .;
   IF (V667 = -1) THEN V667 = .;
   IF (V668 = -1) THEN V668 = .;
   IF (V669 = -1) THEN V669 = .;
   IF (V670 = -1) THEN V670 = .;
   IF (V671 = -1) THEN V671 = .;
   IF (V672 = -1) THEN V672 = .;
   IF (V673 = -1) THEN V673 = .;
   IF (V674 = -1) THEN V674 = .;
   IF (V675 = -1) THEN V675 = .;
   IF (V676 = -1) THEN V676 = .;
   IF (V677 = -1) THEN V677 = .;
   IF (V678 = -1) THEN V678 = .;
   IF (V679 = -1) THEN V679 = .;
   IF (V680 = -1) THEN V680 = .;
   IF (V681 = -1) THEN V681 = .;
   IF (V682 = -1) THEN V682 = .;
   IF (V683 = -1) THEN V683 = .;
   IF (V684 = -1) THEN V684 = .;
   IF (V685 = -1) THEN V685 = .;
   IF (V686 = -1) THEN V686 = .;
   IF (V687 = -1) THEN V687 = .;
   IF (V688 = -1) THEN V688 = .;
   IF (V689 = -1) THEN V689 = .;
   IF (V690 = -1) THEN V690 = .;
   IF (V691 = -1) THEN V691 = .;
   IF (V692 = -1) THEN V692 = .;
   IF (V693 = -1) THEN V693 = .;
   IF (V694 = -1) THEN V694 = .;
   IF (V695 = -1) THEN V695 = .;
   IF (V696 = -1) THEN V696 = .;
   IF (V697 = -1) THEN V697 = .;
   IF (V698 = -1) THEN V698 = .;
   IF (V699 = -1) THEN V699 = .;
   IF (V700 = -1) THEN V700 = .;
   IF (V701 = -1) THEN V701 = .;
   IF (V702 = -1) THEN V702 = .;
   IF (V703 = -1) THEN V703 = .;
   IF (V704 = -1) THEN V704 = .;
   IF (V705 = -1) THEN V705 = .;
   IF (V706 = -1) THEN V706 = .;
   IF (V707 = -1) THEN V707 = .;
   IF (V708 = -1) THEN V708 = .;
   IF (V709 = -1) THEN V709 = .;
   IF (V710 = -1) THEN V710 = .;
   IF (V711 = -1) THEN V711 = .;
   IF (V712 = -1) THEN V712 = .;
   IF (V713 = -1) THEN V713 = .;
   IF (V714 = -1) THEN V714 = .;
   IF (V715 = -1) THEN V715 = .;
   IF (V716 = -1) THEN V716 = .;
   IF (V717 = -1) THEN V717 = .;
   IF (V718 = -1) THEN V718 = .;
   IF (V719 = -1) THEN V719 = .;
   IF (V720 = -1) THEN V720 = .;
   IF (V721 = -1) THEN V721 = .;
   IF (V722 = -1) THEN V722 = .;
   IF (V723 = -1) THEN V723 = .;
   IF (V724 = -1) THEN V724 = .;
   IF (V725 = -1) THEN V725 = .;
   IF (V726 = -1) THEN V726 = .;
   IF (V727 = -1) THEN V727 = .;
   IF (V728 = -1) THEN V728 = .;
   IF (V729 = -1) THEN V729 = .;
   IF (V730 = -1) THEN V730 = .;
   IF (V731 = -1) THEN V731 = .;
   IF (V732 = -1) THEN V732 = .;
   IF (V733 = -1) THEN V733 = .;
   IF (V734 = -1) THEN V734 = .;
   IF (V735 = -1) THEN V735 = .;
   IF (V736 = -1) THEN V736 = .;
   IF (V737 = -1) THEN V737 = .;
   IF (V738 = -1) THEN V738 = .;
   IF (V739 = -1) THEN V739 = .;
   IF (V740 = -1) THEN V740 = .;
   IF (V741 = -1) THEN V741 = .;
   IF (V742 = -1) THEN V742 = .;
   IF (V743 = -1) THEN V743 = .;
   IF (V744 = -1) THEN V744 = .;
   IF (V745 = -1) THEN V745 = .;
   IF (V746 = -1) THEN V746 = .;
   IF (V747 = -1) THEN V747 = .;
   IF (V748 = -1) THEN V748 = .;
   IF (V749 = -1) THEN V749 = .;
   IF (V750 = -1) THEN V750 = .;
   IF (V751 = -1) THEN V751 = .;
   IF (V752 = -1) THEN V752 = .;
   IF (V753 = -1) THEN V753 = .;
   IF (V754 = -1) THEN V754 = .;
   IF (V755 = -1) THEN V755 = .;
   IF (V756 = -1) THEN V756 = .;
   IF (V757 = -1) THEN V757 = .;
   IF (V758 = -1) THEN V758 = .;
   IF (V759 = -1) THEN V759 = .;
   IF (V760 = -1) THEN V760 = .;
   IF (V761 = -1) THEN V761 = .;
   IF (V762 = -1) THEN V762 = .;
   IF (V763 = -1) THEN V763 = .;
   IF (V764 = -1) THEN V764 = .;
   IF (V765 = -1) THEN V765 = .;
   IF (V766 = -1) THEN V766 = .;
   IF (V767 = -1) THEN V767 = .;
   IF (V768 = -1) THEN V768 = .;
   IF (V769 = -1) THEN V769 = .;
   IF (V770 = -1) THEN V770 = .;
   IF (V771 = -1) THEN V771 = .;
   IF (V772 = -1) THEN V772 = .;
   IF (V773 = -1) THEN V773 = .;
   IF (V774 = -1) THEN V774 = .;
   IF (V775 = -1) THEN V775 = .;
   IF (V776 = -1) THEN V776 = .;
   IF (V777 = -1) THEN V777 = .;
   IF (V778 = -1) THEN V778 = .;
   IF (V779 = -1) THEN V779 = .;
   IF (V780 = -1) THEN V780 = .;
   IF (V781 = -1) THEN V781 = .;
   IF (V782 = -1) THEN V782 = .;
   IF (V783 = -1) THEN V783 = .;
   IF (V784 = -1) THEN V784 = .;
   IF (V785 = -1) THEN V785 = .;
   IF (V786 = -1) THEN V786 = .;
   IF (V787 = -1) THEN V787 = .;
   IF (V788 = -1) THEN V788 = .;
   IF (V789 = -1) THEN V789 = .;
   IF (V790 = -1) THEN V790 = .;
   IF (V791 = -1) THEN V791 = .;
   IF (V792 = -1) THEN V792 = .;
   IF (V793 = -1) THEN V793 = .;
   IF (V794 = -1) THEN V794 = .;
   IF (V795 = -1) THEN V795 = .;
   IF (V796 = -1) THEN V796 = .;
   IF (V797 = -1) THEN V797 = .;
   IF (V798 = -1) THEN V798 = .;
   IF (V799 = -1) THEN V799 = .;
   IF (V800 = -1) THEN V800 = .;
   IF (V801 = -1) THEN V801 = .;
   IF (V802 = -1) THEN V802 = .;
   IF (V803 = -1) THEN V803 = .;
   IF (V804 = -1) THEN V804 = .;
   IF (V805 = -1) THEN V805 = .;
   IF (V806 = -1) THEN V806 = .;
   IF (V807 = -1) THEN V807 = .;
   IF (V808 = -1) THEN V808 = .;
   IF (V809 = -1) THEN V809 = .;
   IF (V810 = -1) THEN V810 = .;
   IF (V811 = -1) THEN V811 = .;
   IF (V812 = -1) THEN V812 = .;
   IF (V813 = -1) THEN V813 = .;
   IF (V814 = -1) THEN V814 = .;
   IF (V815 = -1) THEN V815 = .;
   IF (V816 = -1) THEN V816 = .;
   IF (V817 = -1) THEN V817 = .;
   IF (V818 = -1) THEN V818 = .;
   IF (V819 = -1) THEN V819 = .;
   IF (V820 = -1) THEN V820 = .;
   IF (V821 = -1) THEN V821 = .;
   IF (V822 = -1) THEN V822 = .;
   IF (V823 = -1) THEN V823 = .;
   IF (V824 = -1) THEN V824 = .;
   IF (V825 = -1) THEN V825 = .;
   IF (V826 = -1) THEN V826 = .;
   IF (V827 = -1) THEN V827 = .;
   IF (V828 = -1) THEN V828 = .;
   IF (V829 = -1) THEN V829 = .;
   IF (V830 = -1) THEN V830 = .;
   IF (V831 = -1) THEN V831 = .;
   IF (V832 = -1) THEN V832 = .;
   IF (V833 = -1) THEN V833 = .;
   IF (V834 = -1) THEN V834 = .;
   IF (V835 = -1) THEN V835 = .;
   IF (V836 = -1) THEN V836 = .;
   IF (V837 = -1) THEN V837 = .;
   IF (V838 = -1) THEN V838 = .;
   IF (V839 = -1) THEN V839 = .;
   IF (V840 = -1) THEN V840 = .;
   IF (V841 = -1) THEN V841 = .;
   IF (V842 = -1) THEN V842 = .;
   IF (V843 = -1) THEN V843 = .;
   IF (V844 = -1) THEN V844 = .;
   IF (V845 = -1) THEN V845 = .;
   IF (V846 = -1) THEN V846 = .;
   IF (V847 = -1) THEN V847 = .;
   IF (V848 = -1) THEN V848 = .;
   IF (V849 = -1) THEN V849 = .;
   IF (V850 = -1) THEN V850 = .;
   IF (V851 = -1) THEN V851 = .;
   IF (V852 = -1) THEN V852 = .;
   IF (V853 = -1) THEN V853 = .;
   IF (V854 = -1) THEN V854 = .;
   IF (V855 = -1) THEN V855 = .;
   IF (V856 = -1) THEN V856 = .;
   IF (V857 = -1) THEN V857 = .;
   IF (V858 = -1) THEN V858 = .;
   IF (V859 = -1) THEN V859 = .;
   IF (V860 = -1) THEN V860 = .;
   IF (V861 = -1) THEN V861 = .;
   IF (V862 = -1) THEN V862 = .;
   IF (V863 = -1) THEN V863 = .;
   IF (V864 = -1) THEN V864 = .;
   IF (V865 = -1) THEN V865 = .;
   IF (V866 = -1) THEN V866 = .;
   IF (V867 = -1) THEN V867 = .;
   IF (V868 = -1) THEN V868 = .;
   IF (V869 = -1) THEN V869 = .;
   IF (V870 = -1) THEN V870 = .;
   IF (V871 = -1) THEN V871 = .;
   IF (V872 = -1) THEN V872 = .;
   IF (V873 = -1) THEN V873 = .;
   IF (V874 = -1) THEN V874 = .;
   IF (V875 = -1) THEN V875 = .;
   IF (V876 = -1) THEN V876 = .;
   IF (V877 = -1) THEN V877 = .;
   IF (V878 = -1) THEN V878 = .;
   IF (V879 = -1) THEN V879 = .;
   IF (V880 = -1) THEN V880 = .;
   IF (V881 = -1) THEN V881 = .;
   IF (V882 = -1) THEN V882 = .;
   IF (V883 = -1) THEN V883 = .;
   IF (V885 = -1) THEN V885 = .;
   IF (V887 = -1) THEN V887 = .;
   IF (V888 = -1) THEN V888 = .;
   IF (V889 = -1) THEN V889 = .;
   IF (V890 = -1) THEN V890 = .;
   IF (V891 = -1) THEN V891 = .;
   IF (V893 = -1) THEN V893 = .;
   IF (V894 = -1) THEN V894 = .;
   IF (V896 = -1) THEN V896 = .;
   IF (V897 = -1) THEN V897 = .;
   IF (V899 = -1) THEN V899 = .;
   IF (V900 = -1) THEN V900 = .;
   IF (V902 = -1) THEN V902 = .;
   IF (V903 = -1) THEN V903 = .;
   IF (V905 = -1) THEN V905 = .;
   IF (V906 = -1) THEN V906 = .;
   IF (V908 = -1) THEN V908 = .;
   IF (V909 = -1) THEN V909 = .;
   IF (V911 = -1) THEN V911 = .;
   IF (V912 = -1) THEN V912 = .;
   IF (V914 = -1) THEN V914 = .;
   IF (V915 = -1) THEN V915 = .;
   IF (V917 = -1) THEN V917 = .;
   IF (V918 = -1) THEN V918 = .;
   IF (V920 = -1) THEN V920 = .;
   IF (V921 = -1) THEN V921 = .;
   IF (V922 = -1) THEN V922 = .;
   IF (V924 = -1) THEN V924 = .;
   IF (V925 = -1) THEN V925 = .;
   IF (V926 = -1) THEN V926 = .;
   IF (V927 = -1) THEN V927 = .;
   IF (V928 = -1) THEN V928 = .;
   IF (V929 = -1) THEN V929 = .;
   IF (V930 = -1) THEN V930 = .;
   IF (V931 = -1) THEN V931 = .;
   IF (V932 = -1) THEN V932 = .;
   IF (V933 = -1) THEN V933 = .;
   IF (V934 = -1) THEN V934 = .;
   IF (V935 = -1) THEN V935 = .;
   IF (V936 = -1) THEN V936 = .;
   IF (V937 = -1) THEN V937 = .;
   IF (V938 = -1) THEN V938 = .;
   IF (V939 = -1) THEN V939 = .;
   IF (V940 = -1) THEN V940 = .;
   IF (V941 = -1) THEN V941 = .;
   IF (V942 = -1) THEN V942 = .;
   IF (V943 = -1) THEN V943 = .;
   IF (V944 = -1) THEN V944 = .;
   IF (V945 = -1) THEN V945 = .;
   IF (V946 = -1) THEN V946 = .;
   IF (V947 = -1) THEN V947 = .;
   IF (V948 = -1) THEN V948 = .;
   IF (V949 = -1) THEN V949 = .;
   IF (V950 = -1) THEN V950 = .;
   IF (V963 = -1) THEN V963 = .;
   IF (V964 = -1) THEN V964 = .;
   IF (V965 = -1) THEN V965 = .;
   IF (V966 = -1) THEN V966 = .;
   IF (V967 = -1) THEN V967 = .;
   IF (V968 = -1) THEN V968 = .;
   IF (V969 = -1) THEN V969 = .;
   IF (V970 = -1) THEN V970 = .;
   IF (V971 = -1) THEN V971 = .;
   IF (V972 = -1) THEN V972 = .;
   IF (V973 = -1) THEN V973 = .;
   IF (V974 = -1) THEN V974 = .;
   IF (V975 = -1) THEN V975 = .;
   IF (V976 = -1) THEN V976 = .;
   IF (V977 = -1) THEN V977 = .;
   IF (V978 = -1) THEN V978 = .;
   IF (V979 = -1) THEN V979 = .;
   IF (V980 = -1) THEN V980 = .;
   IF (V981 = -1) THEN V981 = .;
   IF (V982 = -1) THEN V982 = .;
   IF (V983 = -1) THEN V983 = .;
   IF (V984 = -1) THEN V984 = .;
   IF (V985 = -1) THEN V985 = .;
   IF (V986 = -1) THEN V986 = .;
   IF (V987 = -1) THEN V987 = .;
   IF (V988 = -1) THEN V988 = .;
   IF (V989 = -1) THEN V989 = .;
   IF (V990 = -1) THEN V990 = .;
   IF (V991 = -1) THEN V991 = .;
   IF (V992 = -1) THEN V992 = .;
   IF (V993 = -1) THEN V993 = .;
   IF (V994 = -1) THEN V994 = .;
   IF (V995 = -1) THEN V995 = .;
   IF (V996 = -1) THEN V996 = .;
   IF (V997 = -1) THEN V997 = .;
   IF (V998 = -1) THEN V998 = .;
   IF (V999 = -1) THEN V999 = .;
   IF (V1000 = -1) THEN V1000 = .;
   IF (V1001 = -1) THEN V1001 = .;
   IF (V1002 = -1) THEN V1002 = .;
   IF (V1003 = -1) THEN V1003 = .;
   IF (V1004 = -1) THEN V1004 = .;
   IF (V1005 = -1) THEN V1005 = .;
   IF (V1006 = -1) THEN V1006 = .;
   IF (V1007 = -1) THEN V1007 = .;
   IF (V1008 = -1) THEN V1008 = .;
   IF (V1009 = -1) THEN V1009 = .;
   IF (V1010 = -1) THEN V1010 = .;
   IF (V1011 = -1) THEN V1011 = .;
   IF (V1012 = -1) THEN V1012 = .;
   IF (V1013 = -1) THEN V1013 = .;
   IF (V1014 = -1) THEN V1014 = .;
   IF (V1015 = -1) THEN V1015 = .;
   IF (V1016 = -1) THEN V1016 = .;
   IF (V1017 = -1) THEN V1017 = .;
   IF (V1018 = -1) THEN V1018 = .;
   IF (V1019 = -1) THEN V1019 = .;
   IF (V1020 = -1) THEN V1020 = .;
   IF (V1021 = -1) THEN V1021 = .;
   IF (V1022 = -1) THEN V1022 = .;
   IF (V1023 = -1) THEN V1023 = .;
   IF (V1024 = -1) THEN V1024 = .;
   IF (V1025 = -1) THEN V1025 = .;
   IF (V1026 = -1) THEN V1026 = .;
   IF (V1027 = -1) THEN V1027 = .;
   IF (V1028 = -1) THEN V1028 = .;
   IF (V1029 = -1) THEN V1029 = .;
   IF (V1030 = -1) THEN V1030 = .;
   IF (V1031 = -1) THEN V1031 = .;
   IF (V1032 = -1) THEN V1032 = .;
   IF (V1033 = -1) THEN V1033 = .;
   IF (V1034 = -1) THEN V1034 = .;
   IF (V1035 = -1) THEN V1035 = .;
   IF (V1036 = -1) THEN V1036 = .;
   IF (V1037 = -1) THEN V1037 = .;
   IF (V1038 = -1) THEN V1038 = .;
   IF (V1039 = -1) THEN V1039 = .;
   IF (V1040 = -1) THEN V1040 = .;
   IF (V1041 = -1) THEN V1041 = .;
   IF (V1042 = -1) THEN V1042 = .;
   IF (V1043 = -1) THEN V1043 = .;
   IF (V1044 = -1) THEN V1044 = .;
   IF (V1045 = -1) THEN V1045 = .;
   IF (V1046 = -1) THEN V1046 = .;
   IF (V1047 = -1) THEN V1047 = .;
   IF (V1048 = -1) THEN V1048 = .;
   IF (V1049 = -1) THEN V1049 = .;
   IF (V1050 = -1) THEN V1050 = .;
   IF (V1051 = -1) THEN V1051 = .;
   IF (V1052 = -1) THEN V1052 = .;
   IF (V1053 = -1) THEN V1053 = .;
   IF (V1054 = -1) THEN V1054 = .;
   IF (V1055 = -1) THEN V1055 = .;
   IF (V1056 = -1) THEN V1056 = .;
   IF (V1057 = -1) THEN V1057 = .;
   IF (V1058 = -1) THEN V1058 = .;
   IF (V1059 = -1) THEN V1059 = .;
   IF (V1060 = -1) THEN V1060 = .;
   IF (V1061 = -1) THEN V1061 = .;
   IF (V1062 = -1) THEN V1062 = .;
   IF (V1063 = -1) THEN V1063 = .;
   IF (V1064 = -1) THEN V1064 = .;
   IF (V1065 = -1) THEN V1065 = .;
   IF (V1066 = -1) THEN V1066 = .;
   IF (V1067 = -1) THEN V1067 = .;
   IF (V1068 = -1) THEN V1068 = .;
   IF (V1069 = -1) THEN V1069 = .;
   IF (V1070 = -1) THEN V1070 = .;
   IF (V1071 = -1) THEN V1071 = .;
   IF (V1072 = -1) THEN V1072 = .;
   IF (V1073 = -1) THEN V1073 = .;
   IF (V1074 = -1) THEN V1074 = .;
   IF (V1075 = -1) THEN V1075 = .;
   IF (V1076 = -1) THEN V1076 = .;
   IF (V1077 = -1) THEN V1077 = .;
   IF (V1078 = -1) THEN V1078 = .;
   IF (V1079 = -1) THEN V1079 = .;
   IF (V1080 = -1) THEN V1080 = .;
   IF (V1081 = -1) THEN V1081 = .;
   IF (V1082 = -1) THEN V1082 = .;
   IF (V1083 = -1) THEN V1083 = .;
   IF (V1084 = -1) THEN V1084 = .;
   IF (V1085 = -1) THEN V1085 = .;
   IF (V1086 = -1) THEN V1086 = .;
   IF (V1087 = -1) THEN V1087 = .;
   IF (V1088 = -1) THEN V1088 = .;
   IF (V1089 = -1) THEN V1089 = .;
   IF (V1090 = -1) THEN V1090 = .;
   IF (V1091 = -1) THEN V1091 = .;
   IF (V1092 = -1) THEN V1092 = .;
   IF (V1093 = -1) THEN V1093 = .;
   IF (V1094 = -1) THEN V1094 = .;
   IF (V1095 = -1) THEN V1095 = .;
   IF (V1096 = -1) THEN V1096 = .;
   IF (V1097 = -1) THEN V1097 = .;
   IF (V1098 = -1) THEN V1098 = .;
   IF (V1099 = -1) THEN V1099 = .;
   IF (V1100 = -1) THEN V1100 = .;
   IF (V1101 = -1) THEN V1101 = .;
   IF (V1102 = -1) THEN V1102 = .;
   IF (V1103 = -1) THEN V1103 = .;
   IF (V1104 = -1) THEN V1104 = .;
   IF (V1105 = -1) THEN V1105 = .;
   IF (V1106 = -1) THEN V1106 = .;
   IF (V1107 = -1) THEN V1107 = .;
   IF (V1108 = -1) THEN V1108 = .;
   IF (V1109 = -1) THEN V1109 = .;
   IF (V1110 = -1) THEN V1110 = .;
   IF (V1111 = -1) THEN V1111 = .;
   IF (V1112 = -1) THEN V1112 = .;
   IF (V1113 = -1) THEN V1113 = .;
   IF (V1114 = -1) THEN V1114 = .;
   IF (V1115 = -1) THEN V1115 = .;
   IF (V1116 = -1) THEN V1116 = .;
   IF (V1117 = -1) THEN V1117 = .;
   IF (V1118 = -1) THEN V1118 = .;
   IF (V1119 = -1) THEN V1119 = .;
   IF (V1120 = -1) THEN V1120 = .;
   IF (V1121 = -1) THEN V1121 = .;
   IF (V1122 = -1) THEN V1122 = .;
   IF (V1123 = -1) THEN V1123 = .;
   IF (V1124 = -1) THEN V1124 = .;
   IF (V1125 = -1) THEN V1125 = .;
   IF (V1126 = -1) THEN V1126 = .;
   IF (V1127 = -1) THEN V1127 = .;
   IF (V1128 = -1) THEN V1128 = .;
   IF (V1129 = -1) THEN V1129 = .;
   IF (V1130 = -1) THEN V1130 = .;
   IF (V1131 = -1) THEN V1131 = .;
   IF (V1132 = -1) THEN V1132 = .;
   IF (V1133 = -1) THEN V1133 = .;
   IF (V1134 = -1) THEN V1134 = .;
   IF (V1135 = -1) THEN V1135 = .;
   IF (V1136 = -1) THEN V1136 = .;
   IF (V1137 = -1) THEN V1137 = .;
   IF (V1138 = -1) THEN V1138 = .;
   IF (V1139 = -1) THEN V1139 = .;
   IF (V1140 = -1) THEN V1140 = .;
   IF (V1141 = -1) THEN V1141 = .;
   IF (V1142 = -1) THEN V1142 = .;
   IF (V1143 = -1) THEN V1143 = .;
   IF (V1144 = -1) THEN V1144 = .;
   IF (V1145 = -1) THEN V1145 = .;
   IF (V1146 = -1) THEN V1146 = .;
   IF (V1147 = -1) THEN V1147 = .;
   IF (V1148 = -1) THEN V1148 = .;
   IF (V1149 = -1) THEN V1149 = .;
   IF (V1150 = -1) THEN V1150 = .;
   IF (V1151 = -1) THEN V1151 = .;
   IF (V1152 = -1) THEN V1152 = .;
   IF (V1153 = -1) THEN V1153 = .;
   IF (V1154 = -1) THEN V1154 = .;
   IF (V1155 = -1) THEN V1155 = .;
   IF (V1156 = -1) THEN V1156 = .;
   IF (V1157 = -1) THEN V1157 = .;
   IF (V1158 = -1) THEN V1158 = .;
   IF (V1159 = -1) THEN V1159 = .;
   IF (V1160 = -1) THEN V1160 = .;
   IF (V1161 = -1) THEN V1161 = .;
   IF (V1162 = -1) THEN V1162 = .;
   IF (V1163 = -1) THEN V1163 = .;
   IF (V1164 = -1) THEN V1164 = .;
   IF (V1165 = -1) THEN V1165 = .;
   IF (V1166 = -1) THEN V1166 = .;
   IF (V1167 = -1) THEN V1167 = .;
   IF (V1168 = -1) THEN V1168 = .;
   IF (V1169 = -1) THEN V1169 = .;
   IF (V1170 = -1) THEN V1170 = .;
   IF (V1171 = -1) THEN V1171 = .;
   IF (V1172 = -1) THEN V1172 = .;
   IF (V1173 = -1) THEN V1173 = .;
   IF (V1174 = -1) THEN V1174 = .;
   IF (V1175 = -1) THEN V1175 = .;
   IF (V1176 = -1) THEN V1176 = .;
   IF (V1177 = -1) THEN V1177 = .;
   IF (V1178 = -1) THEN V1178 = .;
   IF (V1179 = -1) THEN V1179 = .;
   IF (V1180 = -1) THEN V1180 = .;
   IF (V1181 = -1) THEN V1181 = .;
   IF (V1182 = -1) THEN V1182 = .;
   IF (V1183 = -1) THEN V1183 = .;
   IF (V1184 = -1) THEN V1184 = .;
   IF (V1185 = -1) THEN V1185 = .;
   IF (V1186 = -1) THEN V1186 = .;
   IF (V1187 = -1) THEN V1187 = .;
   IF (V1188 = -1) THEN V1188 = .;
   IF (V1189 = -1) THEN V1189 = .;
   IF (V1190 = -1) THEN V1190 = .;
   IF (V1191 = -1) THEN V1191 = .;
   IF (V1192 = -1) THEN V1192 = .;
   IF (V1193 = -1) THEN V1193 = .;
   IF (V1194 = -1) THEN V1194 = .;
   IF (V1195 = -1) THEN V1195 = .;
   IF (V1196 = -1) THEN V1196 = .;
   IF (V1197 = -1) THEN V1197 = .;
   IF (V1198 = -1) THEN V1198 = .;
   IF (V1199 = -1) THEN V1199 = .;
   IF (V1200 = -1) THEN V1200 = .;
   IF (V1201 = -1) THEN V1201 = .;
   IF (V1202 = -1) THEN V1202 = .;
   IF (V1203 = -1) THEN V1203 = .;
   IF (V1204 = -1) THEN V1204 = .;
   IF (V1205 = -1) THEN V1205 = .;
   IF (V1206 = -1) THEN V1206 = .;
   IF (V1207 = -1) THEN V1207 = .;
   IF (V1208 = -1) THEN V1208 = .;
   IF (V1209 = -1) THEN V1209 = .;
   IF (V1211 = -1) THEN V1211 = .;
   IF (V1212 = -1) THEN V1212 = .;
   IF (V1213 = -1) THEN V1213 = .;
   IF (V1214 = -1) THEN V1214 = .;
   IF (V1215 = -1) THEN V1215 = .;
   IF (V1216 = -1) THEN V1216 = .;
   IF (V1217 = -1) THEN V1217 = .;
   IF (V1218 = -1) THEN V1218 = .;
   IF (V1219 = -1) THEN V1219 = .;
   IF (V1220 = -1) THEN V1220 = .;
   IF (V1221 = -1) THEN V1221 = .;
   IF (V1222 = -1) THEN V1222 = .;
   IF (V1223 = -1) THEN V1223 = .;
   IF (V1224 = -1) THEN V1224 = .;
   IF (V1225 = -1) THEN V1225 = .;
   IF (V1226 = -1) THEN V1226 = .;
   IF (V1227 = -1) THEN V1227 = .;
   IF (V1228 = -1) THEN V1228 = .;
   IF (V1229 = -1) THEN V1229 = .;
   IF (V1230 = -1) THEN V1230 = .;
   IF (V1231 = -1) THEN V1231 = .;
   IF (V1232 = -1) THEN V1232 = .;
   IF (V1233 = -1) THEN V1233 = .;
   IF (V1234 = -1) THEN V1234 = .;
   IF (V1235 = -1) THEN V1235 = .;
   IF (V1236 = -1) THEN V1236 = .;
   IF (V1237 = -1) THEN V1237 = .;
   IF (V1238 = -1) THEN V1238 = .;
   IF (V1239 = -1) THEN V1239 = .;
   IF (V1240 = -1) THEN V1240 = .;
   IF (V1241 = -1) THEN V1241 = .;
   IF (V1242 = -1) THEN V1242 = .;
   IF (V1243 = -1) THEN V1243 = .;
   IF (V1244 = -1) THEN V1244 = .;
   IF (V1245 = -1) THEN V1245 = .;
   IF (V1246 = -1) THEN V1246 = .;
   IF (V1247 = -1) THEN V1247 = .;
   IF (V1248 = -1) THEN V1248 = .;
   IF (V1249 = -1) THEN V1249 = .;
   IF (V1250 = -1) THEN V1250 = .;
   IF (V1251 = -1) THEN V1251 = .;
   IF (V1252 = -1) THEN V1252 = .;
   IF (V1253 = -1) THEN V1253 = .;
   IF (V1254 = -1) THEN V1254 = .;
   IF (V1255 = -1) THEN V1255 = .;
   IF (V1256 = -1) THEN V1256 = .;
   IF (V1257 = -1) THEN V1257 = .;
   IF (V1258 = -1) THEN V1258 = .;
   IF (V1259 = -1) THEN V1259 = .;
   IF (V1260 = -1) THEN V1260 = .;
   IF (V1261 = -1) THEN V1261 = .;
   IF (V1262 = -1) THEN V1262 = .;
   IF (V1263 = -1) THEN V1263 = .;
   IF (V1264 = -1) THEN V1264 = .;
   IF (V1265 = -1) THEN V1265 = .;
   IF (V1266 = -1) THEN V1266 = .;
   IF (V1267 = -1) THEN V1267 = .;
   IF (V1268 = -1) THEN V1268 = .;
   IF (V1269 = -1) THEN V1269 = .;
   IF (V1270 = -1) THEN V1270 = .;
   IF (V1271 = -1) THEN V1271 = .;
   IF (V1272 = -1) THEN V1272 = .;
   IF (V1273 = -1) THEN V1273 = .;
   IF (V1274 = -1) THEN V1274 = .;
   IF (V1275 = -1) THEN V1275 = .;
   IF (V1276 = -1) THEN V1276 = .;
   IF (V1277 = -1) THEN V1277 = .;
   IF (V1278 = -1) THEN V1278 = .;
   IF (V1279 = -1) THEN V1279 = .;
   IF (V1280 = -1) THEN V1280 = .;
   IF (V1281 = -1) THEN V1281 = .;
   IF (V1282 = -1) THEN V1282 = .;
   IF (V1283 = -1) THEN V1283 = .;
   IF (V1284 = -1) THEN V1284 = .;
   IF (V1285 = -1) THEN V1285 = .;
   IF (V1286 = -1) THEN V1286 = .;
   IF (V1287 = -1) THEN V1287 = .;
   IF (V1288 = -1) THEN V1288 = .;
   IF (V1289 = -1) THEN V1289 = .;
   IF (V1290 = -1) THEN V1290 = .;
   IF (V1291 = -1) THEN V1291 = .;
   IF (V1292 = -1) THEN V1292 = .;
   IF (V1293 = -1) THEN V1293 = .;
   IF (V1294 = -1) THEN V1294 = .;
   IF (V1295 = -1) THEN V1295 = .;
   IF (V1296 = -1) THEN V1296 = .;
   IF (V1297 = -1) THEN V1297 = .;
   IF (V1298 = -1) THEN V1298 = .;
   IF (V1299 = -1) THEN V1299 = .;
   IF (V1300 = -1) THEN V1300 = .;
   IF (V1301 = -1) THEN V1301 = .;
   IF (V1302 = -1) THEN V1302 = .;
   IF (V1303 = -1) THEN V1303 = .;
   IF (V1304 = -1) THEN V1304 = .;
   IF (V1305 = -1) THEN V1305 = .;
   IF (V1306 = -1) THEN V1306 = .;
   IF (V1307 = -1) THEN V1307 = .;
   IF (V1308 = -1) THEN V1308 = .;
   IF (V1309 = -1) THEN V1309 = .;
   IF (V1310 = -1) THEN V1310 = .;
   IF (V1311 = -1) THEN V1311 = .;
   IF (V1312 = -1) THEN V1312 = .;
   IF (V1313 = -1) THEN V1313 = .;
   IF (V1314 = -1) THEN V1314 = .;
   IF (V1315 = -1) THEN V1315 = .;
   IF (V1316 = -1) THEN V1316 = .;
   IF (V1317 = -1) THEN V1317 = .;
   IF (V1318 = -1) THEN V1318 = .;
   IF (V1319 = -1) THEN V1319 = .;
   IF (V1320 = -1) THEN V1320 = .;
   IF (V1321 = -1) THEN V1321 = .;
   IF (V1322 = -1) THEN V1322 = .;
   IF (V1323 = -1) THEN V1323 = .;
   IF (V1324 = -1) THEN V1324 = .;
   IF (V1325 = -1) THEN V1325 = .;
   IF (V1326 = -1) THEN V1326 = .;
   IF (V1327 = -1) THEN V1327 = .;
   IF (V1328 = -1) THEN V1328 = .;
   IF (V1329 = -1) THEN V1329 = .;
   IF (V1330 = -1) THEN V1330 = .;
   IF (V1331 = -1) THEN V1331 = .;
   IF (V1332 = -1) THEN V1332 = .;
   IF (V1333 = -1) THEN V1333 = .;
   IF (V1334 = -1) THEN V1334 = .;
   IF (V1335 = -1) THEN V1335 = .;
   IF (V1336 = -1) THEN V1336 = .;
   IF (V1337 = -1) THEN V1337 = .;
   IF (V1338 = -1) THEN V1338 = .;
   IF (V1339 = -1) THEN V1339 = .;
   IF (V1340 = -1) THEN V1340 = .;
   IF (V1341 = -1) THEN V1341 = .;
   IF (V1342 = -1) THEN V1342 = .;
   IF (V1343 = -1) THEN V1343 = .;
   IF (V1344 = -1) THEN V1344 = .;
   IF (V1345 = -1) THEN V1345 = .;
   IF (V1346 = -1) THEN V1346 = .;
   IF (V1347 = -1) THEN V1347 = .;
   IF (V1348 = -1) THEN V1348 = .;
   IF (V1349 = -1) THEN V1349 = .;
   IF (V1350 = -1) THEN V1350 = .;
   IF (V1351 = -1) THEN V1351 = .;
   IF (V1352 = -1) THEN V1352 = .;
   IF (V1353 = -1) THEN V1353 = .;
   IF (V1354 = -1) THEN V1354 = .;
   IF (V1355 = -1) THEN V1355 = .;
   IF (V1356 = -1) THEN V1356 = .;
   IF (V1357 = -1) THEN V1357 = .;
   IF (V1358 = -1) THEN V1358 = .;
   IF (V1359 = -1) THEN V1359 = .;
   IF (V1360 = -1) THEN V1360 = .;
   IF (V1361 = -1) THEN V1361 = .;
   IF (V1362 = -1) THEN V1362 = .;
   IF (V1363 = -1) THEN V1363 = .;
   IF (V1364 = -1) THEN V1364 = .;
   IF (V1365 = -1) THEN V1365 = .;
   IF (V1366 = -1) THEN V1366 = .;
   IF (V1367 = -1) THEN V1367 = .;
   IF (V1368 = -1) THEN V1368 = .;
   IF (V1369 = -1) THEN V1369 = .;
   IF (V1370 = -1) THEN V1370 = .;
   IF (V1371 = -1) THEN V1371 = .;
   IF (V1372 = -1) THEN V1372 = .;
   IF (V1373 = -1) THEN V1373 = .;
   IF (V1374 = -1) THEN V1374 = .;
   IF (V1383 = -1) THEN V1383 = .;
   IF (V1384 = -1) THEN V1384 = .;
   IF (V1385 = -1) THEN V1385 = .;
   IF (V1386 = -1) THEN V1386 = .;
   IF (V1387 = -1) THEN V1387 = .;
   IF (V1396 = -1) THEN V1396 = .;
   IF (V1397 = -1) THEN V1397 = .;
   IF (V1398 = -1) THEN V1398 = .;
   IF (V1399 = -1) THEN V1399 = .;
   IF (V1400 = -1) THEN V1400 = .;
   IF (V1401 = -1) THEN V1401 = .;
   IF (V1402 = -1) THEN V1402 = .;
   IF (V1403 = -1) THEN V1403 = .;
   IF (V1404 = -1) THEN V1404 = .;
   IF (V1405 = -1) THEN V1405 = .;
   IF (V1406 = -1) THEN V1406 = .;
   IF (V1407 = -1) THEN V1407 = .;
   IF (V1408 = -1) THEN V1408 = .;
   IF (V1409 = -1) THEN V1409 = .;
   IF (V1410 = -1) THEN V1410 = .;
   IF (V1411 = -1) THEN V1411 = .;
   IF (V1412 = -1) THEN V1412 = .;
   IF (V1413 = -1) THEN V1413 = .;
   IF (V1414 = -1) THEN V1414 = .;
   IF (V1415 = -1) THEN V1415 = .;
   IF (V1416 = -1) THEN V1416 = .;
   IF (V1417 = -1) THEN V1417 = .;
   IF (V1418 = -1) THEN V1418 = .;
   IF (V1419 = -1) THEN V1419 = .;
   IF (V1420 = -1) THEN V1420 = .;
   IF (V1421 = -1) THEN V1421 = .;
   IF (V1422 = -1) THEN V1422 = .;
   IF (V1423 = -1) THEN V1423 = .;
   IF (V1424 = -1) THEN V1424 = .;
   IF (V1425 = -1) THEN V1425 = .;
   IF (V1426 = -1) THEN V1426 = .;
   IF (V1427 = -1) THEN V1427 = .;
   IF (V1428 = -1) THEN V1428 = .;
   IF (V1429 = -1) THEN V1429 = .;
   IF (V1430 = -1) THEN V1430 = .;
   IF (V1431 = -1) THEN V1431 = .;
   IF (V1432 = -1) THEN V1432 = .;
   IF (V1433 = -1) THEN V1433 = .;
   IF (V1434 = -1) THEN V1434 = .;
   IF (V1435 = -1) THEN V1435 = .;
   IF (V1436 = -1) THEN V1436 = .;
   IF (V1437 = -1) THEN V1437 = .;
   IF (V1438 = -1) THEN V1438 = .;
   IF (V1439 = -1) THEN V1439 = .;
   IF (V1440 = -1) THEN V1440 = .;
   IF (V1441 = -1) THEN V1441 = .;
   IF (V1442 = -1) THEN V1442 = .;
   IF (V1443 = -1) THEN V1443 = .;
   IF (V1444 = -1) THEN V1444 = .;
   IF (V1445 = -1) THEN V1445 = .;
   IF (V1446 = -1) THEN V1446 = .;
   IF (V1447 = -1) THEN V1447 = .;
   IF (V1448 = -1) THEN V1448 = .;
   IF (V1449 = -1) THEN V1449 = .;
   IF (V1450 = -1) THEN V1450 = .;
   IF (V1451 = -1) THEN V1451 = .;
   IF (V1452 = -1) THEN V1452 = .;
   IF (V1453 = -1) THEN V1453 = .;
   IF (V1454 = -1) THEN V1454 = .;
   IF (V1455 = -1) THEN V1455 = .;
   IF (V1456 = -1) THEN V1456 = .;
   IF (V1457 = -1) THEN V1457 = .;
   IF (V1458 = -1) THEN V1458 = .;
   IF (V1459 = -1) THEN V1459 = .;
   IF (V1460 = -1) THEN V1460 = .;
   IF (V1461 = -1) THEN V1461 = .;
   IF (V1462 = -1) THEN V1462 = .;
   IF (V1463 = -1) THEN V1463 = .;
   IF (V1464 = -1) THEN V1464 = .;
   IF (V1465 = -1) THEN V1465 = .;
   IF (V1466 = -1) THEN V1466 = .;
   IF (V1467 = -1) THEN V1467 = .;
   IF (V1468 = -1) THEN V1468 = .;
   IF (V1469 = -1) THEN V1469 = .;
   IF (V1470 = -1) THEN V1470 = .;
   IF (V1471 = -1) THEN V1471 = .;
   IF (V1472 = -1) THEN V1472 = .;
   IF (V1473 = -1) THEN V1473 = .;
   IF (V1474 = -1) THEN V1474 = .;
   IF (V1475 = -1) THEN V1475 = .;
   IF (V1476 = -1) THEN V1476 = .;
   IF (V1477 = -1) THEN V1477 = .;
   IF (V1478 = -1) THEN V1478 = .;
   IF (V1479 = -1) THEN V1479 = .;
   IF (V1480 = -1) THEN V1480 = .;
   IF (V1481 = -1) THEN V1481 = .;
   IF (V1482 = -1) THEN V1482 = .;
   IF (V1483 = -1) THEN V1483 = .;
   IF (V1484 = -1) THEN V1484 = .;
   IF (V1485 = -1) THEN V1485 = .;
   IF (V1486 = -1) THEN V1486 = .;
   IF (V1487 = -1) THEN V1487 = .;
   IF (V1488 = -1) THEN V1488 = .;
   IF (V1489 = -1) THEN V1489 = .;
   IF (V1490 = -1) THEN V1490 = .;
   IF (V1491 = -1) THEN V1491 = .;
   IF (V1492 = -1) THEN V1492 = .;
   IF (V1493 = -1) THEN V1493 = .;
   IF (V1494 = -1) THEN V1494 = .;
   IF (V1495 = -1) THEN V1495 = .;
   IF (V1496 = -1) THEN V1496 = .;
   IF (V1497 = -1) THEN V1497 = .;
   IF (V1498 = -1) THEN V1498 = .;
   IF (V1499 = -1) THEN V1499 = .;
   IF (V1500 = -1) THEN V1500 = .;
   IF (V1501 = -1) THEN V1501 = .;
   IF (V1502 = -1) THEN V1502 = .;
   IF (V1503 = -1) THEN V1503 = .;
   IF (V1504 = -1) THEN V1504 = .;
   IF (V1505 = -1) THEN V1505 = .;
   IF (V1506 = -1) THEN V1506 = .;
   IF (V1507 = -1) THEN V1507 = .;
   IF (V1508 = -1) THEN V1508 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT V1 v1ffffff. V2 v2ffffff. V7 v7ffffff.
         V10 v10fffff. V15 v15fffff. V16 v16fffff.
         V17 v17fffff. V18 v18fffff. V19 v19fffff.
         V20 v20fffff. V21 v21fffff. V24 v24fffff.
         V27 v27fffff. V30 v30fffff. V33 v33fffff.
         V37 v37fffff. V38 v38fffff. V39 v39fffff.
         V40 v40fffff. V41 v41fffff. V42 v42fffff.
         V43 v43fffff. V44 v44fffff. V45 v45fffff.
         V47 v47fffff. V50 v50fffff. V51 v51fffff.
         V52 v52fffff. V53 v53fffff. V54 v54fffff.
         V55 v55fffff. V56 v56fffff. V57 v57fffff.
         V58 v58fffff. V59 v59fffff. V60 v60fffff.
         V61 v61fffff. V62 v62fffff. V63 v63fffff.
         V64 v64fffff. V65 v65fffff. V66 v66fffff.
         V67 v67fffff. V68 v68fffff. V69 v69fffff.
         V70 v70fffff. V71 v71fffff. V72 v72fffff.
         V73 v73fffff. V74 v74fffff. V75 v75fffff.
         V76 v76fffff. V77 v77fffff. V78 v78fffff.
         V79 v79fffff. V80 v80fffff. V81 v81fffff.
         V82 v82fffff. V83 v83fffff. V84 v84fffff.
         V85 v85fffff. V86 v86fffff. V87 v87fffff.
         V89 v89fffff. V90 v90fffff. V91 v91fffff.
         V92 v92fffff. V93 v93fffff. V94 v94fffff.
         V95 v95fffff. V96 v96fffff. V97 v97fffff.
         V98 v98fffff. V99 v99fffff. V102 v102ffff.
         V103 v103ffff. V104 v104ffff. V105 v105ffff.
         V106 v106ffff. V107 v107ffff. V109 v109ffff.
         V110 v110ffff. V111 v111ffff. V112 v112ffff.
         V114 v114ffff. V115 v115ffff. V116 v116ffff.
         V117 v117ffff. V118 v118ffff. V119 v119ffff.
         V120 v120ffff. V121 v121ffff. V122 v122ffff.
         V123 v123ffff. V124 v124ffff. V125 v125ffff.
         V126 v126ffff. V127 v127ffff. V128 v128ffff.
         V129 v129ffff. V130 v130ffff. V131 v131ffff.
         V132 v132ffff. V133 v133ffff. V138 v138ffff.
         V139 v139ffff. V140 v140ffff. V141 v141ffff.
         V142 v142ffff. V143 v143ffff. V144 v144ffff.
         V145 v145ffff. V146 v146ffff. V147 v147ffff.
         V148 v148ffff. V149 v149ffff. V150 v150ffff.
         V151 v151ffff. V152 v152ffff. V153 v153ffff.
         V154 v154ffff. V155 v155ffff. V156 v156ffff.
         V157 v157ffff. V158 v158ffff. V159 v159ffff.
         V160 v160ffff. V161 v161ffff. V162 v162ffff.
         V163 v163ffff. V164 v164ffff. V165 v165ffff.
         V166 v166ffff. V167 v167ffff. V168 v168ffff.
         V169 v169ffff. V170 v170ffff. V171 v171ffff.
         V172 v172ffff. V173 v173ffff. V174 v174ffff.
         V176 v176ffff. V181 v181ffff. V186 v186ffff.
         V187 v187ffff. V188 v188ffff. V189 v189ffff.
         V190 v190ffff. V191 v191ffff. V192 v192ffff.
         V193 v193ffff. V194 v194ffff. V195 v195ffff.
         V196 v196ffff. V197 v197ffff. V198 v198ffff.
         V199 v199ffff. V203 v203ffff. V205 v205ffff.
         V206 v206ffff. V207 v207ffff. V208 v208ffff.
         V209 v209ffff. V210 v210ffff. V211 v211ffff.
         V212 v212ffff. V213 v213ffff. V214 v214ffff.
         V215 v215ffff. V216 v216ffff. V217 v217ffff.
         V218 v218ffff. V219 v219ffff. V220 v220ffff.
         V221 v221ffff. V222 v222ffff. V223 v223ffff.
         V224 v224ffff. V225 v225ffff. V226 v226ffff.
         V227 v227ffff. V228 v228ffff. V229 v229ffff.
         V230 v230ffff. V231 v231ffff. V232 v232ffff.
         V233 v233ffff. V234 v234ffff. V235 v235ffff.
         V236 v236ffff. V237 v237ffff. V238 v238ffff.
         V239 v239ffff. V240 v240ffff. V241 v241ffff.
         V242 v242ffff. V243 v243ffff. V244 v244ffff.
         V245 v245ffff. V246 v246ffff. V247 v247ffff.
         V248 v248ffff. V249 v249ffff. V250 v250ffff.
         V251 v251ffff. V252 v252ffff. V253 v253ffff.
         V254 v254ffff. V255 v255ffff. V256 v256ffff.
         V258 v258ffff. V259 v259ffff. V260 v260ffff.
         V261 v261ffff. V262 v262ffff. V263 v263ffff.
         V264 v264ffff. V265 v265ffff. V266 v266ffff.
         V267 v267ffff. V268 v268ffff. V269 v269ffff.
         V270 v270ffff. V271 v271ffff. V272 v272ffff.
         V273 v273ffff. V274 v274ffff. V275 v275ffff.
         V276 v276ffff. V277 v277ffff. V278 v278ffff.
         V279 v279ffff. V280 v280ffff. V281 v281ffff.
         V282 v282ffff. V283 v283ffff. V284 v284ffff.
         V285 v285ffff. V286 v286ffff. V287 v287ffff.
         V288 v288ffff. V289 v289ffff. V290 v290ffff.
         V291 v291ffff. V292 v292ffff. V293 v293ffff.
         V294 v294ffff. V295 v295ffff. V296 v296ffff.
         V297 v297ffff. V298 v298ffff. V299 v299ffff.
         V300 v300ffff. V301 v301ffff. V302 v302ffff.
         V303 v303ffff. V304 v304ffff. V305 v305ffff.
         V306 v306ffff. V307 v307ffff. V308 v308ffff.
         V309 v309ffff. V310 v310ffff. V311 v311ffff.
         V312 v312ffff. V313 v313ffff. V314 v314ffff.
         V315 v315ffff. V316 v316ffff. V317 v317ffff.
         V318 v318ffff. V319 v319ffff. V320 v320ffff.
         V321 v321ffff. V322 v322ffff. V323 v323ffff.
         V324 v324ffff. V325 v325ffff. V326 v326ffff.
         V327 v327ffff. V328 v328ffff. V329 v329ffff.
         V330 v330ffff. V331 v331ffff. V332 v332ffff.
         V333 v333ffff. V334 v334ffff. V335 v335ffff.
         V336 v336ffff. V337 v337ffff. V338 v338ffff.
         V339 v339ffff. V340 v340ffff. V341 v341ffff.
         V342 v342ffff. V343 v343ffff. V344 v344ffff.
         V345 v345ffff. V346 v346ffff. V347 v347ffff.
         V348 v348ffff. V349 v349ffff. V350 v350ffff.
         V351 v351ffff. V352 v352ffff. V353 v353ffff.
         V354 v354ffff. V355 v355ffff. V356 v356ffff.
         V357 v357ffff. V358 v358ffff. V359 v359ffff.
         V360 v360ffff. V361 v361ffff. V362 v362ffff.
         V363 v363ffff. V364 v364ffff. V365 v365ffff.
         V366 v366ffff. V367 v367ffff. V368 v368ffff.
         V369 v369ffff. V370 v370ffff. V371 v371ffff.
         V372 v372ffff. V373 v373ffff. V374 v374ffff.
         V375 v375ffff. V376 v376ffff. V377 v377ffff.
         V378 v378ffff. V379 v379ffff. V380 v380ffff.
         V381 v381ffff. V382 v382ffff. V384 v384ffff.
         V386 v386ffff. V388 v388ffff. V390 v390ffff.
         V392 v392ffff. V394 v394ffff. V396 v396ffff.
         V398 v398ffff. V400 v400ffff. V402 v402ffff.
         V404 v404ffff. V406 v406ffff. V408 v408ffff.
         V410 v410ffff. V412 v412ffff. V414 v414ffff.
         V416 v416ffff. V418 v418ffff. V420 v420ffff.
         V422 v422ffff. V424 v424ffff. V426 v426ffff.
         V428 v428ffff. V430 v430ffff. V432 v432ffff.
         V434 v434ffff. V436 v436ffff. V438 v438ffff.
         V440 v440ffff. V442 v442ffff. V444 v444ffff.
         V446 v446ffff. V448 v448ffff. V450 v450ffff.
         V452 v452ffff. V454 v454ffff. V456 v456ffff.
         V458 v458ffff. V460 v460ffff. V462 v462ffff.
         V464 v464ffff. V466 v466ffff. V468 v468ffff.
         V470 v470ffff. V472 v472ffff. V473 v473ffff.
         V474 v474ffff. V475 v475ffff. V476 v476ffff.
         V477 v477ffff. V478 v478ffff. V479 v479ffff.
         V480 v480ffff. V481 v481ffff. V482 v482ffff.
         V483 v483ffff. V484 v484ffff. V485 v485ffff.
         V486 v486ffff. V487 v487ffff. V488 v488ffff.
         V489 v489ffff. V490 v490ffff. V491 v491ffff.
         V492 v492ffff. V493 v493ffff. V494 v494ffff.
         V495 v495ffff. V496 v496ffff. V497 v497ffff.
         V498 v498ffff. V499 v499ffff. V500 v500ffff.
         V501 v501ffff. V502 v502ffff. V503 v503ffff.
         V504 v504ffff. V505 v505ffff. V506 v506ffff.
         V507 v507ffff. V508 v508ffff. V509 v509ffff.
         V510 v510ffff. V511 v511ffff. V512 v512ffff.
         V513 v513ffff. V514 v514ffff. V515 v515ffff.
         V516 v516ffff. V517 v517ffff. V518 v518ffff.
         V519 v519ffff. V520 v520ffff. V521 v521ffff.
         V522 v522ffff. V523 v523ffff. V525 v525ffff.
         V526 v526ffff. V527 v527ffff. V529 v529ffff.
         V530 v530ffff. V531 v531ffff. V533 v533ffff.
         V534 v534ffff. V535 v535ffff. V537 v537ffff.
         V538 v538ffff. V539 v539ffff. V540 v540ffff.
         V541 v541ffff. V542 v542ffff. V543 v543ffff.
         V544 v544ffff. V545 v545ffff. V546 v546ffff.
         V547 v547ffff. V548 v548ffff. V549 v549ffff.
         V550 v550ffff. V551 v551ffff. V552 v552ffff.
         V553 v553ffff. V554 v554ffff. V555 v555ffff.
         V556 v556ffff. V557 v557ffff. V558 v558ffff.
         V559 v559ffff. V560 v560ffff. V561 v561ffff.
         V562 v562ffff. V563 v563ffff. V564 v564ffff.
         V565 v565ffff. V566 v566ffff. V568 v568ffff.
         V569 v569ffff. V570 v570ffff. V571 v571ffff.
         V572 v572ffff. V573 v573ffff. V575 v575ffff.
         V576 v576ffff. V577 v577ffff. V578 v578ffff.
         V579 v579ffff. V580 v580ffff. V582 v582ffff.
         V583 v583ffff. V584 v584ffff. V585 v585ffff.
         V586 v586ffff. V587 v587ffff. V588 v588ffff.
         V590 v590ffff. V591 v591ffff. V592 v592ffff.
         V593 v593ffff. V594 v594ffff. V595 v595ffff.
         V596 v596ffff. V597 v597ffff. V598 v598ffff.
         V600 v600ffff. V601 v601ffff. V602 v602ffff.
         V603 v603ffff. V604 v604ffff. V605 v605ffff.
         V606 v606ffff. V607 v607ffff. V608 v608ffff.
         V609 v609ffff. V610 v610ffff. V611 v611ffff.
         V612 v612ffff. V613 v613ffff. V614 v614ffff.
         V615 v615ffff. V616 v616ffff. V617 v617ffff.
         V618 v618ffff. V619 v619ffff. V620 v620ffff.
         V621 v621ffff. V622 v622ffff. V623 v623ffff.
         V624 v624ffff. V625 v625ffff. V626 v626ffff.
         V627 v627ffff. V628 v628ffff. V629 v629ffff.
         V630 v630ffff. V631 v631ffff. V632 v632ffff.
         V633 v633ffff. V634 v634ffff. V635 v635ffff.
         V636 v636ffff. V637 v637ffff. V638 v638ffff.
         V639 v639ffff. V640 v640ffff. V641 v641ffff.
         V642 v642ffff. V643 v643ffff. V644 v644ffff.
         V645 v645ffff. V646 v646ffff. V647 v647ffff.
         V648 v648ffff. V649 v649ffff. V650 v650ffff.
         V651 v651ffff. V652 v652ffff. V653 v653ffff.
         V654 v654ffff. V655 v655ffff. V656 v656ffff.
         V658 v658ffff. V659 v659ffff. V660 v660ffff.
         V662 v662ffff. V663 v663ffff. V664 v664ffff.
         V665 v665ffff. V666 v666ffff. V669 v669ffff.
         V670 v670ffff. V671 v671ffff. V672 v672ffff.
         V673 v673ffff. V676 v676ffff. V677 v677ffff.
         V678 v678ffff. V679 v679ffff. V680 v680ffff.
         V681 v681ffff. V682 v682ffff. V683 v683ffff.
         V684 v684ffff. V685 v685ffff. V686 v686ffff.
         V687 v687ffff. V688 v688ffff. V689 v689ffff.
         V690 v690ffff. V691 v691ffff. V692 v692ffff.
         V693 v693ffff. V694 v694ffff. V695 v695ffff.
         V696 v696ffff. V697 v697ffff. V698 v698ffff.
         V699 v699ffff. V700 v700ffff. V701 v701ffff.
         V702 v702ffff. V703 v703ffff. V704 v704ffff.
         V705 v705ffff. V706 v706ffff. V707 v707ffff.
         V708 v708ffff. V709 v709ffff. V710 v710ffff.
         V711 v711ffff. V712 v712ffff. V713 v713ffff.
         V714 v714ffff. V715 v715ffff. V716 v716ffff.
         V717 v717ffff. V718 v718ffff. V719 v719ffff.
         V720 v720ffff. V721 v721ffff. V722 v722ffff.
         V723 v723ffff. V724 v724ffff. V725 v725ffff.
         V726 v726ffff. V727 v727ffff. V728 v728ffff.
         V729 v729ffff. V730 v730ffff. V731 v731ffff.
         V732 v732ffff. V733 v733ffff. V734 v734ffff.
         V735 v735ffff. V736 v736ffff. V737 v737ffff.
         V738 v738ffff. V739 v739ffff. V740 v740ffff.
         V741 v741ffff. V742 v742ffff. V744 v744ffff.
         V745 v745ffff. V746 v746ffff. V747 v747ffff.
         V750 v750ffff. V751 v751ffff. V752 v752ffff.
         V753 v753ffff. V754 v754ffff. V755 v755ffff.
         V756 v756ffff. V757 v757ffff. V758 v758ffff.
         V759 v759ffff. V760 v760ffff. V761 v761ffff.
         V762 v762ffff. V763 v763ffff. V764 v764ffff.
         V765 v765ffff. V766 v766ffff. V767 v767ffff.
         V768 v768ffff. V769 v769ffff. V770 v770ffff.
         V771 v771ffff. V772 v772ffff. V773 v773ffff.
         V774 v774ffff. V775 v775ffff. V776 v776ffff.
         V777 v777ffff. V778 v778ffff. V779 v779ffff.
         V780 v780ffff. V781 v781ffff. V782 v782ffff.
         V783 v783ffff. V784 v784ffff. V785 v785ffff.
         V786 v786ffff. V787 v787ffff. V788 v788ffff.
         V789 v789ffff. V790 v790ffff. V791 v791ffff.
         V792 v792ffff. V793 v793ffff. V794 v794ffff.
         V795 v795ffff. V796 v796ffff. V797 v797ffff.
         V798 v798ffff. V799 v799ffff. V800 v800ffff.
         V801 v801ffff. V802 v802ffff. V803 v803ffff.
         V804 v804ffff. V805 v805ffff. V806 v806ffff.
         V807 v807ffff. V808 v808ffff. V809 v809ffff.
         V810 v810ffff. V811 v811ffff. V812 v812ffff.
         V813 v813ffff. V814 v814ffff. V815 v815ffff.
         V816 v816ffff. V817 v817ffff. V818 v818ffff.
         V819 v819ffff. V820 v820ffff. V822 v822ffff.
         V823 v823ffff. V824 v824ffff. V825 v825ffff.
         V826 v826ffff. V827 v827ffff. V828 v828ffff.
         V830 v830ffff. V831 v831ffff. V832 v832ffff.
         V833 v833ffff. V834 v834ffff. V835 v835ffff.
         V836 v836ffff. V837 v837ffff. V838 v838ffff.
         V839 v839ffff. V840 v840ffff. V841 v841ffff.
         V842 v842ffff. V843 v843ffff. V844 v844ffff.
         V845 v845ffff. V846 v846ffff. V847 v847ffff.
         V848 v848ffff. V849 v849ffff. V850 v850ffff.
         V851 v851ffff. V852 v852ffff. V853 v853ffff.
         V854 v854ffff. V855 v855ffff. V857 v857ffff.
         V858 v858ffff. V859 v859ffff. V860 v860ffff.
         V861 v861ffff. V862 v862ffff. V863 v863ffff.
         V864 v864ffff. V865 v865ffff. V867 v867ffff.
         V868 v868ffff. V869 v869ffff. V870 v870ffff.
         V871 v871ffff. V872 v872ffff. V873 v873ffff.
         V874 v874ffff. V875 v875ffff. V876 v876ffff.
         V877 v877ffff. V878 v878ffff. V879 v879ffff.
         V880 v880ffff. V881 v881ffff. V883 v883ffff.
         V884 v884ffff. V885 v885ffff. V886 v886ffff.
         V891 v891ffff. V892 v892ffff. V894 v894ffff.
         V895 v895ffff. V897 v897ffff. V898 v898ffff.
         V900 v900ffff. V901 v901ffff. V903 v903ffff.
         V904 v904ffff. V906 v906ffff. V907 v907ffff.
         V909 v909ffff. V910 v910ffff. V912 v912ffff.
         V913 v913ffff. V915 v915ffff. V916 v916ffff.
         V918 v918ffff. V919 v919ffff. V920 v920ffff.
         V922 v922ffff. V923 v923ffff. V924 v924ffff.
         V925 v925ffff. V926 v926ffff. V927 v927ffff.
         V928 v928ffff. V929 v929ffff. V930 v930ffff.
         V931 v931ffff. V932 v932ffff. V933 v933ffff.
         V934 v934ffff. V935 v935ffff. V936 v936ffff.
         V937 v937ffff. V938 v938ffff. V939 v939ffff.
         V940 v940ffff. V941 v941ffff. V942 v942ffff.
         V943 v943ffff. V944 v944ffff. V945 v945ffff.
         V946 v946ffff. V947 v947ffff. V948 v948ffff.
         V949 v949ffff. V950 v950ffff. V951 v951ffff.
         V952 v952ffff. V953 v953ffff. V954 v954ffff.
         V955 v955ffff. V956 v956ffff. V957 v957ffff.
         V958 v958ffff. V959 v959ffff. V960 v960ffff.
         V961 v961ffff. V962 v962ffff. V972 v972ffff.
         V973 v973ffff. V974 v974ffff. V975 v975ffff.
         V976 v976ffff. V977 v977ffff. V978 v978ffff.
         V979 v979ffff. V980 v980ffff. V981 v981ffff.
         V982 v982ffff. V983 v983ffff. V984 v984ffff.
         V985 v985ffff. V986 v986ffff. V987 v987ffff.
         V988 v988ffff. V989 v989ffff. V990 v990ffff.
         V991 v991ffff. V992 v992ffff. V993 v993ffff.
         V994 v994ffff. V995 v995ffff. V996 v996ffff.
         V997 v997ffff. V998 v998ffff. V999 v999ffff.
         V1000 v1000fff. V1001 v1001fff. V1002 v1002fff.
         V1003 v1003fff. V1004 v1004fff. V1005 v1005fff.
         V1006 v1006fff. V1007 v1007fff. V1008 v1008fff.
         V1009 v1009fff. V1010 v1010fff. V1011 v1011fff.
         V1012 v1012fff. V1013 v1013fff. V1014 v1014fff.
         V1015 v1015fff. V1016 v1016fff. V1017 v1017fff.
         V1018 v1018fff. V1019 v1019fff. V1020 v1020fff.
         V1021 v1021fff. V1022 v1022fff. V1023 v1023fff.
         V1024 v1024fff. V1025 v1025fff. V1026 v1026fff.
         V1027 v1027fff. V1028 v1028fff. V1029 v1029fff.
         V1030 v1030fff. V1031 v1031fff. V1032 v1032fff.
         V1033 v1033fff. V1034 v1034fff. V1035 v1035fff.
         V1036 v1036fff. V1037 v1037fff. V1038 v1038fff.
         V1039 v1039fff. V1040 v1040fff. V1041 v1041fff.
         V1042 v1042fff. V1043 v1043fff. V1044 v1044fff.
         V1045 v1045fff. V1046 v1046fff. V1047 v1047fff.
         V1048 v1048fff. V1049 v1049fff. V1050 v1050fff.
         V1051 v1051fff. V1052 v1052fff. V1053 v1053fff.
         V1054 v1054fff. V1055 v1055fff. V1056 v1056fff.
         V1057 v1057fff. V1058 v1058fff. V1059 v1059fff.
         V1060 v1060fff. V1061 v1061fff. V1062 v1062fff.
         V1063 v1063fff. V1064 v1064fff. V1065 v1065fff.
         V1067 v1067fff. V1068 v1068fff. V1075 v1075fff.
         V1076 v1076fff. V1077 v1077fff. V1084 v1084fff.
         V1085 v1085fff. V1086 v1086fff. V1093 v1093fff.
         V1094 v1094fff. V1095 v1095fff. V1096 v1096fff.
         V1098 v1098fff. V1099 v1099fff. V1101 v1101fff.
         V1103 v1103fff. V1104 v1104fff. V1105 v1105fff.
         V1106 v1106fff. V1108 v1108fff. V1109 v1109fff.
         V1110 v1110fff. V1111 v1111fff. V1112 v1112fff.
         V1113 v1113fff. V1114 v1114fff. V1115 v1115fff.
         V1116 v1116fff. V1117 v1117fff. V1118 v1118fff.
         V1119 v1119fff. V1120 v1120fff. V1121 v1121fff.
         V1122 v1122fff. V1123 v1123fff. V1124 v1124fff.
         V1125 v1125fff. V1126 v1126fff. V1127 v1127fff.
         V1128 v1128fff. V1129 v1129fff. V1130 v1130fff.
         V1131 v1131fff. V1132 v1132fff. V1133 v1133fff.
         V1136 v1136fff. V1137 v1137fff. V1138 v1138fff.
         V1139 v1139fff. V1141 v1141fff. V1142 v1142fff.
         V1143 v1143fff. V1144 v1144fff. V1145 v1145fff.
         V1146 v1146fff. V1147 v1147fff. V1148 v1148fff.
         V1149 v1149fff. V1150 v1150fff. V1151 v1151fff.
         V1152 v1152fff. V1153 v1153fff. V1154 v1154fff.
         V1156 v1156fff. V1157 v1157fff. V1158 v1158fff.
         V1159 v1159fff. V1160 v1160fff. V1161 v1161fff.
         V1162 v1162fff. V1163 v1163fff. V1164 v1164fff.
         V1165 v1165fff. V1166 v1166fff. V1167 v1167fff.
         V1168 v1168fff. V1169 v1169fff. V1173 v1173fff.
         V1174 v1174fff. V1175 v1175fff. V1176 v1176fff.
         V1177 v1177fff. V1178 v1178fff. V1179 v1179fff.
         V1180 v1180fff. V1181 v1181fff. V1182 v1182fff.
         V1183 v1183fff. V1184 v1184fff. V1185 v1185fff.
         V1189 v1189fff. V1190 v1190fff. V1191 v1191fff.
         V1193 v1193fff. V1198 v1198fff. V1199 v1199fff.
         V1200 v1200fff. V1201 v1201fff. V1202 v1202fff.
         V1203 v1203fff. V1204 v1204fff. V1205 v1205fff.
         V1206 v1206fff. V1207 v1207fff. V1208 v1208fff.
         V1209 v1209fff. V1210 v1210fff. V1212 v1212fff.
         V1213 v1213fff. V1214 v1214fff. V1215 v1215fff.
         V1217 v1217fff. V1218 v1218fff. V1219 v1219fff.
         V1220 v1220fff. V1222 v1222fff. V1223 v1223fff.
         V1224 v1224fff. V1225 v1225fff. V1227 v1227fff.
         V1228 v1228fff. V1229 v1229fff. V1231 v1231fff.
         V1232 v1232fff. V1233 v1233fff. V1234 v1234fff.
         V1235 v1235fff. V1236 v1236fff. V1237 v1237fff.
         V1238 v1238fff. V1239 v1239fff. V1240 v1240fff.
         V1241 v1241fff. V1242 v1242fff. V1243 v1243fff.
         V1244 v1244fff. V1245 v1245fff. V1246 v1246fff.
         V1247 v1247fff. V1248 v1248fff. V1249 v1249fff.
         V1250 v1250fff. V1251 v1251fff. V1252 v1252fff.
         V1253 v1253fff. V1254 v1254fff. V1255 v1255fff.
         V1256 v1256fff. V1257 v1257fff. V1258 v1258fff.
         V1259 v1259fff. V1260 v1260fff. V1261 v1261fff.
         V1262 v1262fff. V1263 v1263fff. V1264 v1264fff.
         V1265 v1265fff. V1266 v1266fff. V1267 v1267fff.
         V1268 v1268fff. V1269 v1269fff. V1270 v1270fff.
         V1271 v1271fff. V1272 v1272fff. V1273 v1273fff.
         V1274 v1274fff. V1280 v1280fff. V1281 v1281fff.
         V1282 v1282fff. V1283 v1283fff. V1285 v1285fff.
         V1286 v1286fff. V1287 v1287fff. V1288 v1288fff.
         V1290 v1290fff. V1291 v1291fff. V1292 v1292fff.
         V1293 v1293fff. V1294 v1294fff. V1295 v1295fff.
         V1296 v1296fff. V1297 v1297fff. V1298 v1298fff.
         V1299 v1299fff. V1300 v1300fff. V1301 v1301fff.
         V1302 v1302fff. V1303 v1303fff. V1304 v1304fff.
         V1305 v1305fff. V1306 v1306fff. V1307 v1307fff.
         V1308 v1308fff. V1309 v1309fff. V1310 v1310fff.
         V1311 v1311fff. V1312 v1312fff. V1313 v1313fff.
         V1314 v1314fff. V1315 v1315fff. V1316 v1316fff.
         V1317 v1317fff. V1318 v1318fff. V1319 v1319fff.
         V1320 v1320fff. V1321 v1321fff. V1322 v1322fff.
         V1323 v1323fff. V1324 v1324fff. V1325 v1325fff.
         V1326 v1326fff. V1327 v1327fff. V1328 v1328fff.
         V1329 v1329fff. V1330 v1330fff. V1331 v1331fff.
         V1332 v1332fff. V1333 v1333fff. V1334 v1334fff.
         V1335 v1335fff. V1336 v1336fff. V1337 v1337fff.
         V1338 v1338fff. V1339 v1339fff. V1340 v1340fff.
         V1341 v1341fff. V1342 v1342fff. V1343 v1343fff.
         V1344 v1344fff. V1345 v1345fff. V1346 v1346fff.
         V1347 v1347fff. V1348 v1348fff. V1349 v1349fff.
         V1350 v1350fff. V1351 v1351fff. V1352 v1352fff.
         V1353 v1353fff. V1354 v1354fff. V1355 v1355fff.
         V1356 v1356fff. V1357 v1357fff. V1358 v1358fff.
         V1359 v1359fff. V1360 v1360fff. V1361 v1361fff.
         V1362 v1362fff. V1363 v1363fff. V1364 v1364fff.
         V1365 v1365fff. V1366 v1366fff. V1367 v1367fff.
         V1368 v1368fff. V1369 v1369fff. V1370 v1370fff.
         V1371 v1371fff. V1372 v1372fff. V1375 v1375fff.
         V1376 v1376fff. V1377 v1377fff. V1378 v1378fff.
         V1379 v1379fff. V1380 v1380fff. V1381 v1381fff.
         V1382 v1382fff. V1383 v1383fff. V1384 v1384fff.
         V1385 v1385fff. V1388 v1388fff. V1389 v1389fff.
         V1390 v1390fff. V1391 v1391fff. V1392 v1392fff.
         V1393 v1393fff. V1394 v1394fff. V1395 v1395fff.
         V1396 v1396fff. V1397 v1397fff. V1398 v1398fff.
         V1399 v1399fff. V1400 v1400fff. V1401 v1401fff.
         V1402 v1402fff. V1403 v1403fff. V1404 v1404fff.
         V1405 v1405fff. V1406 v1406fff. V1407 v1407fff.
         V1408 v1408fff. V1409 v1409fff. V1410 v1410fff.
         V1411 v1411fff. V1412 v1412fff. V1413 v1413fff.
         V1414 v1414fff. V1415 v1415fff. V1416 v1416fff.
         V1417 v1417fff. V1418 v1418fff. V1419 v1419fff.
         V1420 v1420fff. V1421 v1421fff. V1422 v1422fff.
         V1423 v1423fff. V1424 v1424fff. V1425 v1425fff.
         V1433 v1433fff. V1434 v1434fff. V1435 v1435fff.
         V1436 v1436fff. V1437 v1437fff. V1438 v1438fff.
         V1439 v1439fff. V1442 v1442fff. V1443 v1443fff.
         V1444 v1444fff. V1446 v1446fff. V1447 v1447fff.
         V1450 v1450fff. V1451 v1451fff. V1452 v1452fff.
         V1453 v1453fff. V1455 v1455fff. V1456 v1456fff.
         V1460 v1460fff. V1461 v1461fff. V1462 v1462fff.
         V1463 v1463fff. V1465 v1465fff. V1466 v1466fff.
         V1467 v1467fff. V1468 v1468fff. V1469 v1469fff.
         V1470 v1470fff. V1471 v1471fff. V1472 v1472fff.
         V1473 v1473fff. V1474 v1474fff. V1475 v1475fff.
         V1476 v1476fff. V1479 v1479fff. V1480 v1480fff.
         V1481 v1481fff. V1482 v1482fff. V1483 v1483fff.
         V1484 v1484fff. V1485 v1485fff. V1486 v1486fff.
         V1487 v1487fff. V1488 v1488fff. V1489 v1489fff.
         V1508 v1508fff.  ;
*/

RUN ;
